@@ -21,18 +21,18 @@ AST_Extended_Port::AST_Extended_Port (
 {
 }
 
-AST_Extended_Port::~AST_Extended_Port (void)
+AST_Extended_Port::~AST_Extended_Port ()
 {
 }
 
 AST_PortType *
-AST_Extended_Port::port_type (void) const
+AST_Extended_Port::port_type () const
 {
-  return AST_PortType::narrow_from_decl (this->field_type ());
+  return dynamic_cast<AST_PortType*> (this->field_type ());
 }
 
 void
-AST_Extended_Port::destroy (void)
+AST_Extended_Port::destroy ()
 {
   this->AST_Field::destroy ();
 }
@@ -50,6 +50,3 @@ AST_Extended_Port::ast_accept (ast_visitor *visitor)
 {
   return visitor->visit_extended_port (this);
 }
-
-IMPL_NARROW_FROM_DECL (AST_Extended_Port)
-
