@@ -104,6 +104,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_factory.h"
 #include "ast_finder.h"
 #include "ast_fixed.h"
+#include "ast_annotation_appl.h"
+#include "ast_annotation_member.h"
 
 #include "utl_identifier.h"
 
@@ -116,10 +118,10 @@ AST_PredefinedType *
 AST_Generator::create_predefined_type (AST_PredefinedType::PredefinedType t,
                                        UTL_ScopedName *n)
 {
-  AST_PredefinedType *retval = 0;
+  AST_PredefinedType *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_PredefinedType (t, n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -128,7 +130,7 @@ AST_Module *
 AST_Generator::create_module (UTL_Scope *s,
                               UTL_ScopedName *n)
 {
-  AST_Module *retval = 0;
+  AST_Module *retval = nullptr;
 
   // Check for another module of the same name in the scope.
   for (UTL_ScopeActiveIterator iter (s, UTL_Scope::IK_decls);
@@ -137,12 +139,12 @@ AST_Generator::create_module (UTL_Scope *s,
     {
       // Can't just check node type here, since it could be a
       // template module or template module instantiation.
-      AST_Module *m = AST_Module::narrow_from_decl (iter.item ());
+      AST_Module *m = dynamic_cast<AST_Module*> (iter.item ());
       if (m && m->local_name ()->compare (n->last_component ()))
         {
           // Create this new module with referance to the
           // "first" previous module found in scope.
-          ACE_NEW_RETURN (retval, AST_Module (n, m), 0);
+          ACE_NEW_RETURN (retval, AST_Module (n, m), nullptr);
           retval->prefix (const_cast<char *> (m->prefix ()));
           return retval;
         }
@@ -153,8 +155,7 @@ AST_Generator::create_module (UTL_Scope *s,
   // is itself a module, and has been previously opened, any
   // of the previous openings may contain a previous opening
   // of the module we're creating.
-  //  AST_Module *prev_module = AST_Module::narrow_from_scope (s);
-  AST_Module *prev_module = AST_Module::narrow_from_scope (s);
+  AST_Module *prev_module = dynamic_cast<AST_Module*> (s);
   if (prev_module)
     {
       while (!!(prev_module= prev_module->previous_opening ()))
@@ -163,12 +164,12 @@ AST_Generator::create_module (UTL_Scope *s,
                !iter.is_done ();
                iter.next ())
             {
-              AST_Module *m = AST_Module::narrow_from_decl (iter.item ());
+              AST_Module *m = dynamic_cast<AST_Module*> (iter.item ());
               if (m && m->local_name ()->compare (n->last_component ()))
                 {
                   // Create this new module with referance to the
                   // "first" previous module found in scope.
-                  ACE_NEW_RETURN (retval, AST_Module (n, m), 0);
+                  ACE_NEW_RETURN (retval, AST_Module (n, m), nullptr);
                   return retval;
                 }
             }
@@ -176,17 +177,17 @@ AST_Generator::create_module (UTL_Scope *s,
     }
 
   // There is no previous module to this one
-  ACE_NEW_RETURN (retval, AST_Module (n), 0);
+  ACE_NEW_RETURN (retval, AST_Module (n), nullptr);
   return retval;
 }
 
 AST_Root *
 AST_Generator::create_root (UTL_ScopedName *n)
 {
-  AST_Root *retval = 0;
+  AST_Root *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Root (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -200,7 +201,7 @@ AST_Generator::create_interface (UTL_ScopedName *n,
                                  bool is_local,
                                  bool is_abstract)
 {
-  AST_Interface *retval = 0;
+  AST_Interface *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Interface (n,
                                  inherits,
@@ -209,7 +210,7 @@ AST_Generator::create_interface (UTL_ScopedName *n,
                                  n_inherits_flat,
                                  is_local,
                                  is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -221,16 +222,16 @@ AST_Generator::create_interface_fwd (UTL_ScopedName *n,
 {
   AST_Interface
     *full_defn = this->create_interface (n,
-                                         0,
+                                         nullptr,
                                          -1,
-                                         0,
+                                         nullptr,
                                          0,
                                          is_local,
                                          is_abstract);
-  AST_InterfaceFwd *retval = 0;
+  AST_InterfaceFwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_InterfaceFwd (full_defn, n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -250,7 +251,7 @@ AST_Generator::create_valuetype (UTL_ScopedName *n,
                                  bool is_truncatable,
                                  bool is_custom)
 {
-  AST_ValueType *retval = 0;
+  AST_ValueType *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_ValueType (n,
                                  inherits,
@@ -264,10 +265,10 @@ AST_Generator::create_valuetype (UTL_ScopedName *n,
                                  is_abstract,
                                  is_truncatable,
                                  is_custom),
-                  0);
+                  nullptr);
 
   // The following helps with OBV_ namespace generation.
-  AST_Module *m = AST_Module::narrow_from_scope (retval->defined_in ());
+  AST_Module *m = dynamic_cast<AST_Module*> (retval->defined_in ());
   if (m)
     {
       m->set_has_nested_valuetype ();
@@ -281,23 +282,23 @@ AST_Generator::create_valuetype_fwd (UTL_ScopedName *n,
                                      bool is_abstract)
 {
   AST_ValueType *full_defn = this->create_valuetype (n,
-                                                     0,
+                                                     nullptr,
                                                      -1,
+                                                     nullptr,
+                                                     nullptr,
                                                      0,
+                                                     nullptr,
                                                      0,
-                                                     0,
-                                                     0,
-                                                     0,
-                                                     0,
+                                                     nullptr,
                                                      is_abstract,
                                                      false,
                                                      false);
 
-  AST_ValueTypeFwd *retval = 0;
+  AST_ValueTypeFwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_ValueTypeFwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -317,7 +318,7 @@ AST_Generator::create_eventtype (UTL_ScopedName *n,
                                  bool is_truncatable,
                                  bool is_custom)
 {
-  AST_EventType *retval = 0;
+  AST_EventType *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_EventType (n,
                                  inherits,
@@ -331,12 +332,12 @@ AST_Generator::create_eventtype (UTL_ScopedName *n,
                                  is_abstract,
                                  is_truncatable,
                                  is_custom),
-                  0);
+                  nullptr);
 
   // The following helps with OBV_ namespace generation.
-  AST_Module *m = AST_Module::narrow_from_scope (retval->defined_in ());
+  AST_Module *m = dynamic_cast<AST_Module*> (retval->defined_in ());
 
-  if (m != 0)
+  if (m != nullptr)
     {
       m->set_has_nested_valuetype ();
     }
@@ -349,23 +350,23 @@ AST_Generator::create_eventtype_fwd (UTL_ScopedName *n,
                                      bool is_abstract)
 {
   AST_EventType *full_defn = this->create_eventtype (n,
-                                                     0,
+                                                     nullptr,
                                                      -1,
+                                                     nullptr,
+                                                     nullptr,
                                                      0,
+                                                     nullptr,
                                                      0,
-                                                     0,
-                                                     0,
-                                                     0,
-                                                     0,
+                                                     nullptr,
                                                      is_abstract,
                                                      false,
                                                      false);
 
-  AST_EventTypeFwd *retval = 0;
+  AST_EventTypeFwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_EventTypeFwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -379,7 +380,7 @@ AST_Generator::create_component (UTL_ScopedName *n,
                                  AST_Interface **supports_flat,
                                  long n_supports_flat)
 {
-  AST_Component *retval = 0;
+  AST_Component *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Component (n,
                                  base_component,
@@ -387,7 +388,7 @@ AST_Generator::create_component (UTL_ScopedName *n,
                                  n_supports,
                                  supports_flat,
                                  n_supports_flat),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -396,17 +397,17 @@ AST_ComponentFwd *
 AST_Generator::create_component_fwd (UTL_ScopedName *n)
 {
   AST_Component *full_defn = this->create_component (n,
-                                                     0,
-                                                     0,
+                                                     nullptr,
+                                                     nullptr,
                                                      -1,
-                                                     0,
+                                                     nullptr,
                                                      0);
 
-  AST_ComponentFwd *retval = 0;
+  AST_ComponentFwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_ComponentFwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -422,7 +423,7 @@ AST_Generator::create_home (UTL_ScopedName *n,
                             AST_Interface **supports_flat,
                             long n_supports_flat)
 {
-  AST_Home *retval = 0;
+  AST_Home *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Home (n,
                             base_home,
@@ -432,7 +433,7 @@ AST_Generator::create_home (UTL_ScopedName *n,
                             n_supports,
                             supports_flat,
                             n_supports_flat),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -442,12 +443,12 @@ AST_Generator::create_exception (UTL_ScopedName *n,
                                  bool is_local,
                                  bool is_abstract)
 {
-  AST_Exception *retval = 0;
+  AST_Exception *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Exception (n,
                                  is_local,
                                  is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -457,12 +458,12 @@ AST_Generator::create_structure (UTL_ScopedName *n,
                                  bool is_local,
                                  bool is_abstract)
 {
-  AST_Structure *retval = 0;
+  AST_Structure *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Structure (n,
                                  is_local,
                                  is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -473,11 +474,11 @@ AST_Generator::create_structure_fwd (UTL_ScopedName *n)
   AST_Structure *full_defn = this->create_structure  (n,
                                                       false,
                                                       false);
-  AST_StructureFwd *retval = 0;
+  AST_StructureFwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_StructureFwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -488,12 +489,12 @@ AST_Generator::create_enum (UTL_ScopedName *n,
                             bool is_local,
                             bool is_abstract)
 {
-  AST_Enum *retval = 0;
+  AST_Enum *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Enum (n,
                             is_local,
                             is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -505,14 +506,14 @@ AST_Generator::create_operation (AST_Type *rt,
                                  bool is_local,
                                  bool is_abstract)
 {
-  AST_Operation *retval = 0;
+  AST_Operation *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Operation (rt,
                                  fl,
                                  n,
                                  is_local,
                                  is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -522,12 +523,12 @@ AST_Generator::create_field (AST_Type *ft,
                              UTL_ScopedName *n,
                              AST_Field::Visibility vis)
 {
-  AST_Field *retval = 0;
+  AST_Field *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Field (ft,
                              n,
                              vis),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -537,12 +538,12 @@ AST_Generator::create_argument (AST_Argument::Direction d,
                                 AST_Type *ft,
                                 UTL_ScopedName *n)
 {
-  AST_Argument *retval = 0;
+  AST_Argument *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Argument (d,
                                 ft,
                                 n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -554,14 +555,14 @@ AST_Generator::create_attribute (bool ro,
                                  bool is_local,
                                  bool is_abstract)
 {
-  AST_Attribute *retval = 0;
+  AST_Attribute *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Attribute (ro,
                                  ft,
                                  n,
                                  is_local,
                                  is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -572,13 +573,13 @@ AST_Generator::create_union (AST_ConcreteType *dt,
                              bool is_local,
                              bool is_abstract)
 {
-  AST_Union *retval = 0;
+  AST_Union *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Union (dt,
                              n,
                              is_local,
                              is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -586,15 +587,15 @@ AST_Generator::create_union (AST_ConcreteType *dt,
 AST_UnionFwd *
 AST_Generator::create_union_fwd (UTL_ScopedName *n)
 {
-  AST_Union *full_defn = this->create_union (0,
+  AST_Union *full_defn = this->create_union (nullptr,
                                              n,
                                              false,
                                              false);
-  AST_UnionFwd *retval = 0;
+  AST_UnionFwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_UnionFwd (full_defn,
                                 n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -605,12 +606,12 @@ AST_Generator::create_union_branch (UTL_LabelList *ll,
                                     AST_Type *ft,
                                     UTL_ScopedName *n)
 {
-  AST_UnionBranch *retval = 0;
+  AST_UnionBranch *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_UnionBranch (ll,
                                    ft,
                                    n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -619,11 +620,11 @@ AST_UnionLabel *
 AST_Generator::create_union_label (AST_UnionLabel::UnionLabel ul,
                                    AST_Expression *v)
 {
-  AST_UnionLabel *retval = 0;
+  AST_UnionLabel *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_UnionLabel (ul,
                                   v),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -633,12 +634,12 @@ AST_Generator::create_constant (AST_Expression::ExprType et,
                                 AST_Expression *ev,
                                 UTL_ScopedName *n)
 {
-  AST_Constant *retval = 0;
+  AST_Constant *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Constant (et,
                                 ev,
                                 n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -646,10 +647,10 @@ AST_Generator::create_constant (AST_Expression::ExprType et,
 AST_Expression *
 AST_Generator::create_expr (UTL_ScopedName *n)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -658,11 +659,11 @@ AST_Expression *
 AST_Generator::create_expr (AST_Expression *v,
                             AST_Expression::ExprType t)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (v,
                                   t),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -672,12 +673,12 @@ AST_Generator::create_expr (AST_Expression::ExprComb c,
                             AST_Expression *v1,
                             AST_Expression *v2)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (c,
                                   v1,
                                   v2),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -685,10 +686,10 @@ AST_Generator::create_expr (AST_Expression::ExprComb c,
 AST_Expression *
 AST_Generator::create_expr (ACE_CDR::Long v)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (v),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -696,10 +697,10 @@ AST_Generator::create_expr (ACE_CDR::Long v)
 AST_Expression *
 AST_Generator::create_expr (ACE_CDR::LongLong l)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (l),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -707,10 +708,10 @@ AST_Generator::create_expr (ACE_CDR::LongLong l)
 AST_Expression *
 AST_Generator::create_expr (ACE_CDR::Boolean b)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (b),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -718,10 +719,10 @@ AST_Generator::create_expr (ACE_CDR::Boolean b)
 AST_Expression *
 AST_Generator::create_expr (ACE_CDR::ULong v)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (v),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -729,10 +730,10 @@ AST_Generator::create_expr (ACE_CDR::ULong v)
 AST_Expression *
 AST_Generator::create_expr (ACE_CDR::ULongLong l)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (l),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -741,10 +742,10 @@ AST_Expression *
 AST_Generator::create_expr (ACE_CDR::ULong v,
                             AST_Expression::ExprType t)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (v, t),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -752,10 +753,10 @@ AST_Generator::create_expr (ACE_CDR::ULong v,
 AST_Expression *
 AST_Generator::create_expr (UTL_String *s)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (s),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -763,10 +764,10 @@ AST_Generator::create_expr (UTL_String *s)
 AST_Expression *
 AST_Generator::create_expr (ACE_CDR::Char c)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (c),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -774,10 +775,10 @@ AST_Generator::create_expr (ACE_CDR::Char c)
 AST_Expression *
 AST_Generator::create_expr (ACE_OutputCDR::from_wchar wc)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (wc),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -785,10 +786,10 @@ AST_Generator::create_expr (ACE_OutputCDR::from_wchar wc)
 AST_Expression *
 AST_Generator::create_expr (char *s)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (s),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -796,10 +797,10 @@ AST_Generator::create_expr (char *s)
 AST_Expression *
 AST_Generator::create_expr (ACE_CDR::Double d)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (d),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -807,10 +808,10 @@ AST_Generator::create_expr (ACE_CDR::Double d)
 AST_Expression *
 AST_Generator::create_expr (const ACE_CDR::Fixed &f)
 {
-  AST_Expression *retval = 0;
+  AST_Expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Expression (f),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -819,11 +820,11 @@ AST_EnumVal *
 AST_Generator::create_enum_val (ACE_CDR::ULong v,
                                 UTL_ScopedName *n)
 {
-  AST_EnumVal *retval = 0;
+  AST_EnumVal *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_EnumVal (v,
                                n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -835,14 +836,14 @@ AST_Generator::create_array (UTL_ScopedName *n,
                              bool is_local,
                              bool is_abstract)
 {
-  AST_Array *retval = 0;
+  AST_Array *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Array (n,
                              ndims,
                              dims,
                              is_local,
                              is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -854,14 +855,14 @@ AST_Generator::create_sequence (AST_Expression *ms,
                                 bool is_local,
                                 bool is_abstract)
 {
-  AST_Sequence *retval = 0;
+  AST_Sequence *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Sequence (ms,
                                 bt,
                                 n,
                                 is_local,
                                 is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -871,14 +872,14 @@ AST_Generator::create_string (AST_Expression *ms)
 {
   Identifier id ("string");
   UTL_ScopedName n (&id,
-                    0);
+                    nullptr);
 
-  AST_String *retval = 0;
+  AST_String *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_String (AST_Decl::NT_string,
                               &n,
                               ms),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -890,18 +891,18 @@ AST_Generator::create_wstring (AST_Expression *ms)
                    ? "string"
                    : "wstring");
   UTL_ScopedName n (&id,
-                    0);
+                    nullptr);
   AST_Decl::NodeType nt = sizeof (ACE_CDR::WChar) == 1
                             ? AST_Decl::NT_string
                             : AST_Decl::NT_wstring;
 
-  AST_String *retval = 0;
+  AST_String *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_String (nt,
                               &n,
                               ms,
                               sizeof (ACE_OS::WChar)),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -911,9 +912,9 @@ AST_Generator::create_fixed (AST_Expression *digits,
                              AST_Expression *scale)
 {
   Identifier id ("fixed");
-  UTL_ScopedName name (&id, 0);
-  AST_Fixed *retval = 0;
-  ACE_NEW_RETURN (retval, AST_Fixed (&name, digits, scale), 0);
+  UTL_ScopedName name (&id, nullptr);
+  AST_Fixed *retval = nullptr;
+  ACE_NEW_RETURN (retval, AST_Fixed (&name, digits, scale), nullptr);
   return retval;
 }
 
@@ -923,13 +924,13 @@ AST_Generator::create_typedef (AST_Type *bt,
                                bool is_local,
                                bool is_abstract)
 {
-  AST_Typedef *retval = 0;
+  AST_Typedef *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Typedef (bt,
                                n,
                                is_local,
                                is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -937,10 +938,10 @@ AST_Generator::create_typedef (AST_Type *bt,
 AST_Native *
 AST_Generator::create_native (UTL_ScopedName *n)
 {
-  AST_Native *retval = 0;
+  AST_Native *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Native (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -948,10 +949,10 @@ AST_Generator::create_native (UTL_ScopedName *n)
 AST_Factory *
 AST_Generator::create_factory (UTL_ScopedName *n)
 {
-  AST_Factory *retval = 0;
+  AST_Factory *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Factory (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -959,10 +960,10 @@ AST_Generator::create_factory (UTL_ScopedName *n)
 AST_Finder *
 AST_Generator::create_finder (UTL_ScopedName *n)
 {
-  AST_Finder *retval = 0;
+  AST_Finder *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Finder (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -971,10 +972,10 @@ AST_ValueBox *
 AST_Generator::create_valuebox (UTL_ScopedName *n,
                                 AST_Type *boxed_type)
 {
-  AST_ValueBox *retval = 0;
+  AST_ValueBox *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_ValueBox (n, boxed_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -982,10 +983,10 @@ AST_Generator::create_valuebox (UTL_ScopedName *n,
 AST_PortType *
 AST_Generator::create_porttype (UTL_ScopedName *n)
 {
-  AST_PortType *retval = 0;
+  AST_PortType *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_PortType (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -994,11 +995,11 @@ AST_Provides *
 AST_Generator::create_provides (UTL_ScopedName *n,
                                 AST_Type *provides_type)
 {
-  AST_Provides *retval = 0;
+  AST_Provides *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Provides (n,
                                 provides_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1008,12 +1009,12 @@ AST_Generator::create_uses (UTL_ScopedName *n,
                             AST_Type *uses_type,
                             bool is_multiple)
 {
-  AST_Uses *retval = 0;
+  AST_Uses *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Uses (n,
                             uses_type,
                             is_multiple),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1022,11 +1023,11 @@ AST_Publishes *
 AST_Generator::create_publishes (UTL_ScopedName *n,
                                  AST_Type *publishes_type)
 {
-  AST_Publishes *retval = 0;
+  AST_Publishes *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Publishes (n,
                                  publishes_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1035,11 +1036,11 @@ AST_Emits *
 AST_Generator::create_emits (UTL_ScopedName *n,
                              AST_Type *emits_type)
 {
-  AST_Emits *retval = 0;
+  AST_Emits *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Emits (n,
                              emits_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1047,11 +1048,11 @@ AST_Consumes *
 AST_Generator::create_consumes (UTL_ScopedName *n,
                                 AST_Type *consumes_type)
 {
-  AST_Consumes *retval = 0;
+  AST_Consumes *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Consumes (n,
                                 consumes_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1061,11 +1062,11 @@ AST_Generator::create_extended_port (
   UTL_ScopedName *n,
   AST_PortType *porttype_ref)
 {
-  AST_Extended_Port *retval = 0;
+  AST_Extended_Port *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Extended_Port (n,
                                      porttype_ref),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1075,11 +1076,11 @@ AST_Generator::create_mirror_port (
   UTL_ScopedName *n,
   AST_PortType *porttype_ref)
 {
-  AST_Mirror_Port *retval = 0;
+  AST_Mirror_Port *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Mirror_Port (n,
                                    porttype_ref),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1089,11 +1090,11 @@ AST_Generator::create_connector (
   UTL_ScopedName *n,
   AST_Connector *base_connector)
 {
-  AST_Connector *retval = 0;
+  AST_Connector *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Connector (n,
                                  base_connector),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1103,11 +1104,11 @@ AST_Generator::create_template_module (
   UTL_ScopedName *n,
   FE_Utils::T_PARAMLIST_INFO *template_params)
 {
-  AST_Template_Module *retval = 0;
+  AST_Template_Module *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Template_Module (n,
                                        template_params),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1118,12 +1119,12 @@ AST_Generator::create_template_module_inst (
   AST_Template_Module *ref,
   FE_Utils::T_ARGLIST *template_args)
 {
-  AST_Template_Module_Inst *retval = 0;
+  AST_Template_Module_Inst *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Template_Module_Inst (n,
                                             ref,
                                             template_args),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1134,12 +1135,12 @@ AST_Generator::create_template_module_ref (
   AST_Template_Module *ref,
   UTL_StrList *param_refs)
 {
-  AST_Template_Module_Ref *retval = 0;
+  AST_Template_Module_Ref *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Template_Module_Ref (n,
                                            ref,
                                            param_refs),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1149,12 +1150,41 @@ AST_Generator::create_param_holder (
   UTL_ScopedName *parameter_name,
   FE_Utils::T_Param_Info *info)
 {
-  AST_Param_Holder *retval = 0;
+  AST_Param_Holder *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   AST_Param_Holder (parameter_name,
                                     info),
-                  0);
+                  nullptr);
 
   return retval;
 }
 
+AST_Annotation_Decl *
+AST_Generator::create_annotation_decl (
+  UTL_ScopedName *name)
+{
+  AST_Annotation_Decl *retval = nullptr;
+  ACE_NEW_RETURN (retval, AST_Annotation_Decl (name), nullptr);
+  return retval;
+}
+
+AST_Annotation_Appl *
+AST_Generator::create_annotation_appl (
+  UTL_ScopedName *name,
+  AST_Annotation_Appl::Params *params)
+{
+  AST_Annotation_Appl *retval = nullptr;
+  ACE_NEW_RETURN (retval, AST_Annotation_Appl (name, params), nullptr);
+  return retval;
+}
+
+AST_Annotation_Member *
+AST_Generator::create_annotation_member (
+  AST_Expression::ExprType expr_type,
+  AST_Type *type,
+  UTL_ScopedName *name)
+{
+  AST_Annotation_Member *retval = nullptr;
+  ACE_NEW_RETURN (retval, AST_Annotation_Member (expr_type, type, name), nullptr);
+  return retval;
+}
