@@ -22,12 +22,12 @@ AST_PortType::AST_PortType (UTL_ScopedName *n)
 {
 }
 
-AST_PortType::~AST_PortType (void)
+AST_PortType::~AST_PortType ()
 {
 }
 
 void
-AST_PortType::destroy (void)
+AST_PortType::destroy ()
 {
   this->UTL_Scope::destroy ();
   this->AST_Type::destroy ();
@@ -47,27 +47,17 @@ AST_PortType::ast_accept (ast_visitor *visitor)
 AST_Provides *
 AST_PortType::fe_add_provides (AST_Provides *p)
 {
-  return
-    AST_Provides::narrow_from_decl (
-      this->fe_add_ref_decl (p));
+  return dynamic_cast<AST_Provides*> (this->fe_add_ref_decl (p));
 }
 
 AST_Uses *
 AST_PortType::fe_add_uses (AST_Uses *u)
 {
-  return
-    AST_Uses::narrow_from_decl (
-      this->fe_add_ref_decl (u));
+  return dynamic_cast<AST_Uses*> (this->fe_add_ref_decl (u));
 }
 
 AST_Attribute *
 AST_PortType::fe_add_attribute (AST_Attribute *t)
 {
-  return
-    AST_Attribute::narrow_from_decl (
-      this->fe_add_decl (t));
+  return dynamic_cast<AST_Attribute*> (this->fe_add_decl (t));
 }
-
-IMPL_NARROW_FROM_DECL (AST_PortType)
-IMPL_NARROW_FROM_SCOPE (AST_PortType)
-
