@@ -86,7 +86,7 @@ bool
 AST_illegal_interface_recursion (AST_Decl *t)
 {
   // Can't be 0 since we know we have an interface or valuetype.
-  AST_Decl *d = 0;
+  AST_Decl *d = nullptr;
 
   // If we encounter the argument in an enclosing scope, it's illegal.
   for (UTL_ScopeStackActiveIterator i (idl_global->scopes ());
@@ -114,15 +114,15 @@ AST_illegal_interface_recursion (AST_Decl *t)
 bool
 AST_illegal_recursive_type (AST_Decl *t)
 {
-  if (t == 0)
+  if (t == nullptr)
     {
       return false;
     }
 
   AST_Decl::NodeType nt;
-  AST_Type *ut = AST_Type::narrow_from_decl (t);
+  AST_Type *ut = dynamic_cast<AST_Type*> (t);
 
-  if (ut != 0)
+  if (ut != nullptr)
     {
       ut = ut->unaliased_type ();
       nt = ut->node_type ();
@@ -145,16 +145,16 @@ AST_illegal_recursive_type (AST_Decl *t)
 
   bool check_for_struct = false;
   bool check_for_union = false;
-  AST_Structure  *st1 = 0;
-  AST_Union  *un1 = 0;
+  AST_Structure  *st1 = nullptr;
+  AST_Union  *un1 = nullptr;
 
   // Narrow the type appropriately so comparison will work.
   if (t->node_type () == AST_Decl::NT_struct)
     {
       check_for_struct = true;
-      st1 = AST_Structure::narrow_from_decl (t);
+      st1 = dynamic_cast<AST_Structure*> (t);
 
-      if (st1 == 0)
+      if (st1 == nullptr)
         {
           return false;  // NOT ILLEGAL.
         }
@@ -162,17 +162,17 @@ AST_illegal_recursive_type (AST_Decl *t)
   else if (t->node_type () == AST_Decl::NT_union)
     {
       check_for_union = true;
-      un1 = AST_Union::narrow_from_decl (t);
+      un1 = dynamic_cast<AST_Union*> (t);
 
-      if (un1 == 0)
+      if (un1 == nullptr)
         {
           return false;  // NOT ILLEGAL.
         }
     }
 
-  UTL_Scope  *s = 0;
-  AST_Structure *st2 = 0;
-  AST_Union *un2 = 0;
+  UTL_Scope  *s = nullptr;
+  AST_Structure *st2 = nullptr;
+  AST_Union *un2 = nullptr;
 
   // OK, iterate up the stack.
   for (UTL_ScopeStackActiveIterator i (idl_global->scopes ());
@@ -183,7 +183,7 @@ AST_illegal_recursive_type (AST_Decl *t)
 
       // If we hit a NULL we're done since it means that we're nested inside
       // a sequence, where recursive types may be used.
-      if (s == 0)
+      if (s == nullptr)
         {
           return false;  // NOT ILLEGAL.
         }
@@ -192,9 +192,9 @@ AST_illegal_recursive_type (AST_Decl *t)
       if (s->scope_node_type () == AST_Decl::NT_struct
           && check_for_struct == true)
         {
-          st2 = AST_Structure::narrow_from_scope (s);
+          st2 = dynamic_cast<AST_Structure*> (s);
 
-          if (st2 != 0 && st2 == st1)
+          if (st2 != nullptr && st2 == st1)
             {
               return true;  // ILLEGAL RECURSIVE TYPE USE.
             }
@@ -202,9 +202,9 @@ AST_illegal_recursive_type (AST_Decl *t)
       else if (s->scope_node_type () == AST_Decl::NT_union
                && check_for_union == true)
         {
-          un2 = AST_Union::narrow_from_scope (s);
+          un2 = dynamic_cast<AST_Union*> (s);
 
-          if (un2 != 0 && un2 == un1)
+          if (un2 != nullptr && un2 == un1)
             {
               return true;  // ILLEGAL RECURSIVE TYPE USE.
             }
