@@ -52,24 +52,20 @@ be_array::be_array (UTL_ScopedName *n,
     }
 }
 
-be_array::~be_array (void)
-{
-}
-
 int
-be_array::create_name (void)
+be_array::create_name ()
 {
   char namebuf [NAMEBUFSIZE];
   unsigned long i;
-  UTL_ScopedName *n = 0;
-  be_decl *scope = 0;
+  UTL_ScopedName *n = nullptr;
+  be_decl *scope = nullptr;
 
   ACE_OS::memset (namebuf,
                   '\0',
                   NAMEBUFSIZE);
   // Retrieve the base type.
   // The name always starts this way.
-  be_type *bt = be_type::narrow_from_decl (this->base_type ());
+  be_type *bt = dynamic_cast<be_type*> (this->base_type ());
 
   if (!bt)
     {
@@ -90,7 +86,7 @@ be_array::create_name (void)
       AST_Expression *expr = this->dims ()[i];
 
       // Dimension value.
-      if ((expr == 0) || ((expr != 0) && (expr->ev () == 0)))
+      if ((expr == nullptr) || ((expr != nullptr) && (expr->ev () == nullptr)))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_array::"
@@ -116,22 +112,22 @@ be_array::create_name (void)
     }
 
   // Now see if we have a fully scoped name and if so, generate one.
-  scope = be_scope::narrow_from_scope (this->defined_in ())->decl ();
+  scope = dynamic_cast<be_scope*> (this->defined_in ())->decl ();
 
   if (scope)
     {
       // Make a copy of the enclosing scope's  name.
       n = (UTL_ScopedName *)scope->name ()->copy ();
 
-      Identifier *id = 0;
+      Identifier *id = nullptr;
       ACE_NEW_RETURN (id,
                       Identifier (ACE_OS::strdup (namebuf)),
                       -1);
 
-      UTL_ScopedName *sn = 0;
+      UTL_ScopedName *sn = nullptr;
       ACE_NEW_RETURN (sn,
                       UTL_ScopedName (id,
-                                      0),
+                                      nullptr),
                       -1);
 
       // Add our local name as the last component.
@@ -151,43 +147,43 @@ be_array::create_name (void)
 
 // Overriden method.
 void
-be_array::compute_tc_name (void)
+be_array::compute_tc_name ()
 {
   // Array TypeCodes can only be accessed through an alias
   // TypeCode.  Generate a TypeCode name that is meant for internal
   // use alone.
 
-  Identifier * tao_id = 0;
+  Identifier * tao_id = nullptr;
   ACE_NEW (tao_id,
            Identifier ("TAO"));
 
   ACE_NEW (this->tc_name_,
            UTL_ScopedName (tao_id,
-                           0));
+                           nullptr));
 
   ACE_CString local_tc_name =
     ACE_CString ("tc_")
     + ACE_CString (this->flat_name ());
 
-  Identifier * typecode_scope = 0;
+  Identifier * typecode_scope = nullptr;
   ACE_NEW (typecode_scope,
            Identifier ("TypeCode"));
 
-  UTL_ScopedName * tc_scope_conc_name = 0;
+  UTL_ScopedName * tc_scope_conc_name = nullptr;
   ACE_NEW (tc_scope_conc_name,
            UTL_ScopedName (typecode_scope,
-                           0));
+                           nullptr));
 
   this->tc_name_->nconc (tc_scope_conc_name);
 
-  Identifier * id = 0;
+  Identifier * id = nullptr;
   ACE_NEW (id,
            Identifier (local_tc_name.c_str ()));
 
-  UTL_ScopedName * conc_name = 0;
+  UTL_ScopedName * conc_name = nullptr;
   ACE_NEW (conc_name,
            UTL_ScopedName (id,
-                           0));
+                           nullptr));
 
   this->tc_name_->nconc (conc_name);
 }
@@ -208,7 +204,7 @@ be_array::gen_dimensions (TAO_OutStream *os,
       AST_Expression *expr = this->dims ()[i];
 
       // Dimension value.
-      if ((expr == 0) || ((expr != 0) && (expr->ev () == 0)))
+      if ((expr == nullptr) || ((expr != nullptr) && (expr->ev () == nullptr)))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_array::"
@@ -239,7 +235,7 @@ void
 be_array::gen_ostream_operator (TAO_OutStream *os,
                                 bool use_underscore)
 {
-  be_scope* scope = be_scope::narrow_from_scope (this->defined_in ());
+  be_scope* scope = dynamic_cast<be_scope*> (this->defined_in ());
   be_decl* parent = scope->decl ();
   ACE_CString arg_name (ACE_CString (parent->full_name ())
                         + "::"
@@ -288,7 +284,7 @@ be_array::gen_ostream_operator (TAO_OutStream *os,
       instance_name += "]";
     }
 
-  be_type *bt = be_type::narrow_from_decl (this->base_type ());
+  be_type *bt = dynamic_cast<be_type*> (this->base_type ());
   bt->gen_member_ostream_operator (os,
                                    instance_name.c_str (),
                                    use_underscore,
@@ -314,7 +310,7 @@ be_array::gen_member_ostream_operator (TAO_OutStream *os,
                                        bool use_underscore,
                                        bool accessor)
 {
-  be_scope* scope = be_scope::narrow_from_scope (this->defined_in ());
+  be_scope* scope = dynamic_cast<be_scope*> (this->defined_in ());
   be_decl* parent = scope->decl ();
   ACE_CString decl_name (ACE_CString (parent->full_name ())
                          + "::"
@@ -341,12 +337,8 @@ be_array::accept (be_visitor *visitor)
 }
 
 void
-be_array::destroy (void)
+be_array::destroy ()
 {
   this->be_type::destroy ();
   this->AST_Array::destroy ();
 }
-
-
-
-IMPL_NARROW_FROM_DECL (be_array)
