@@ -33,12 +33,8 @@ be_constant::accept (be_visitor *visitor)
 }
 
 void
-be_constant::destroy (void)
+be_constant::destroy ()
 {
   this->be_decl::destroy ();
   this->AST_Constant::destroy ();
 }
-
-
-
-IMPL_NARROW_FROM_DECL (be_constant)
