@@ -20,15 +20,15 @@ be_emits::be_emits (UTL_ScopedName *n,
 {
 }
 
-be_emits::~be_emits (void)
+be_emits::~be_emits ()
 {
 }
 
 be_eventtype *
-be_emits::emits_type (void) const
+be_emits::emits_type () const
 {
   return
-    be_eventtype::narrow_from_decl (
+    dynamic_cast<be_eventtype*> (
       this->AST_Emits::emits_type ());
 }
 
@@ -39,10 +39,8 @@ be_emits::accept (be_visitor *visitor)
 }
 
 void
-be_emits::destroy (void)
+be_emits::destroy ()
 {
   this->AST_Emits::destroy ();
   this->be_field::destroy ();
 }
-
-IMPL_NARROW_FROM_DECL (be_emits)
