@@ -121,10 +121,10 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 AST_Root *
 be_generator::create_root (UTL_ScopedName *n)
 {
-  be_root *retval = 0;
+  be_root *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_root (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -133,11 +133,11 @@ AST_PredefinedType *
 be_generator::create_predefined_type (AST_PredefinedType::PredefinedType t,
                                       UTL_ScopedName *n)
 {
-  be_predefined_type *retval = 0;
+  be_predefined_type *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_predefined_type (t,
                                       n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -146,7 +146,7 @@ AST_Module *
 be_generator::create_module (UTL_Scope *s,
                              UTL_ScopedName *n)
 {
-  AST_Module *retval = 0;
+  AST_Module *retval = nullptr;
 
   // Check for another module of the same name in this scope.
   for (UTL_ScopeActiveIterator iter (s, UTL_Scope::IK_decls);
@@ -155,13 +155,13 @@ be_generator::create_module (UTL_Scope *s,
     {
       // Can't just check node type here, since it could be a
       // template module or template module instantiation.
-      AST_Module *m = AST_Module::narrow_from_decl (iter.item ());
+      AST_Module *m = dynamic_cast<AST_Module*> (iter.item ());
 
       if (m && m->local_name ()->compare (n->last_component ()))
         {
           // Create this new module with referance to the
           // "first" previous module found in scope.
-          ACE_NEW_RETURN (retval, be_module (n, m), 0);
+          ACE_NEW_RETURN (retval, be_module (n, m), nullptr);
           retval->prefix (const_cast<char *> (m->prefix ()));
           return retval;
         }
@@ -172,7 +172,7 @@ be_generator::create_module (UTL_Scope *s,
   // is itself a module, and has been previously opened, any
   // of the previous openings may contain a previous opening
   // of the module we're creating.
-  AST_Module *prev_module = AST_Module::narrow_from_scope (s);
+  AST_Module *prev_module = dynamic_cast<AST_Module*> (s);
   if (prev_module)
     {
       while (!!(prev_module = prev_module->previous_opening ()))
@@ -181,12 +181,12 @@ be_generator::create_module (UTL_Scope *s,
                !iter.is_done ();
                iter.next ())
             {
-              AST_Module *m = AST_Module::narrow_from_decl (iter.item ());
+              AST_Module *m = dynamic_cast<AST_Module*> (iter.item ());
               if (m && m->local_name ()->compare (n->last_component ()))
                 {
                   // Create this new module with referance to the
                   // "first" previous module found in scope.
-                  ACE_NEW_RETURN (retval, be_module (n, m), 0);
+                  ACE_NEW_RETURN (retval, be_module (n, m), nullptr);
                   return retval;
                 }
             }
@@ -194,7 +194,7 @@ be_generator::create_module (UTL_Scope *s,
     }
 
   // There is no previous module to be found
-  ACE_NEW_RETURN (retval, be_module (n), 0);
+  ACE_NEW_RETURN (retval, be_module (n), nullptr);
   return retval;
 }
 
@@ -207,7 +207,7 @@ be_generator::create_interface (UTL_ScopedName *n,
                                 bool l,
                                 bool a)
 {
-  be_interface *retval = 0;
+  be_interface *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_interface (n,
                                 ih,
@@ -216,7 +216,7 @@ be_generator::create_interface (UTL_ScopedName *n,
                                 nih_flat,
                                 l,
                                 a),
-                  0);
+                  nullptr);
 
   /// Trigger this interation over the included pragmas when the
   /// first local interface is seen in the main file. In an
@@ -236,18 +236,18 @@ be_generator::create_interface_fwd (UTL_ScopedName *n,
                                     bool is_abstract)
 {
   AST_Interface *full_defn = this->create_interface (n,
-                                                     0,
+                                                     nullptr,
                                                      -1,
-                                                     0,
+                                                     nullptr,
                                                      0,
                                                      is_local,
                                                      is_abstract);
 
-  be_interface_fwd *retval = 0;
+  be_interface_fwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_interface_fwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -257,11 +257,11 @@ AST_ValueBox *
 be_generator::create_valuebox (UTL_ScopedName *n,
                                AST_Type *boxed_type)
 {
-  be_valuebox *retval = 0;
+  be_valuebox *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_valuebox (boxed_type,
                                n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -280,7 +280,7 @@ be_generator::create_valuetype (UTL_ScopedName *n,
                                 bool is_truncatable,
                                 bool is_custom)
 {
-  be_valuetype *retval = 0;
+  be_valuetype *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_valuetype (n,
                                 inherits,
@@ -294,7 +294,7 @@ be_generator::create_valuetype (UTL_ScopedName *n,
                                 is_abstract,
                                 is_truncatable,
                                 is_custom),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -304,23 +304,23 @@ be_generator::create_valuetype_fwd (UTL_ScopedName *n,
                                     bool is_abstract)
 {
   AST_ValueType *full_defn = this->create_valuetype (n,
-                                                     0,
+                                                     nullptr,
                                                      -1,
+                                                     nullptr,
+                                                     nullptr,
                                                      0,
+                                                     nullptr,
                                                      0,
-                                                     0,
-                                                     0,
-                                                     0,
-                                                     0,
+                                                     nullptr,
                                                      is_abstract,
                                                      false,
                                                      false);
 
-  be_valuetype_fwd *retval = 0;
+  be_valuetype_fwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_valuetype_fwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -340,7 +340,7 @@ be_generator::create_eventtype (UTL_ScopedName *n,
                                 bool is_truncatable,
                                 bool is_custom)
 {
-  be_eventtype *retval = 0;
+  be_eventtype *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_eventtype (n,
                                 inherits,
@@ -354,7 +354,7 @@ be_generator::create_eventtype (UTL_ScopedName *n,
                                 is_abstract,
                                 is_truncatable,
                                 is_custom),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -364,23 +364,23 @@ be_generator::create_eventtype_fwd (UTL_ScopedName *n,
                                     bool is_abstract)
 {
   AST_EventType *full_defn = this->create_eventtype (n,
-                                                     0,
+                                                     nullptr,
                                                      -1,
+                                                     nullptr,
+                                                     nullptr,
                                                      0,
+                                                     nullptr,
                                                      0,
-                                                     0,
-                                                     0,
-                                                     0,
-                                                     0,
+                                                     nullptr,
                                                      is_abstract,
                                                      false,
                                                      false);
 
-  be_eventtype_fwd *retval = 0;
+  be_eventtype_fwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_eventtype_fwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -394,7 +394,7 @@ be_generator::create_component (UTL_ScopedName *n,
                                 AST_Interface **supports_flat,
                                 long n_supports_flat)
 {
-  be_component *retval = 0;
+  be_component *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_component (n,
                                 base_component,
@@ -402,7 +402,7 @@ be_generator::create_component (UTL_ScopedName *n,
                                 n_supports,
                                 supports_flat,
                                 n_supports_flat),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -411,17 +411,17 @@ AST_ComponentFwd *
 be_generator::create_component_fwd (UTL_ScopedName *n)
 {
   AST_Component *full_defn = this->create_component (n,
-                                                     0,
-                                                     0,
+                                                     nullptr,
+                                                     nullptr,
                                                      -1,
-                                                     0,
+                                                     nullptr,
                                                      0);
 
-  be_component_fwd *retval = 0;
+  be_component_fwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_component_fwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -437,7 +437,7 @@ be_generator::create_home (UTL_ScopedName *n,
                            AST_Interface **supports_flat,
                            long n_supports_flat)
 {
-  be_home *retval = 0;
+  be_home *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_home (n,
                            base_home,
@@ -447,7 +447,7 @@ be_generator::create_home (UTL_ScopedName *n,
                            n_supports,
                            supports_flat,
                            n_supports_flat),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -457,12 +457,12 @@ be_generator::create_exception (UTL_ScopedName *n,
                                 bool is_local,
                                 bool is_abstract)
 {
-  be_exception *retval = 0;
+  be_exception *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_exception (n,
                                 is_local,
                                 is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -472,12 +472,12 @@ be_generator::create_structure (UTL_ScopedName *n,
                                 bool is_local,
                                 bool is_abstract)
 {
-  be_structure *retval = 0;
+  be_structure *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_structure (n,
                                 is_local,
                                 is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -489,11 +489,11 @@ be_generator::create_structure_fwd (UTL_ScopedName *n)
   AST_Structure *full_defn = this->create_structure (n,
                                                      false,
                                                      false);
-  be_structure_fwd *retval = 0;
+  be_structure_fwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_structure_fwd (full_defn,
                                     n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -504,12 +504,12 @@ be_generator::create_enum (UTL_ScopedName *n,
                            bool is_local,
                            bool is_abstract)
 {
-  be_enum *retval = 0;
+  be_enum *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_enum (n,
                            is_local,
                            is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -521,14 +521,14 @@ be_generator::create_operation (AST_Type *rt,
                                 bool is_local,
                                 bool is_abstract)
 {
-  be_operation *retval = 0;
+  be_operation *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_operation (rt,
                                 fl,
                                 n,
                                 is_local,
                                 is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -538,12 +538,12 @@ be_generator::create_field (AST_Type *ft,
                             UTL_ScopedName *n,
                             AST_Field::Visibility vis)
 {
-  be_field *retval = 0;
+  be_field *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_field (ft,
                             n,
                             vis),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -553,12 +553,12 @@ be_generator::create_argument (AST_Argument::Direction d,
                                AST_Type *ft,
                                UTL_ScopedName *n)
 {
-  be_argument *retval = 0;
+  be_argument *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_argument (d,
                                ft,
                                n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -570,14 +570,14 @@ be_generator::create_attribute (bool ro,
                                 bool is_local,
                                 bool is_abstract)
 {
-  be_attribute *retval = 0;
+  be_attribute *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_attribute (ro,
                                 ft,
                                 n,
                                 is_local,
                                 is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -588,13 +588,13 @@ be_generator::create_union (AST_ConcreteType *dt,
                             bool is_local,
                             bool is_abstract)
 {
-  be_union *retval = 0;
+  be_union *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_union (dt,
                             n,
                             is_local,
                             is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -602,15 +602,15 @@ be_generator::create_union (AST_ConcreteType *dt,
 AST_UnionFwd *
 be_generator::create_union_fwd (UTL_ScopedName *n)
 {
-  AST_Union *full_defn = this->create_union (0,
+  AST_Union *full_defn = this->create_union (nullptr,
                                              n,
                                              false,
                                              false);
-  be_union_fwd *retval = 0;
+  be_union_fwd *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_union_fwd (full_defn,
                                 n),
-                  0);
+                  nullptr);
 
   full_defn->fwd_decl (retval);
   return retval;
@@ -621,12 +621,12 @@ be_generator::create_union_branch (UTL_LabelList *ll,
                                    AST_Type *ft,
                                    UTL_ScopedName *n)
 {
-  be_union_branch *retval = 0;
+  be_union_branch *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_union_branch (ll,
                                    ft,
                                    n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -635,11 +635,11 @@ AST_UnionLabel *
 be_generator::create_union_label (AST_UnionLabel::UnionLabel ul,
                                   AST_Expression *lv)
 {
-  be_union_label *retval = 0;
+  be_union_label *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_union_label (ul,
                                   lv),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -649,12 +649,12 @@ be_generator::create_constant (AST_Expression::ExprType et,
                                AST_Expression *ev,
                                UTL_ScopedName *n)
 {
-  be_constant *retval = 0;
+  be_constant *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_constant (et,
                                ev,
                                n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -662,10 +662,10 @@ be_generator::create_constant (AST_Expression::ExprType et,
 AST_Expression *
 be_generator::create_expr (UTL_ScopedName *n)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -674,11 +674,11 @@ AST_Expression *
 be_generator::create_expr (AST_Expression *b,
                            AST_Expression::ExprType t)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (b,
                                  t),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -688,12 +688,12 @@ be_generator::create_expr (AST_Expression::ExprComb c,
                            AST_Expression *v1,
                            AST_Expression *v2)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (c,
                                  v1,
                                  v2),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -701,10 +701,10 @@ be_generator::create_expr (AST_Expression::ExprComb c,
 AST_Expression *
 be_generator::create_expr (ACE_CDR::Long l)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (l),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -712,10 +712,10 @@ be_generator::create_expr (ACE_CDR::Long l)
 AST_Expression *
 be_generator::create_expr (ACE_CDR::LongLong l)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (l),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -723,10 +723,10 @@ be_generator::create_expr (ACE_CDR::LongLong l)
 AST_Expression *
 be_generator::create_expr (ACE_CDR::Boolean b)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (b),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -734,10 +734,10 @@ be_generator::create_expr (ACE_CDR::Boolean b)
 AST_Expression *
 be_generator::create_expr (ACE_CDR::ULong l)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (l),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -745,10 +745,10 @@ be_generator::create_expr (ACE_CDR::ULong l)
 AST_Expression *
 be_generator::create_expr (ACE_CDR::ULongLong l)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (l),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -757,10 +757,10 @@ AST_Expression *
 be_generator::create_expr (ACE_CDR::ULong l,
                            AST_Expression::ExprType t)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (l, t),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -768,10 +768,10 @@ be_generator::create_expr (ACE_CDR::ULong l,
 AST_Expression *
 be_generator::create_expr (UTL_String *s)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (s),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -779,10 +779,10 @@ be_generator::create_expr (UTL_String *s)
 AST_Expression *
 be_generator::create_expr (ACE_CDR::Char c)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (c),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -790,10 +790,10 @@ be_generator::create_expr (ACE_CDR::Char c)
 AST_Expression *
 be_generator::create_expr (ACE_OutputCDR::from_wchar wc)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (wc),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -801,10 +801,10 @@ be_generator::create_expr (ACE_OutputCDR::from_wchar wc)
 AST_Expression *
 be_generator::create_expr (char *s)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (s),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -812,10 +812,10 @@ be_generator::create_expr (char *s)
 AST_Expression *
 be_generator::create_expr (ACE_CDR::Double d)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (d),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -823,10 +823,10 @@ be_generator::create_expr (ACE_CDR::Double d)
 AST_Expression *
 be_generator::create_expr (const ACE_CDR::Fixed &f)
 {
-  be_expression *retval = 0;
+  be_expression *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_expression (f),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -835,11 +835,11 @@ AST_EnumVal *
 be_generator::create_enum_val (ACE_CDR::ULong v,
                                UTL_ScopedName *n)
 {
-  be_enum_val *retval = 0;
+  be_enum_val *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_enum_val (v,
                                n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -851,14 +851,14 @@ be_generator::create_array (UTL_ScopedName *n,
                             bool is_local,
                             bool is_abstract)
 {
-  be_array *retval = 0;
+  be_array *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_array (n,
                             ndims,
                             dims,
                             is_local,
                             is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -870,14 +870,14 @@ be_generator::create_sequence (AST_Expression *v,
                                bool is_local,
                                bool is_abstract)
 {
-  be_sequence *retval = 0;
+  be_sequence *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_sequence (v,
                                bt,
                                n,
                                is_local,
                                is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -887,15 +887,15 @@ be_generator::create_string (AST_Expression *v)
 {
   Identifier id ("string");
   UTL_ScopedName n (&id,
-                    0);
+                    nullptr);
 
-  be_string *retval = 0;
+  be_string *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_string (AST_Decl::NT_string,
                              &n,
                              v,
                              1),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -907,18 +907,18 @@ be_generator::create_wstring (AST_Expression *v)
                    ? "string"
                    : "wstring");
   UTL_ScopedName n (&id,
-                    0);
+                    nullptr);
   AST_Decl::NodeType nt = sizeof (ACE_CDR::WChar) == 1
                             ? AST_Decl::NT_string
                             : AST_Decl::NT_wstring;
 
-  be_string *retval = 0;
+  be_string *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_string (nt,
                              &n,
                              v,
                              sizeof (ACE_CDR::WChar)),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -928,9 +928,9 @@ be_generator::create_fixed (AST_Expression *digits,
                             AST_Expression *scale)
 {
   Identifier id ("fixed");
-  UTL_ScopedName name (&id, 0);
-  AST_Fixed *retval = 0;
-  ACE_NEW_RETURN (retval, be_fixed (&name, digits, scale), 0);
+  UTL_ScopedName name (&id, nullptr);
+  AST_Fixed *retval = nullptr;
+  ACE_NEW_RETURN (retval, be_fixed (&name, digits, scale), nullptr);
   return retval;
 }
 
@@ -940,13 +940,13 @@ be_generator::create_typedef (AST_Type *bt,
                               bool is_local,
                               bool is_abstract)
 {
-  be_typedef *retval = 0;
+  be_typedef *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_typedef (bt,
                               n,
                               is_local,
                               is_abstract),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -954,10 +954,10 @@ be_generator::create_typedef (AST_Type *bt,
 AST_Native *
 be_generator::create_native (UTL_ScopedName *n)
 {
-  be_native *retval = 0;
+  be_native *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_native (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -965,10 +965,10 @@ be_generator::create_native (UTL_ScopedName *n)
 AST_Factory *
 be_generator::create_factory (UTL_ScopedName *n)
 {
-  be_factory *retval = 0;
+  be_factory *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_factory (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -976,10 +976,10 @@ be_generator::create_factory (UTL_ScopedName *n)
 AST_Finder *
 be_generator::create_finder (UTL_ScopedName *n)
 {
-  be_finder *retval = 0;
+  be_finder *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_finder (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -987,10 +987,10 @@ be_generator::create_finder (UTL_ScopedName *n)
 AST_PortType *
 be_generator::create_porttype (UTL_ScopedName *n)
 {
-  be_porttype *retval = 0;
+  be_porttype *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_porttype (n),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -999,11 +999,11 @@ AST_Provides *
 be_generator::create_provides (UTL_ScopedName *n,
                                AST_Type *provides_type)
 {
-  be_provides *retval = 0;
+  be_provides *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_provides (n,
                                provides_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1013,12 +1013,12 @@ be_generator::create_uses (UTL_ScopedName *n,
                            AST_Type *uses_type,
                            bool is_multiple)
 {
-  be_uses *retval = 0;
+  be_uses *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_uses (n,
                            uses_type,
                            is_multiple),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1027,11 +1027,11 @@ AST_Publishes *
 be_generator::create_publishes (UTL_ScopedName *n,
                                 AST_Type *publishes_type)
 {
-  be_publishes *retval = 0;
+  be_publishes *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_publishes (n,
                                 publishes_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1040,11 +1040,11 @@ AST_Emits *
 be_generator::create_emits (UTL_ScopedName *n,
                             AST_Type *emits_type)
 {
-  be_emits *retval = 0;
+  be_emits *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_emits (n,
                             emits_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1052,11 +1052,11 @@ AST_Consumes *
 be_generator::create_consumes (UTL_ScopedName *n,
                                AST_Type *consumes_type)
 {
-  be_consumes *retval = 0;
+  be_consumes *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_consumes (n,
                                consumes_type),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1066,11 +1066,11 @@ be_generator::create_extended_port (
   UTL_ScopedName *n,
   AST_PortType *porttype_ref)
 {
-  be_extended_port *retval = 0;
+  be_extended_port *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_extended_port (n,
                                     porttype_ref),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1080,11 +1080,11 @@ be_generator::create_mirror_port (
   UTL_ScopedName *n,
   AST_PortType *porttype_ref)
 {
-  be_mirror_port *retval = 0;
+  be_mirror_port *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_mirror_port (n,
                                   porttype_ref),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1094,11 +1094,11 @@ be_generator::create_connector (
   UTL_ScopedName *n,
   AST_Connector *base_connector)
 {
-  be_connector *retval = 0;
+  be_connector *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_connector (n,
                                 base_connector),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1108,11 +1108,11 @@ be_generator::create_template_module (
   UTL_ScopedName *n,
   FE_Utils::T_PARAMLIST_INFO *template_params)
 {
-  be_template_module *retval = 0;
+  be_template_module *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_template_module (n,
                                       template_params),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1123,12 +1123,12 @@ be_generator::create_template_module_inst (
   AST_Template_Module *ref,
   FE_Utils::T_ARGLIST *template_args)
 {
-  be_template_module_inst *retval = 0;
+  be_template_module_inst *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_template_module_inst (n,
                                            ref,
                                            template_args),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1139,12 +1139,12 @@ be_generator::create_template_module_ref (
   AST_Template_Module *ref,
   UTL_StrList *param_refs)
 {
-  be_template_module_ref *retval = 0;
+  be_template_module_ref *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_template_module_ref (n,
                                           ref,
                                           param_refs),
-                  0);
+                  nullptr);
 
   return retval;
 }
@@ -1154,11 +1154,11 @@ be_generator::create_param_holder (
   UTL_ScopedName *parameter_name,
   FE_Utils::T_Param_Info *info)
 {
-  be_param_holder *retval = 0;
+  be_param_holder *retval = nullptr;
   ACE_NEW_RETURN (retval,
                   be_param_holder (parameter_name,
                                    info),
-                  0);
+                  nullptr);
 
   return retval;
 }
