@@ -20,15 +20,15 @@ be_publishes::be_publishes (UTL_ScopedName *n,
 {
 }
 
-be_publishes::~be_publishes (void)
+be_publishes::~be_publishes ()
 {
 }
 
 be_eventtype *
-be_publishes::publishes_type (void) const
+be_publishes::publishes_type () const
 {
   return
-    be_eventtype::narrow_from_decl (
+    dynamic_cast<be_eventtype*> (
       this->AST_Publishes::publishes_type ());
 }
 
@@ -39,10 +39,8 @@ be_publishes::accept (be_visitor *visitor)
 }
 
 void
-be_publishes::destroy (void)
+be_publishes::destroy ()
 {
   this->AST_Publishes::destroy ();
   this->be_field::destroy ();
 }
-
-IMPL_NARROW_FROM_DECL (be_publishes)
