@@ -55,7 +55,7 @@ be_sequence::be_sequence (AST_Expression *v,
     be_type (AST_Decl::NT_sequence,
              n),
     mt_ (be_sequence::MNG_UNKNOWN),
-    field_node_ (0)
+    field_node_ (nullptr)
 {
   // Always the case.
   this->has_constructor (true);
@@ -95,22 +95,10 @@ be_sequence::be_sequence (AST_Expression *v,
         break;
     }
 
-  AST_Decl::NodeType nt = t->node_type ();
-  AST_Typedef *td = 0;
-  AST_Type *pbt = 0;
-
-  if (nt == AST_Decl::NT_typedef)
+  AST_Type *const base_type = primitive_base_type ();
+  if (base_type && base_type->node_type () == AST_Decl::NT_pre_defined)
     {
-      td = AST_Typedef::narrow_from_decl (t);
-      pbt = td->primitive_base_type ();
-      nt = pbt->node_type ();
-    }
-
-  if (nt == AST_Decl::NT_pre_defined)
-    {
-      AST_PredefinedType *pdt =
-        AST_PredefinedType::narrow_from_decl (pbt ? pbt : t);
-
+      AST_PredefinedType *pdt = dynamic_cast<AST_PredefinedType*> (base_type);
       switch (pdt->pt ())
         {
           case AST_PredefinedType::PT_octet:
@@ -123,19 +111,32 @@ be_sequence::be_sequence (AST_Expression *v,
 }
 
 be_type *
-be_sequence::base_type (void) const
+be_sequence::base_type () const
 {
   return
-    be_type::narrow_from_decl (
+    dynamic_cast<be_type*> (
       this->AST_Sequence::base_type ());
 }
 
+be_type *
+be_sequence::primitive_base_type () const
+{
+  be_type *type_node = base_type ();
+  if (type_node && type_node->node_type () == AST_Decl::NT_typedef)
+    {
+      be_typedef *const typedef_node = dynamic_cast<be_typedef *> (type_node);
+      if (!typedef_node) return nullptr;
+      type_node = typedef_node->primitive_base_type ();
+    }
+  return type_node;
+}
+
 // Helper to create_name.
 char *
-be_sequence::gen_name (void)
+be_sequence::gen_name ()
 {
   char namebuf [NAMEBUFSIZE];
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Reset the buffer.
   ACE_OS::memset (namebuf,
@@ -143,9 +144,9 @@ be_sequence::gen_name (void)
                   NAMEBUFSIZE);
 
   // Retrieve the base type.
-  bt = be_type::narrow_from_decl (this->base_type ());
+  bt = dynamic_cast<be_type*> (this->base_type ());
 
-  if (bt == 0)
+  if (bt == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_sequence::"
@@ -161,9 +162,9 @@ be_sequence::gen_name (void)
   if (bt->node_type () == AST_Decl::NT_sequence)
     {
       // Our base type is an anonymous sequence.
-      be_sequence *seq = be_sequence::narrow_from_decl (bt);
+      be_sequence *seq = dynamic_cast<be_sequence*> (bt);
 
-      if (seq == 0)
+      if (seq == nullptr)
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_sequence::"
@@ -215,11 +216,11 @@ be_sequence::gen_name (void)
 int
 be_sequence::create_name (be_typedef *node)
 {
-  static char *namebuf = 0;
-  UTL_ScopedName *n = 0;
+  static char *namebuf = nullptr;
+  UTL_ScopedName *n = nullptr;
 
   // Scope in which we are defined.
-  be_decl *scope = 0;
+  be_decl *scope = nullptr;
 
   // If there is a typedef node, we use its name as our name.
   if (node)
@@ -236,22 +237,22 @@ be_sequence::create_name (be_typedef *node)
       // Now see if we have a fully scoped name and if so, generate one.
       UTL_Scope *us = this->defined_in ();
 
-      scope = be_scope::narrow_from_scope (us)->decl ();
+      scope = dynamic_cast<be_scope*> (us)->decl ();
 
-      if (scope != 0)
+      if (scope != nullptr)
         {
           // Make a copy of the enclosing scope's name.
           n = (UTL_ScopedName *) scope->name ()->copy ();
 
-          Identifier *id = 0;
+          Identifier *id = nullptr;
           ACE_NEW_RETURN (id,
                           Identifier (namebuf),
                           -1);
 
-          UTL_ScopedName *conc_name = 0;
+          UTL_ScopedName *conc_name = nullptr;
           ACE_NEW_RETURN (conc_name,
                           UTL_ScopedName (id,
-                                          0),
+                                          nullptr),
                           -1);
 
           // Add our local name as the last component.
@@ -275,36 +276,21 @@ be_sequence::create_name (be_typedef *node)
 
 // Does this sequence have a managed type sequence element?
 be_sequence::MANAGED_TYPE
-be_sequence::managed_type (void)
+be_sequence::managed_type ()
 {
   if (this->mt_ == be_sequence::MNG_UNKNOWN) // Not calculated yet.
     {
       // Base types.
-      be_type *bt = 0;
-      be_type *prim_type = 0;
-
-      bt = be_type::narrow_from_decl (this->base_type ());
-
-      if (!bt)
+      be_type *const base_type = primitive_base_type ();
+      if (!base_type)
         ACE_ERROR_RETURN ((LM_ERROR,
                            "TAO_IDL (%N:%l) "
-                           "be_type::narrow_from_decl "
+                           "dynamic_cast<be_type*> "
                            "failed\n"),
                           be_sequence::MNG_UNKNOWN);
 
-      if (bt->node_type () == AST_Decl::NT_typedef)
-        {
-          // Get the primitive base type of this typedef node.
-          be_typedef *t = be_typedef::narrow_from_decl (bt);
-          prim_type = t->primitive_base_type ();
-        }
-      else
-        {
-          prim_type = bt;
-        }
-
       // Determine if we need a managed type and which one.
-      switch (prim_type->node_type ())
+      switch (base_type->node_type ())
         {
           case AST_Decl::NT_interface:
           case AST_Decl::NT_interface_fwd:
@@ -329,7 +315,7 @@ be_sequence::managed_type (void)
           case AST_Decl::NT_pre_defined:
             {
               be_predefined_type * const bpd =
-                be_predefined_type::narrow_from_decl (prim_type);
+                dynamic_cast<be_predefined_type*> (base_type);
 
               AST_PredefinedType::PredefinedType pt = bpd->pt ();
 
@@ -361,9 +347,9 @@ be_sequence::managed_type (void)
 AST_Sequence *
 be_sequence::fe_add_sequence (AST_Sequence *t)
 {
-  if (t == 0)
+  if (t == nullptr)
     {
-      return 0;
+      return nullptr;
     }
 
   this->add_to_local_types (t);
@@ -372,7 +358,7 @@ be_sequence::fe_add_sequence (AST_Sequence *t)
 
 // Overridden method
 be_decl *
-be_sequence::decl (void)
+be_sequence::decl ()
 {
   return this;
 }
@@ -426,10 +412,8 @@ be_sequence::instance_name ()
                   '\0',
                   NAMEBUFSIZE);
 
-  be_type *bt = 0;
-  bt = be_type::narrow_from_decl (this->base_type ());
-
-  if (bt == 0)
+  be_type *const prim_type = primitive_base_type ();
+  if (!prim_type)
     {
       ACE_ERROR ((LM_ERROR,
                   "(%N:%l) be_visitor_sequence_ch::"
@@ -439,18 +423,6 @@ be_sequence::instance_name ()
       return namebuf;
     }
 
-  // Generate the class name.
-
-  // The base type after removing all the aliases.
-  be_type  *prim_type = bt;
-
-  if (bt->node_type () == AST_Decl::NT_typedef)
-    {
-      // Get the primitive base type of this typedef node.
-      be_typedef *t = be_typedef::narrow_from_decl (bt);
-      prim_type = t->primitive_base_type ();
-    }
-
   // Generate the appropriate sequence type.
   switch (this->managed_type ())
     {
@@ -523,9 +495,9 @@ be_sequence::instance_name ()
           // TAO provides extensions for octet sequences, first find out
           // if the base type is an octet (or an alias for octet)
           be_predefined_type *predef =
-            be_predefined_type::narrow_from_decl (prim_type);
+            dynamic_cast<be_predefined_type*> (prim_type);
 
-          if (predef != 0
+          if (predef != nullptr
               && predef->pt() == AST_PredefinedType::PT_octet)
             {
               ACE_OS::sprintf (namebuf,
@@ -558,7 +530,7 @@ be_sequence::gen_base_class_name (TAO_OutStream *os,
                                   const char * linebreak,
                                   AST_Decl *ctx_scope)
 {
-  be_type *elem = be_type::narrow_from_decl (this->base_type ());
+  be_type *elem = dynamic_cast<be_type*> (this->base_type ());
   /*
   if (be_global->alt_mapping () && this->unbounded ())
     {
@@ -621,22 +593,19 @@ be_sequence::gen_base_class_name (TAO_OutStream *os,
       break;
     case be_sequence::MNG_STRING:
       {
-        be_type *prim_type = 0;
-        if (elem->node_type () == AST_Decl::NT_typedef)
+        be_type *const prim_type = primitive_base_type ();
+        if (!prim_type)
           {
-            // Get the primitive base type of this typedef node.
-            be_typedef *t = be_typedef::narrow_from_decl (elem);
-            prim_type = t->primitive_base_type ();
+            ACE_ERROR_RETURN ((LM_ERROR,
+                               "(%N:%l) be_sequence::"
+                               "gen_base_class_name - "
+                               "Bad element type\n"),
+                              -1);
           }
-        else
-          {
-            prim_type = elem;
-          }
-
         if (prim_type->node_type () == AST_Decl::NT_string)
           {
             be_string *str =
-              be_string::narrow_from_decl (prim_type);
+              dynamic_cast<be_string*> (prim_type);
             if (!str)
               {
                 ACE_ERROR_RETURN ((LM_ERROR,
@@ -680,22 +649,19 @@ be_sequence::gen_base_class_name (TAO_OutStream *os,
       break;
     case be_sequence::MNG_WSTRING:
       {
-        be_type *prim_type = 0;
-        if (elem->node_type () == AST_Decl::NT_typedef)
+        be_type *const prim_type = primitive_base_type ();
+        if (!prim_type)
           {
-            // Get the primitive base type of this typedef node.
-            be_typedef *t = be_typedef::narrow_from_decl (elem);
-            prim_type = t->primitive_base_type ();
+            ACE_ERROR_RETURN ((LM_ERROR,
+                               "(%N:%l) be_sequence::"
+                               "gen_base_class_name - "
+                               "Bad element type\n"),
+                              -1);
           }
-        else
-          {
-            prim_type = elem;
-          }
-
         if (prim_type->node_type () == AST_Decl::NT_wstring)
           {
             be_string *str =
-              be_string::narrow_from_decl (prim_type);
+              dynamic_cast<be_string*> (prim_type);
             if (!str)
               {
                 ACE_ERROR_RETURN ((LM_ERROR,
@@ -744,46 +710,74 @@ be_sequence::gen_base_class_name (TAO_OutStream *os,
             if (this->unbounded ())
               {
                 *os << "::TAO::unbounded_array_sequence<" << linebreak
-                     << be_idt << be_idt_nl
-                     << elem->nested_type_name (ctx_scope) << "," << linebreak
-                     << be_nl;
-                 *os << elem->nested_type_name (ctx_scope) << "_slice,"
-                     << linebreak << be_nl
-                     << elem->nested_type_name (ctx_scope) << "_tag"
-                     << linebreak << be_uidt_nl
-                     << ">" << be_uidt;
+                    << be_idt << be_idt_nl
+                    << elem->nested_type_name (ctx_scope) << "," << linebreak
+                    << be_nl;
+                *os << elem->nested_type_name (ctx_scope) << "_slice,"
+                    << linebreak << be_nl
+                    << elem->nested_type_name (ctx_scope) << "_tag"
+                    << linebreak << be_uidt_nl
+                    << ">" << be_uidt;
               }
             else
               {
                 *os << "::TAO::bounded_array_sequence<" << linebreak
-                     << be_idt << be_idt_nl
-                     << elem->nested_type_name (ctx_scope) << "," << linebreak
-                     << be_nl;
-                 *os << elem->nested_type_name (ctx_scope) << "_slice,"
-                     << linebreak << be_nl
-                     << elem->nested_type_name (ctx_scope) << "_tag,"
-                     << linebreak << be_nl
-                     << this->max_size ()->ev ()->u.ulval << linebreak
-                     << be_uidt_nl
-                     << ">" << be_uidt;
+                    << be_idt << be_idt_nl
+                    << elem->nested_type_name (ctx_scope) << "," << linebreak
+                    << be_nl;
+                *os << elem->nested_type_name (ctx_scope) << "_slice,"
+                    << linebreak << be_nl
+                    << elem->nested_type_name (ctx_scope) << "_tag,"
+                    << linebreak << be_nl
+                    << this->max_size ()->ev ()->u.ulval << linebreak
+                    << be_uidt_nl
+                    << ">" << be_uidt;
               }
 
             break;
           default:
-            if (this->unbounded ())
-              {
-                *os << "::TAO::unbounded_value_sequence< "
-                    << elem->nested_type_name (ctx_scope)
-                    << ">";
-              }
-            else
-              {
-                *os << "::TAO::bounded_value_sequence< "
-                    << elem->nested_type_name (ctx_scope) << ","
-                    << this->max_size ()->ev ()->u.ulval
-                    << ">";
-              }
+            {
+              be_type *const base_type = primitive_base_type ();
+              if (!base_type)
+                {
+                  ACE_ERROR_RETURN ((LM_ERROR,
+                                     "(%N:%l) be_sequence::"
+                                     "gen_base_class_name - "
+                                     "Bad element type\n"),
+                                    -1);
+                }
 
+              const char *tag = "";
+              if (base_type->node_type () == AST_Decl::NT_pre_defined)
+                {
+                  be_predefined_type *const predefined_type =
+                    dynamic_cast<be_predefined_type*> (base_type);
+                  if (!predefined_type)
+                    ACE_ERROR_RETURN ((LM_ERROR,
+                                       "(%N:%l) be_sequence::"
+                                       "gen_base_class_name - "
+                                       "Bad element type\n"),
+                                      -1);
+                  switch (predefined_type->pt ())
+                    {
+                      case AST_PredefinedType::PT_uint8:
+                        tag = ", CORBA::IDLv4::UInt8_tag";
+                        break;
+                      case AST_PredefinedType::PT_int8:
+                        tag = ", CORBA::IDLv4::Int8_tag";
+                        break;
+                      default:
+                        break;
+                    }
+                }
+
+              *os
+                << "::TAO::" << (unbounded () ? "un" : "") << "bounded_value_sequence< "
+                << elem->nested_type_name (ctx_scope);
+              if (!unbounded ())
+                *os << "," << this->max_size ()->ev ()->u.ulval;
+              *os << tag << ">";
+            }
             break;
         }
 
@@ -794,7 +788,7 @@ be_sequence::gen_base_class_name (TAO_OutStream *os,
 }
 
 be_field *
-be_sequence::field_node (void) const
+be_sequence::field_node () const
 {
   return this->field_node_;
 }
@@ -807,19 +801,19 @@ be_sequence::field_node (be_field *node)
 
 // Overriden method.
 void
-be_sequence::compute_tc_name (void)
+be_sequence::compute_tc_name ()
 {
   // Sequence TypeCodes can only be accessed through an alias
   // TypeCode.  Generate a TypeCode name that is meant for internal
   // use alone.
 
-  Identifier * tao_id = 0;
+  Identifier * tao_id = nullptr;
   ACE_NEW (tao_id,
            Identifier ("TAO"));
 
   ACE_NEW (this->tc_name_,
            UTL_ScopedName (tao_id,
-                           0));
+                           nullptr));
 
   char bound[30] = { 0 };
 
@@ -832,25 +826,25 @@ be_sequence::compute_tc_name (void)
     + ACE_CString (this->flat_name ())
     + ACE_CString (bound);
 
-  Identifier * typecode_scope = 0;
+  Identifier * typecode_scope = nullptr;
   ACE_NEW (typecode_scope,
            Identifier ("TypeCode"));
 
-  UTL_ScopedName * tc_scope_conc_name = 0;
+  UTL_ScopedName * tc_scope_conc_name = nullptr;
   ACE_NEW (tc_scope_conc_name,
            UTL_ScopedName (typecode_scope,
-                           0));
+                           nullptr));
 
   this->tc_name_->nconc (tc_scope_conc_name);
 
-  Identifier * id = 0;
+  Identifier * id = nullptr;
   ACE_NEW (id,
            Identifier (local_tc_name.c_str ()));
 
-  UTL_ScopedName * conc_name = 0;
+  UTL_ScopedName * conc_name = nullptr;
   ACE_NEW (conc_name,
            UTL_ScopedName (id,
-                           0));
+                           nullptr));
 
   this->tc_name_->nconc (conc_name);
 }
@@ -870,14 +864,10 @@ be_sequence::smart_fwd_helper_name (AST_Decl *ctx_scope,
 }
 
 void
-be_sequence::destroy (void)
+be_sequence::destroy ()
 {
   // Call the destroy methods of our base classes.
   this->be_scope::destroy ();
   this->be_type::destroy ();
   this->AST_Sequence::destroy ();
 }
-
-
-
-IMPL_NARROW_FROM_DECL (be_sequence)
