@@ -21,14 +21,14 @@ be_visitor_args_upcall_ss::be_visitor_args_upcall_ss (be_visitor_context *ctx)
 {
 }
 
-be_visitor_args_upcall_ss::~be_visitor_args_upcall_ss (void)
+be_visitor_args_upcall_ss::~be_visitor_args_upcall_ss ()
 {
 }
 
 int be_visitor_args_upcall_ss::visit_argument (be_argument *node)
 {
   this->ctx_->node (node);
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -61,7 +61,7 @@ int be_visitor_args_upcall_ss::visit_array (be_array *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_argument *arg =
-    be_argument::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_argument*> (this->ctx_->node ());
 
   switch (this->direction ())
     {
@@ -108,7 +108,7 @@ int be_visitor_args_upcall_ss::visit_enum (be_enum *)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_argument *arg =
-    be_argument::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_argument*> (this->ctx_->node ());
 
   switch (this->direction ())
     {
@@ -158,7 +158,7 @@ int be_visitor_args_upcall_ss::visit_predefined_type (
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_argument *arg =
-    be_argument::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_argument*> (this->ctx_->node ());
   AST_PredefinedType::PredefinedType pt = node->pt ();
 
   if (pt == AST_PredefinedType::PT_any)
@@ -248,7 +248,7 @@ int be_visitor_args_upcall_ss::visit_sequence (
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_argument *arg =
-    be_argument::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_argument*> (this->ctx_->node ());
 
   switch (this->direction ())
     {
@@ -307,7 +307,7 @@ int be_visitor_args_upcall_ss::visit_typedef (
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
 
@@ -343,11 +343,11 @@ be_visitor_args_upcall_ss::visit_eventtype_fwd (
   return this->visit_valuetype_fwd (node);
 }
 
-int be_visitor_args_upcall_ss::emit_common (void)
+int be_visitor_args_upcall_ss::emit_common ()
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_argument *arg =
-    be_argument::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_argument*> (this->ctx_->node ());
 
   switch (this->direction ())
     {
@@ -397,7 +397,7 @@ int be_visitor_args_upcall_ss::emit_common2 (
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_argument *arg =
-    be_argument::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_argument*> (this->ctx_->node ());
 
   switch (this->direction ())
     {
