@@ -21,7 +21,7 @@ be_visitor_facet_ami_exs::be_visitor_facet_ami_exs (
 {
 }
 
-be_visitor_facet_ami_exs::~be_visitor_facet_ami_exs (void)
+be_visitor_facet_ami_exs::~be_visitor_facet_ami_exs ()
 {
 }
 
@@ -43,7 +43,7 @@ be_visitor_facet_ami_exs::visit_provides (be_provides *node)
 {
 
   this->iface_ =
-    be_interface::narrow_from_decl (node->provides_type ());
+    dynamic_cast<be_interface*> (node->provides_type ());
 
     if (this->gen_reply_handler_class () == -1)
     {
@@ -74,8 +74,8 @@ be_visitor_facet_ami_exs::visit_attribute (be_attribute *node)
   be_operation get_op (node->field_type (),
                          AST_Operation::OP_noflags,
                          node->name (),
-                         0,
-                         0);
+                         false,
+                         false);
   get_op.set_name ((UTL_IdList *) node->name ()->copy ());
   if (this->visit_operation (&get_op) == -1)
     {
@@ -94,7 +94,7 @@ be_visitor_facet_ami_exs::visit_attribute (be_attribute *node)
       return 0;
     }
   Identifier id ("void");
-  UTL_ScopedName sn (&id, 0);
+  UTL_ScopedName sn (&id, nullptr);
 
   // Create the return type, which is "void"
   be_predefined_type rt (AST_PredefinedType::PT_void, &sn);
@@ -111,8 +111,8 @@ be_visitor_facet_ami_exs::visit_attribute (be_attribute *node)
   be_operation set_op (&rt,
                        AST_Operation::OP_noflags,
                        node->name (),
-                       0,
-                       0);
+                       false,
+                       false);
 
   set_op.set_name ((UTL_IdList *) node->name ()->copy ());
   set_op.be_add_argument (arg);
@@ -203,7 +203,7 @@ be_visitor_facet_ami_exs::post_process (be_decl *node)
   return 0;
 }
 void
-be_visitor_facet_ami_exs::init (void)
+be_visitor_facet_ami_exs::init ()
 {
   UTL_Scope *s = this->iface_->defined_in ();
   ACE_CString handler_str (
@@ -219,13 +219,13 @@ be_visitor_facet_ami_exs::init (void)
 
   sn->destroy ();
   delete sn;
-  sn = 0;
+  sn = nullptr;
 
 
   be_interface *callback_iface =
-    be_interface::narrow_from_decl (d);
+    dynamic_cast<be_interface*> (d);
 
-  if (callback_iface == 0)
+  if (callback_iface == nullptr)
    this->sync_ = true;
   else
     this->sync_ = false;
@@ -233,7 +233,7 @@ be_visitor_facet_ami_exs::init (void)
 
 }
 int
-be_visitor_facet_ami_exs::gen_reply_handler_class (void)
+be_visitor_facet_ami_exs::gen_reply_handler_class ()
 {
   this->for_reply_handler_ = true;
 
@@ -268,7 +268,7 @@ be_visitor_facet_ami_exs::gen_reply_handler_class (void)
 
   os_ << be_nl_2
       << iface_name << suffix << "::~"
-      << iface_name << suffix << " (void)" << be_nl
+      << iface_name << suffix << " ()" << be_nl
       << "{" << be_nl
       << "}";
 
@@ -291,11 +291,11 @@ be_visitor_facet_ami_exs::gen_reply_handler_class (void)
 
   sn->destroy ();
   delete sn;
-  sn = 0;
+  sn = nullptr;
 
 
   be_interface *callback_iface =
-    be_interface::narrow_from_decl (d);
+    dynamic_cast<be_interface*> (d);
 
   /// The overload of traverse_inheritance_graph() used here
   /// doesn't automatically prime the queues.
@@ -325,7 +325,7 @@ be_visitor_facet_ami_exs::gen_reply_handler_class (void)
 }
 
 int
-be_visitor_facet_ami_exs::gen_facet_executor_class (void)
+be_visitor_facet_ami_exs::gen_facet_executor_class ()
 {
 
   this->for_reply_handler_ = false;
@@ -337,13 +337,13 @@ be_visitor_facet_ami_exs::gen_facet_executor_class (void)
 
   os_ << be_nl_2
       << iface_name << suffix << "::"
-      << iface_name << suffix << " (void)" << be_nl
+      << iface_name << suffix << " ()" << be_nl
       << "{" << be_nl
       << "}";
 
   os_ << be_nl_2
       << iface_name << suffix << "::~"
-      << iface_name << suffix << " (void)" << be_nl
+      << iface_name << suffix << " ()" << be_nl
       << "{" << be_nl
       << "}";
 
@@ -360,10 +360,10 @@ be_visitor_facet_ami_exs::gen_facet_executor_class (void)
 
     sn->destroy ();
     delete sn;
-    sn = 0;
+    sn = nullptr;
 
     be_interface *sync_iface =
-       be_interface::narrow_from_decl (d);
+       dynamic_cast<be_interface*> (d);
 
     /// The overload of traverse_inheritance_graph() used here
     /// doesn't automatically prime the queues.
@@ -389,7 +389,7 @@ be_visitor_facet_ami_exs::gen_facet_executor_class (void)
 
       }
 
-  ACE_CString scope_str (scope_name, 0, false);
+  ACE_CString scope_str (scope_name, nullptr, false);
 
   const char *container_type = be_global->ciao_container_type ();
 
@@ -421,7 +421,7 @@ be_visitor_facet_ami_exs::gen_facet_executor_class (void)
 
   os_ << be_nl_2
       << "::CORBA::Object_ptr" << be_nl
-      << iface_name << "_exec_i::_get_component (void)" << be_nl
+      << iface_name << "_exec_i::_get_component ()" << be_nl
       << "{" << be_idt_nl
       << "return" << be_idt_nl
       << "::" << s->name () << smart_scope
@@ -477,7 +477,7 @@ be_visitor_facet_ami_exs::gen_reply_hander_op (be_operation *node)
       UTL_ScopeActiveIterator i (node, UTL_Scope::IK_decls);
       AST_Decl *d = i.item ();
       AST_Argument *arg =
-        AST_Argument::narrow_from_decl (d);
+        dynamic_cast<AST_Argument*> (d);
       AST_Type *t = arg->field_type ();
       ACE_CString type_name = t->full_name ();
 
@@ -539,7 +539,7 @@ be_visitor_facet_ami_exs::gen_facet_executor_op (be_operation *node)
 {
 
   // do not handle not sendc operations.
-  if (ACE_OS::strstr (node->local_name()->get_string (), "sendc_")== 0)
+  if (ACE_OS::strstr (node->local_name()->get_string (), "sendc_")== nullptr)
      return 0;
 
     os_ << be_nl_2
@@ -653,7 +653,7 @@ be_visitor_facet_ami_exs::gen_facet_executor_sync_op (be_operation *node)
 
    os_ << be_nl_2;
   // generate the return type.
-  be_type *bt = be_type::narrow_from_decl (node->return_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->return_type ());
 
   if (!bt)
     {
@@ -701,10 +701,10 @@ be_visitor_facet_ami_exs::gen_facet_executor_sync_op (be_operation *node)
   os_ << be_nl
       << "{" << be_idt_nl;
 
-  AST_PredefinedType *pdt = 0;
-  pdt = AST_PredefinedType::narrow_from_decl (bt);
+  AST_PredefinedType *pdt = nullptr;
+  pdt = dynamic_cast<AST_PredefinedType*> (bt);
   bool ret = true;
-  if ((pdt != 0) && (pdt->pt () == AST_PredefinedType::PT_void))
+  if ((pdt != nullptr) && (pdt->pt () == AST_PredefinedType::PT_void))
     ret =false;
 
   os_  << "::" << scope->full_name () << smart_scope
