@@ -21,14 +21,14 @@ be_visitor_field_cdr_op_cs::be_visitor_field_cdr_op_cs (
 {
 }
 
-be_visitor_field_cdr_op_cs::~be_visitor_field_cdr_op_cs (void)
+be_visitor_field_cdr_op_cs::~be_visitor_field_cdr_op_cs ()
 {
 }
 
 int
 be_visitor_field_cdr_op_cs::visit_field (be_field *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -81,9 +81,9 @@ be_visitor_field_cdr_op_cs::visit_array (be_array *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -102,7 +102,7 @@ be_visitor_field_cdr_op_cs::visit_array (be_array *node)
                   '\0',
                   NAMEBUFSIZE);
 
-  if (this->ctx_->alias () == 0 // Not a typedef.
+  if (this->ctx_->alias () == nullptr // Not a typedef.
       && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays ...
@@ -112,7 +112,7 @@ be_visitor_field_cdr_op_cs::visit_array (be_array *node)
       if (node->is_nested ())
         {
           be_decl *parent =
-            be_scope::narrow_from_scope (node->defined_in ())->decl ();
+            dynamic_cast<be_scope*> (node->defined_in ())->decl ();
           ACE_OS::sprintf (fname,
                            "%s::_%s",
                            parent->full_name (),
@@ -188,9 +188,9 @@ be_visitor_field_cdr_op_cs::visit_enum (be_enum *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -231,9 +231,9 @@ be_visitor_field_cdr_op_cs::visit_interface (be_interface *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -305,9 +305,9 @@ be_visitor_field_cdr_op_cs::visit_interface_fwd (be_interface_fwd *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -404,13 +404,13 @@ be_visitor_field_cdr_op_cs::visit_eventtype_fwd (be_eventtype_fwd *node)
 
 
 int
-be_visitor_field_cdr_op_cs::emit_valuetype_common (void)
+be_visitor_field_cdr_op_cs::emit_valuetype_common ()
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -456,9 +456,9 @@ be_visitor_field_cdr_op_cs::visit_predefined_type (be_predefined_type *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -500,6 +500,16 @@ be_visitor_field_cdr_op_cs::visit_predefined_type (be_predefined_type *node)
           *os << "(strm >> ::ACE_InputCDR::to_boolean (_tao_aggregate."
               << f->local_name () << "))";
         }
+      else if (pt == AST_PredefinedType::PT_uint8)
+        {
+          *os << "(strm >> ::ACE_InputCDR::to_uint8 (_tao_aggregate."
+              << f->local_name () << "))";
+        }
+      else if (pt == AST_PredefinedType::PT_int8)
+        {
+          *os << "(strm >> ::ACE_InputCDR::to_int8 (_tao_aggregate."
+              << f->local_name () << "))";
+        }
       else
         {
           *os << "(strm >> _tao_aggregate." << f->local_name () << ")";
@@ -531,6 +541,16 @@ be_visitor_field_cdr_op_cs::visit_predefined_type (be_predefined_type *node)
           *os << "(strm << ::ACE_OutputCDR::from_boolean (_tao_aggregate."
               << f->local_name () << "))";
         }
+      else if (pt == AST_PredefinedType::PT_uint8)
+        {
+          *os << "(strm << ::ACE_OutputCDR::from_uint8 (_tao_aggregate."
+              << f->local_name () << "))";
+        }
+      else if (pt == AST_PredefinedType::PT_int8)
+        {
+          *os << "(strm << ::ACE_OutputCDR::from_int8 (_tao_aggregate."
+              << f->local_name () << "))";
+        }
       else
         {
           *os << "(strm << _tao_aggregate." << f->local_name () << ")";
@@ -579,9 +599,9 @@ be_visitor_field_cdr_op_cs::visit_sequence (be_sequence *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -624,9 +644,9 @@ be_visitor_field_cdr_op_cs::visit_string (be_string *str)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -640,7 +660,7 @@ be_visitor_field_cdr_op_cs::visit_string (be_string *str)
   switch (this->ctx_->sub_state ())
     {
     case TAO_CodeGen::TAO_CDR_INPUT:
-      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+      if (str != nullptr && str->max_size ()->ev ()->u.ulval != 0)
         {
           if (str->width () == (long) sizeof (char))
             {
@@ -662,7 +682,7 @@ be_visitor_field_cdr_op_cs::visit_string (be_string *str)
 
       break;
     case TAO_CodeGen::TAO_CDR_OUTPUT:
-      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+      if (str != nullptr && str->max_size ()->ev ()->u.ulval != 0)
         {
           if (str->width () == (long) sizeof (char))
             {
@@ -726,9 +746,9 @@ be_visitor_field_cdr_op_cs::visit_structure (be_structure *node)
 
   // retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -769,7 +789,7 @@ be_visitor_field_cdr_op_cs::visit_structure_fwd (
   be_structure_fwd *node)
 {
   be_structure *s =
-    be_structure::narrow_from_decl (node->full_definition ());
+    dynamic_cast<be_structure*> (node->full_definition ());
 
   return this->visit_structure (s);
 }
@@ -789,7 +809,7 @@ be_visitor_field_cdr_op_cs::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
 
@@ -821,9 +841,9 @@ be_visitor_field_cdr_op_cs::visit_union (be_union *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -863,7 +883,7 @@ int
 be_visitor_field_cdr_op_cs::visit_union_fwd (be_union_fwd *node)
 {
   be_union *u =
-    be_union::narrow_from_decl (node->full_definition ());
+    dynamic_cast<be_union*> (node->full_definition ());
 
   return this->visit_union (u);
 }
@@ -887,9 +907,9 @@ be_visitor_cdr_op_field_decl::be_visitor_cdr_op_field_decl (
 int
 be_visitor_cdr_op_field_decl::visit_field (be_field *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
-  if (bt == 0)
+  if (bt == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_cdr_op_field_decl::"
@@ -920,9 +940,9 @@ be_visitor_cdr_op_field_decl::visit_array (be_array *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_cdr_op_field_decl::"
@@ -939,7 +959,7 @@ be_visitor_cdr_op_field_decl::visit_array (be_array *node)
                   '\0',
                   NAMEBUFSIZE);
 
-  if (this->ctx_->alias () == 0 // Not a typedef.
+  if (this->ctx_->alias () == nullptr // Not a typedef.
       && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays,
@@ -949,7 +969,7 @@ be_visitor_cdr_op_field_decl::visit_array (be_array *node)
 
       if (node->is_nested ())
         {
-          be_decl *parent = be_scope::narrow_from_scope (node->defined_in ())->decl ();
+          be_decl *parent = dynamic_cast<be_scope*> (node->defined_in ())->decl ();
           ACE_OS::sprintf (fname,
                            "%s::_%s",
                            parent->full_name (),
@@ -977,17 +997,10 @@ be_visitor_cdr_op_field_decl::visit_array (be_array *node)
     case TAO_CodeGen::TAO_CDR_INPUT:
     case TAO_CodeGen::TAO_CDR_OUTPUT:
       *os << fname << "_forany "
-          << "_tao_aggregate_" << f->local_name () << be_idt << be_idt_nl
-          << "#if defined __IBMCPP__ && __IBMCPP__ <= 800" << be_nl
-          << "((" << fname << "_slice*) (" << be_nl
-          << "#else" << be_nl
-          << "(const_cast<" << be_idt << be_idt_nl
-          << fname << "_slice*> (" << be_uidt << be_uidt_nl
-          << "#endif" << be_idt << be_idt_nl
-          << "_tao_aggregate." << f->local_name () << be_uidt_nl
-          << ")" << be_uidt << be_uidt_nl
-          << ");" << be_uidt_nl;
-
+          << "_tao_aggregate_" << f->local_name () << be_idt_nl
+          << "(const_cast<" << fname << "_slice*> (" << be_idt_nl
+          << "_tao_aggregate." << f->local_name () << "));" << be_uidt
+          << be_uidt_nl;
       break;
     case TAO_CodeGen::TAO_CDR_SCOPE:
     default:
@@ -1012,7 +1025,7 @@ be_visitor_cdr_op_field_decl::visit_typedef (be_typedef *node)
   // The node to be visited in the base primitve type that gets typedefed.
   be_type *bt = node->primitive_base_type ();
 
-  if (bt == 0 || bt->accept (this) == -1)
+  if (bt == nullptr || bt->accept (this) == -1)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_cdr_op_field_decl::"
@@ -1021,6 +1034,6 @@ be_visitor_cdr_op_field_decl::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
