@@ -25,14 +25,14 @@ be_visitor_field_cs::be_visitor_field_cs (be_visitor_context *ctx)
 {
 }
 
-be_visitor_field_cs::~be_visitor_field_cs (void)
+be_visitor_field_cs::~be_visitor_field_cs ()
 {
 }
 
 int
 be_visitor_field_cs::visit_field (be_field *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -154,7 +154,7 @@ be_visitor_field_cs::visit_structure_fwd (
   be_structure_fwd *node)
 {
   be_structure *s =
-    be_structure::narrow_from_decl (node->full_definition ());
+    dynamic_cast<be_structure*> (node->full_definition ());
 
   return this->visit_structure (s);
 }
@@ -174,7 +174,7 @@ be_visitor_field_cs::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
 
@@ -205,7 +205,7 @@ int
 be_visitor_field_cs::visit_union_fwd (be_union_fwd *node)
 {
   be_union *u =
-    be_union::narrow_from_decl (node->full_definition ());
+    dynamic_cast<be_union*> (node->full_definition ());
 
   return this->visit_union (u);
 }
