@@ -17,7 +17,7 @@ be_visitor_module_any_op::be_visitor_module_any_op (be_visitor_context *ctx)
 {
 }
 
-be_visitor_module_any_op::~be_visitor_module_any_op (void)
+be_visitor_module_any_op::~be_visitor_module_any_op ()
 {
 }
 
