@@ -16,7 +16,7 @@ be_visitor_operation_ss::be_visitor_operation_ss (be_visitor_context *ctx)
 {
 }
 
-be_visitor_operation_ss::~be_visitor_operation_ss (void)
+be_visitor_operation_ss::~be_visitor_operation_ss ()
 {
 }
 
@@ -30,7 +30,7 @@ be_visitor_operation_ss::visit_operation (be_operation * node)
     }
 
   TAO_OutStream *os = this->ctx_->stream ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   this->ctx_->node (node);
 
@@ -43,7 +43,7 @@ be_visitor_operation_ss::visit_operation (be_operation * node)
     }
 
   // Retrieve the operation return type.
-  bt = be_type::narrow_from_decl (node->return_type ());
+  bt = dynamic_cast<be_type*> (node->return_type ());
 
   if (!bt)
     {
@@ -65,7 +65,7 @@ be_visitor_operation_ss::visit_argument (be_argument *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the type for this argument.
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -127,9 +127,9 @@ be_visitor_operation_ss::gen_skel_operation_body (be_operation * node,
                  ? this->ctx_->attribute ()->defined_in ()
                  : node->defined_in ();
 
-  be_interface *intf = be_interface::narrow_from_scope (s);
+  be_interface *intf = dynamic_cast<be_interface*> (s);
 
-  if (intf == 0)
+  if (intf == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          ACE_TEXT ("be_visitor_operation_ss::")
@@ -164,8 +164,7 @@ be_visitor_operation_ss::gen_skel_operation_body (be_operation * node,
                                 intf->full_skel_name (),
                                 upcall_command_name.c_str ());
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "void " << intf->full_skel_name () << "::";
 
@@ -220,25 +219,22 @@ be_visitor_operation_ss::gen_skel_operation_body (be_operation * node,
   *os << be_nl_2
       << "TAO::Argument * const args[] =" << be_idt_nl
       << "{" << be_idt_nl
-      << "&retval";
+      << "std::addressof(retval)";
 
   for (UTL_ScopeActiveIterator arg_list_iter (node, UTL_Scope::IK_decls);
        ! arg_list_iter.is_done ();
        arg_list_iter.next ())
     {
       AST_Argument * const arg =
-        AST_Argument::narrow_from_decl (arg_list_iter.item ());
+        dynamic_cast<AST_Argument*> (arg_list_iter.item ());
 
       *os << "," << be_nl
-          << "&_tao_" << arg->local_name ();
+          << "std::addressof(_tao_" << arg->local_name () << ")";
     }
 
   *os << be_uidt_nl
       << "};" << be_uidt_nl << be_nl;
 
-  *os << "static size_t const nargs = "
-      << (node->argument_count () + 1) << ";" << be_nl_2;
-
   // Get the right object implementation.
   *os << intf->full_skel_name () << " * const impl =" << be_idt_nl
       << "dynamic_cast<"
@@ -268,17 +264,26 @@ be_visitor_operation_ss::gen_skel_operation_body (be_operation * node,
 
   *os << ");" << be_uidt_nl << be_nl;
 
-
   *os << "TAO::Upcall_Wrapper upcall_wrapper;" << be_nl
       << "upcall_wrapper.upcall (server_request" << be_nl
       << "                       , args" << be_nl
-      << "                       , nargs" << be_nl
+      << "                       , " << (node->argument_count () + 1) << be_nl
       << "                       , command"
       << "\n#if TAO_HAS_INTERCEPTORS == 1" << be_nl
-      << "                       , servant_upcall" << be_nl
-      << "                       , exceptions" << be_nl
-      << "                       , nexceptions"
-      << "\n#endif  /* TAO_HAS_INTERCEPTORS == 1 */" << be_nl
+      << "                       , servant_upcall" << be_nl;
+
+  if (node->exceptions () && be_global->tc_support ())
+    {
+      *os << "                       , exceptions" << be_nl
+          << "                       , " << node->exceptions ()->length ();
+    }
+  else
+    {
+      *os << "                       , nullptr" << be_nl
+          << "                       , 0";
+    }
+
+  *os << "\n#endif  /* TAO_HAS_INTERCEPTORS == 1 */" << be_nl
       << "                       );" << be_uidt_nl
       << "}" << be_nl_2;
 
@@ -294,7 +299,7 @@ be_visitor_operation_ss::gen_skel_body_arglist (be_operation * node,
        arg_decl_iter.next ())
     {
       AST_Argument * const arg =
-        AST_Argument::narrow_from_decl (arg_decl_iter.item ());
+        dynamic_cast<AST_Argument*> (arg_decl_iter.item ());
 
       *os << be_nl
           << "TAO::SArg_Traits< ";
