@@ -17,7 +17,7 @@ be_visitor_root_cns::be_visitor_root_cns (be_visitor_context *ctx)
 {
 }
 
-be_visitor_root_cns::~be_visitor_root_cns (void)
+be_visitor_root_cns::~be_visitor_root_cns ()
 {
 }
 
@@ -46,7 +46,7 @@ be_visitor_root_cns::visit_root (be_root *node)
 }
 
 int
-be_visitor_root_cns::init (void)
+be_visitor_root_cns::init ()
 {
   // First open the client-side header file for writing.
   int status =
