@@ -17,18 +17,18 @@ be_visitor_valuebox_union_member_ci::be_visitor_valuebox_union_member_ci (
     be_visitor_context *ctx
   )
   : be_visitor_decl (ctx),
-    vb_node_ (0)
+    vb_node_ (nullptr)
 {
 }
 
-be_visitor_valuebox_union_member_ci::~be_visitor_valuebox_union_member_ci (void)
+be_visitor_valuebox_union_member_ci::~be_visitor_valuebox_union_member_ci ()
 {
 }
 
 int
 be_visitor_valuebox_union_member_ci::visit_union_member (be_union_branch *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -40,7 +40,7 @@ be_visitor_valuebox_union_member_ci::visit_union_member (be_union_branch *node)
     }
 
   this->vb_node_ =
-    be_valuebox::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_valuebox*> (this->ctx_->node ());
   this->ctx_->node (node);
 
   if (bt->accept (this) == -1)
@@ -61,7 +61,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -97,7 +97,7 @@ be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
       if (bt->is_nested ())
         {
           be_decl *parent =
-                 be_scope::narrow_from_scope (bt->defined_in ())->decl ();
+                 dynamic_cast<be_scope*> (bt->defined_in ())->decl ();
           ACE_OS::sprintf (fname,
                            "%s::_%s",
                            parent->full_name (),
@@ -118,8 +118,7 @@ be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
                        bt->full_name ());
     }
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Modifier to set the member." << be_nl;
 
@@ -135,7 +134,7 @@ be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
 
   *os << "ACE_INLINE const " << fname << "_slice *" << be_nl
       << vb_node_->name () << "::" << field->local_name ()
-      << " (void) const" << be_nl
+      << " () const" << be_nl
       << "{" << be_idt_nl
       << "return this->_pd_value->" << field->local_name ()
       << " ();" << be_uidt_nl
@@ -148,7 +147,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_enum (be_enum *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -171,9 +170,7 @@ be_visitor_valuebox_union_member_ci::visit_enum (be_enum *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
-
+  TAO_INSERT_COMMENT (os);
 
   this->emit_member_set (field, bt, "", "");
   this->emit_member_get (field, bt, "", "", "const");
@@ -185,7 +182,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_interface (be_interface *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -208,8 +205,7 @@ be_visitor_valuebox_union_member_ci::visit_interface (be_interface *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   this->emit_member_set (field, bt, "", "_ptr");
   this->emit_member_get (field, bt, "", "_ptr", "const");
@@ -221,7 +217,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_interface_fwd (be_interface_fwd *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -244,8 +240,7 @@ be_visitor_valuebox_union_member_ci::visit_interface_fwd (be_interface_fwd *node
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   this->emit_member_set (field, bt, "", "_ptr");
   this->emit_member_get (field, bt, "", "_ptr", "const");
@@ -271,7 +266,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_predefined_type (be_predefined_type *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -294,8 +289,7 @@ be_visitor_valuebox_union_member_ci::visit_predefined_type (be_predefined_type *
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   switch (node->pt ())
   {
@@ -324,7 +318,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_sequence (be_sequence *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -347,8 +341,7 @@ be_visitor_valuebox_union_member_ci::visit_sequence (be_sequence *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   this->emit_member_set (field, bt, "const ", " &");
   this->emit_member_get (field, bt, "const ", " &", "const");
@@ -361,7 +354,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_string (be_string *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -384,8 +377,7 @@ be_visitor_valuebox_union_member_ci::visit_string (be_string *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   this->emit_member_set (field, bt, "", "");
   this->emit_member_set (field, bt, "const ", "");
@@ -419,7 +411,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_structure (be_structure *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -442,8 +434,7 @@ be_visitor_valuebox_union_member_ci::visit_structure (be_structure *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   this->emit_member_set (field, bt, "const ", " &");
   this->emit_member_get (field, bt, "const ", " &", "const");
@@ -467,7 +458,7 @@ be_visitor_valuebox_union_member_ci::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
 
@@ -475,7 +466,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_union (be_union *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -498,8 +489,7 @@ be_visitor_valuebox_union_member_ci::visit_union (be_union *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   this->emit_member_set (field, bt, "const ", " &");
   this->emit_member_get (field, bt, "const ", " &", "const");
@@ -544,7 +534,7 @@ be_visitor_valuebox_union_member_ci::emit_member_get (
   *os << "ACE_INLINE " << const_prefix << field_type->name () << type_suffix
       << be_nl
       << vb_node_->name () << "::" << field->local_name ()
-      << " (void) " << const_method << be_nl
+      << " () " << const_method << be_nl
       << "{" << be_idt_nl
       << "return this->_pd_value->" << field->local_name ()
       << " ();" << be_uidt_nl
