@@ -16,19 +16,19 @@
 be_visitor_valuetype_field_cs::be_visitor_valuetype_field_cs (
     be_visitor_context *ctx)
   : be_visitor_decl (ctx),
-    in_obv_space_ (0)
+    in_obv_space_ (false)
 {
   setenclosings ("");
 }
 
-be_visitor_valuetype_field_cs::~be_visitor_valuetype_field_cs (void)
+be_visitor_valuetype_field_cs::~be_visitor_valuetype_field_cs ()
 {
 }
 
 int
 be_visitor_valuetype_field_cs::visit_field (be_field *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -60,8 +60,8 @@ be_visitor_valuetype_field_cs::visit_array (be_array *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -117,7 +117,7 @@ be_visitor_valuetype_field_cs::visit_array (be_array *node)
       if (bt->is_nested ())
         {
           be_decl *parent =
-                 be_scope::narrow_from_scope (bt->defined_in ())->decl ();
+                 dynamic_cast<be_scope*> (bt->defined_in ())->decl ();
           ACE_OS::sprintf (fname,
                            "%s::_%s",
                            parent->full_name (),
@@ -138,8 +138,7 @@ be_visitor_valuetype_field_cs::visit_array (be_array *node)
                        bt->full_name ());
     }
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member." << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -162,7 +161,7 @@ be_visitor_valuetype_field_cs::visit_array (be_array *node)
   this->op_name (bu,
                  os);
 
-  *os << "::" << ub->local_name () << " (void) const" << be_nl
+  *os << "::" << ub->local_name () << " () const" << be_nl
       << "{" << be_idt_nl;
   *os << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -175,7 +174,7 @@ be_visitor_valuetype_field_cs::visit_array (be_array *node)
       this->op_name (bu,
                      os);
 
-  *os << "::" << ub->local_name () << " (void)" << be_nl
+  *os << "::" << ub->local_name () << " ()" << be_nl
       << "{" << be_idt_nl;
   *os << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -190,8 +189,8 @@ be_visitor_valuetype_field_cs::visit_enum (be_enum *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -214,8 +213,7 @@ be_visitor_valuetype_field_cs::visit_enum (be_enum *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member." << be_nl
       << this->pre_op() << "void" << be_nl;
@@ -259,8 +257,8 @@ be_visitor_valuetype_field_cs::visit_interface (be_interface *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -283,8 +281,7 @@ be_visitor_valuetype_field_cs::visit_interface (be_interface *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member." << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -328,8 +325,8 @@ be_visitor_valuetype_field_cs::visit_interface_fwd (be_interface_fwd *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -352,8 +349,7 @@ be_visitor_valuetype_field_cs::visit_interface_fwd (be_interface_fwd *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "// Accessor to set the member." << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -402,8 +398,8 @@ be_visitor_valuetype_field_cs::valuetype_common (be_type *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -426,8 +422,7 @@ be_visitor_valuetype_field_cs::valuetype_common (be_type *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member." << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -483,8 +478,8 @@ be_visitor_valuetype_field_cs::visit_valuetype_fwd (be_valuetype_fwd *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -507,8 +502,7 @@ be_visitor_valuetype_field_cs::visit_valuetype_fwd (be_valuetype_fwd *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member." << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -559,8 +553,8 @@ be_visitor_valuetype_field_cs::visit_predefined_type (be_predefined_type *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -583,8 +577,7 @@ be_visitor_valuetype_field_cs::visit_predefined_type (be_predefined_type *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member." << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -650,7 +643,7 @@ be_visitor_valuetype_field_cs::visit_predefined_type (be_predefined_type *node)
                      os);
 
       *os << "::" << ub->local_name ()
-          << " (void) const" << be_nl
+          << " () const" << be_nl
           << "{" << be_idt_nl
           << "return this->"
           << bu->field_pd_prefix () << ub->local_name ()
@@ -666,7 +659,7 @@ be_visitor_valuetype_field_cs::visit_predefined_type (be_predefined_type *node)
       this->op_name (bu, os);
 
       *os << "::" << ub->local_name ()
-          << " (void) const" << be_nl
+          << " () const" << be_nl
           << "{" << be_idt_nl
           << "return this->"
           << bu->field_pd_prefix () << ub->local_name ()
@@ -680,7 +673,7 @@ be_visitor_valuetype_field_cs::visit_predefined_type (be_predefined_type *node)
       this->op_name (bu, os);
 
       *os << "::" << ub->local_name ()
-          << " (void)" << be_nl
+          << " ()" << be_nl
           << "{" << be_idt_nl
           << "return this->"
           << bu->field_pd_prefix () << ub->local_name ()
@@ -698,7 +691,7 @@ be_visitor_valuetype_field_cs::visit_predefined_type (be_predefined_type *node)
       this->op_name (bu, os);
 
       *os << "::" << ub->local_name ()
-          << " (void) const" << be_nl
+          << " () const" << be_nl
           << "{" << be_idt_nl
           << "return this->"
           << bu->field_pd_prefix () << ub->local_name ()
@@ -717,8 +710,8 @@ be_visitor_valuetype_field_cs::visit_sequence (be_sequence *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -758,8 +751,7 @@ be_visitor_valuetype_field_cs::visit_sequence (be_sequence *node)
         }
     }
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   // (1) set from a const
   *os << "/// Accessor to set the member." << be_nl
@@ -785,7 +777,7 @@ be_visitor_valuetype_field_cs::visit_sequence (be_sequence *node)
                  os);
 
   *os << "::" << ub->local_name ()
-      << " (void) const" << be_nl
+      << " () const" << be_nl
       << "{" << be_idt_nl
       << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -799,7 +791,7 @@ be_visitor_valuetype_field_cs::visit_sequence (be_sequence *node)
   this->op_name (bu,
                  os);
 
-  *os << "::" << ub->local_name () << " (void)" << be_nl
+  *os << "::" << ub->local_name () << " ()" << be_nl
       << "{" << be_idt_nl
       << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -815,7 +807,7 @@ be_visitor_valuetype_field_cs::visit_string (be_string *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
 
   if (!ub || !bu)
     {
@@ -830,8 +822,7 @@ be_visitor_valuetype_field_cs::visit_string (be_string *node)
 
   // Three methods to set the string value.
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member." << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -942,7 +933,7 @@ be_visitor_valuetype_field_cs::visit_string (be_string *node)
                  os);
 
   *os << "::" << ub->local_name ()
-      << " (void) const // get method" << be_nl
+      << " () const // get method" << be_nl
       << "{" << be_idt_nl
       << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -958,8 +949,8 @@ be_visitor_valuetype_field_cs::visit_structure (be_structure *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -999,8 +990,7 @@ be_visitor_valuetype_field_cs::visit_structure (be_structure *node)
         }
     }
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   // (1) Set from a const.
   *os << "/// Accessor to set the member." << be_nl
@@ -1026,7 +1016,7 @@ be_visitor_valuetype_field_cs::visit_structure (be_structure *node)
   this->op_name (bu,
                  os);
 
-  *os << "::" << ub->local_name () << " (void) const" << be_nl
+  *os << "::" << ub->local_name () << " () const" << be_nl
       << "{" << be_idt_nl;
   *os << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -1040,7 +1030,7 @@ be_visitor_valuetype_field_cs::visit_structure (be_structure *node)
   this->op_name (bu,
                  os);
 
-  *os << "::" << ub->local_name () << " (void)" << be_nl
+  *os << "::" << ub->local_name () << " ()" << be_nl
       << "{" << be_idt_nl;
   *os << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -1066,7 +1056,7 @@ be_visitor_valuetype_field_cs::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
 
@@ -1075,8 +1065,8 @@ be_visitor_valuetype_field_cs::visit_union (be_union *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -1116,8 +1106,7 @@ be_visitor_valuetype_field_cs::visit_union (be_union *node)
         }
     }
 
-  *os << be_nl_2 << "// TAO_IDL - Generated from" << be_nl
-      << "// " << __FILE__ << ":" << __LINE__ << be_nl_2;
+  TAO_INSERT_COMMENT (os);
 
   *os << "/// Accessor to set the member" << be_nl
       << this->pre_op () << "void" << be_nl;
@@ -1138,7 +1127,7 @@ be_visitor_valuetype_field_cs::visit_union (be_union *node)
   this->op_name (bu,
                  os);
 
-  *os << "::" << ub->local_name () << " (void) const" << be_nl
+  *os << "::" << ub->local_name () << " () const" << be_nl
       << "{" << be_idt_nl
       << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
@@ -1152,7 +1141,7 @@ be_visitor_valuetype_field_cs::visit_union (be_union *node)
   this->op_name (bu,
                  os);
 
-  *os << "::" << ub->local_name () << " (void)" << be_nl
+  *os << "::" << ub->local_name () << " ()" << be_nl
       << "{" << be_idt_nl
       << "return this->"
       << bu->field_pd_prefix () << ub->local_name ()
