@@ -20,7 +20,7 @@ be_visitor_valuetype_init_arglist_ch::be_visitor_valuetype_init_arglist_ch (
 }
 
 be_visitor_valuetype_init_arglist_ch::~be_visitor_valuetype_init_arglist_ch (
-  void)
+  )
 {
 }
 
@@ -49,7 +49,7 @@ be_visitor_valuetype_init_arglist_ch::visit_factory (be_factory *node)
     }
   else
     {
-      os << "void)";
+      os << ")";
     }
 
    return 0;
