@@ -35,20 +35,15 @@ public:
            AST_Interface **supports_flat,
            long n_supports_flat);
 
-  virtual ~be_home (void);
+  virtual ~be_home ();
 
   void scan (UTL_Scope *s);
 
   // Cleanup function.
-  virtual void destroy (void);
+  virtual void destroy ();
 
   // Visiting.
   virtual int accept (be_visitor* visitor);
-
-  // Narrowing.
-
-  DEF_NARROW_FROM_DECL (be_home);
-  DEF_NARROW_FROM_SCOPE (be_home);
 };
 
 #endif // if !defined
