@@ -28,17 +28,13 @@ class be_root : public virtual AST_Root,
 public:
   be_root (UTL_ScopedName *n);
 
-  virtual ~be_root (void);
+  virtual ~be_root ();
 
   /// Cleanup method.
-  virtual void destroy (void);
+  virtual void destroy ();
 
   // Visiting.
   virtual int accept (be_visitor *visitor);
-
-  // Narrowing.
-  DEF_NARROW_FROM_DECL (be_root);
-  DEF_NARROW_FROM_SCOPE (be_root);
 };
 
 #endif
