@@ -14,10 +14,6 @@
 #ifndef _BE_VISITOR_ARRAY_CDR_OP_CH_H_
 #define _BE_VISITOR_ARRAY_CDR_OP_CH_H_
 
-// ************************************************************
-// class be_visitor_array_cdr_op_ch
-// ************************************************************
-
 /**
  * @class be_visitor_array_cdr_op_ch
  *
@@ -34,7 +30,7 @@ public:
   be_visitor_array_cdr_op_ch (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_array_cdr_op_ch (void);
+  ~be_visitor_array_cdr_op_ch ();
 
   /// visit array
   virtual int visit_array (be_array *node);
