@@ -28,7 +28,7 @@ class be_visitor_component : public be_visitor_interface
 public:
   be_visitor_component (be_visitor_context *ctx);
 
-  ~be_visitor_component (void);
+  ~be_visitor_component ();
 
   /// This is the only type of declaration a component may contain.
   virtual int visit_attribute (be_attribute *node);
