@@ -25,7 +25,7 @@ class be_visitor_component_svth : public be_visitor_component
 public:
   be_visitor_component_svth (be_visitor_context *ctx);
 
-  ~be_visitor_component_svth (void);
+  ~be_visitor_component_svth ();
 
   virtual int visit_component (be_component *node);
   virtual int visit_connector (be_connector *node);
