@@ -27,7 +27,7 @@ class be_visitor_context_svts : public be_visitor_component_scope
 public:
   be_visitor_context_svts (be_visitor_context *ctx);
 
-  ~be_visitor_context_svts (void);
+  ~be_visitor_context_svts ();
 
   virtual int visit_component (be_component *node);
   virtual int visit_connector (be_connector *node);
