@@ -24,13 +24,13 @@ class be_visitor_executor_exs_attr_init
 {
 public:
   be_visitor_executor_exs_attr_init (be_visitor_context *ctx);
-  ~be_visitor_executor_exs_attr_init (void);
+  ~be_visitor_executor_exs_attr_init ();
 
   virtual int visit_attribute (be_attribute *node);
 
   virtual int pre_process (be_decl *);
 
-  bool attr_generated (void) const;
+  bool attr_generated () const;
 
 private:
   bool semicolon_generated_;
