@@ -32,7 +32,7 @@ public:
   be_visitor_component_fwd_cdr_op_ch (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_component_fwd_cdr_op_ch (void);
+  ~be_visitor_component_fwd_cdr_op_ch ();
 
   /// visit forward declared component.
   virtual int visit_component_fwd (be_component_fwd *node);
