@@ -31,12 +31,12 @@ class be_visitor_connector_ami_exh
 public:
   be_visitor_connector_ami_exh (be_visitor_context *ctx);
 
-  ~be_visitor_connector_ami_exh (void);
+  ~be_visitor_connector_ami_exh ();
 
   virtual int visit_connector (be_connector *node);
 
 private:
-  void gen_entrypoint (void);
+  void gen_entrypoint ();
 };
 
 #endif /* _BE_CONNECTOR_CONNECTOR_AMI_EXH_H_ */
