@@ -30,7 +30,7 @@ public:
   be_visitor_enum_any_op_cs (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_enum_any_op_cs (void);
+  ~be_visitor_enum_any_op_cs ();
 
   /// visit enum
   virtual int visit_enum (be_enum *node);
