@@ -30,7 +30,7 @@ public:
   be_visitor_enum_cdr_op_ch (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_enum_cdr_op_ch (void);
+  ~be_visitor_enum_cdr_op_ch ();
 
   /// visit enum
   virtual int visit_enum (be_enum *node);
