@@ -10,7 +10,6 @@
  */
 //=============================================================================
 
-
 #ifndef _BE_VISITOR_ENUM_CDR_OP_CS_H_
 #define _BE_VISITOR_ENUM_CDR_OP_CS_H_
 
@@ -30,10 +29,10 @@ public:
   be_visitor_enum_cdr_op_cs (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_enum_cdr_op_cs (void);
+  ~be_visitor_enum_cdr_op_cs () override = default;
 
   /// visit enum
-  virtual int visit_enum (be_enum *node);
+  int visit_enum (be_enum *node) override;
 };
 
 #endif /* _BE_VISITOR_ENUM_CDR_OP_CS_H_ */
