@@ -27,7 +27,7 @@ class be_visitor_exception_any_op_ch : public be_visitor_scope
 
 public:
   be_visitor_exception_any_op_ch (be_visitor_context *ctx);
-  ~be_visitor_exception_any_op_ch (void);
+  ~be_visitor_exception_any_op_ch ();
 
   virtual int visit_exception (be_exception *node);
   virtual int visit_field (be_field *node);
