@@ -28,7 +28,7 @@ class be_visitor_exception_cdr_op_ch : public be_visitor_exception
 
 public:
   be_visitor_exception_cdr_op_ch (be_visitor_context *ctx);
-  ~be_visitor_exception_cdr_op_ch (void);
+  ~be_visitor_exception_cdr_op_ch ();
 
   virtual int visit_exception (be_exception *node);
 };
