@@ -28,7 +28,7 @@ class be_visitor_exception_cdr_op_cs : public be_visitor_exception
 
 public:
   be_visitor_exception_cdr_op_cs (be_visitor_context *ctx);
-  ~be_visitor_exception_cdr_op_cs (void);
+  ~be_visitor_exception_cdr_op_cs ();
 
   virtual int visit_exception (be_exception *node);
 
