@@ -25,7 +25,7 @@ class be_visitor_field_cdr_op_ch : public be_visitor_decl
 {
 public:
   be_visitor_field_cdr_op_ch (be_visitor_context *ctx);
-  ~be_visitor_field_cdr_op_ch (void);
+  ~be_visitor_field_cdr_op_ch ();
 
   virtual int visit_field (be_field *node);
 
