@@ -26,7 +26,7 @@ class be_visitor_home_svh : public be_visitor_scope
 public:
   be_visitor_home_svh (be_visitor_context *ctx);
 
-  ~be_visitor_home_svh (void);
+  ~be_visitor_home_svh ();
 
   virtual int visit_home (be_home *node);
   virtual int visit_operation (be_operation *node);
@@ -35,9 +35,9 @@ public:
   virtual int visit_finder (be_finder *node);
 
 private:
-  int gen_servant_class (void);
+  int gen_servant_class ();
 
-  void gen_entrypoint (void);
+  void gen_entrypoint ();
 
   /// Helper method passed to traverse_inheritance_graph(),
   /// collects supported operations and attributes.
