@@ -26,7 +26,7 @@ class be_visitor_interface_any_op_cs : public be_visitor_interface
 
 public:
   be_visitor_interface_any_op_cs (be_visitor_context *ctx);
-  ~be_visitor_interface_any_op_cs (void);
+  ~be_visitor_interface_any_op_cs ();
 
   virtual int visit_interface (be_interface *node);
   virtual int visit_component (be_component *node);
