@@ -28,7 +28,7 @@ class be_visitor_interface_cdr_op_ch : public be_visitor_interface
 
 public:
   be_visitor_interface_cdr_op_ch (be_visitor_context *ctx);
-  ~be_visitor_interface_cdr_op_ch (void);
+  ~be_visitor_interface_cdr_op_ch ();
 
   virtual int visit_interface (be_interface *node);
   virtual int visit_component (be_component *node);
