@@ -27,7 +27,7 @@ class be_visitor_facet_svth : public be_visitor_interface
 public:
   be_visitor_facet_svth (be_visitor_context *ctx);
 
-  ~be_visitor_facet_svth (void);
+  ~be_visitor_facet_svth ();
 
   virtual int visit_interface (be_interface *node);
 };
