@@ -24,7 +24,7 @@ class be_visitor_interface_sh : public be_visitor_interface
 {
 public:
   be_visitor_interface_sh (be_visitor_context *ctx);
-  ~be_visitor_interface_sh (void);
+  ~be_visitor_interface_sh ();
 
   virtual int visit_interface (be_interface *node);
   virtual int visit_component (be_component *node);
