@@ -27,7 +27,7 @@ public:
   be_visitor_interface_smart_proxy_cs (be_visitor_context *ctx);
 
   /// destructor
-  virtual ~be_visitor_interface_smart_proxy_cs (void);
+  virtual ~be_visitor_interface_smart_proxy_cs ();
 
   /// visit interface
   virtual int visit_interface (be_interface *node);
