@@ -25,7 +25,7 @@ class be_visitor_amh_rh_operation_sh : public be_visitor_operation
  public:
     be_visitor_amh_rh_operation_sh (be_visitor_context *ctx);
 
-    ~be_visitor_amh_rh_operation_sh (void);
+    ~be_visitor_amh_rh_operation_sh ();
 
     int visit_operation (be_operation *node);
 
