@@ -36,7 +36,7 @@ public:
   be_visitor_operation_exceptlist_ss (be_visitor_context * ctx);
 
   /// destructor
-  ~be_visitor_operation_exceptlist_ss (void);
+  ~be_visitor_operation_exceptlist_ss ();
 
   /// visit the operation
   int visit_operation (be_operation * node);
