@@ -33,7 +33,7 @@ public:
   be_visitor_operation_smart_proxy_ch (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_operation_smart_proxy_ch (void);
+  ~be_visitor_operation_smart_proxy_ch ();
 
   /// visit operation node.
   virtual int visit_operation (be_operation *node);
