@@ -26,13 +26,13 @@ class be_visitor_root_is : public be_visitor_root
 public:
   be_visitor_root_is (be_visitor_context *ctx);
 
-  ~be_visitor_root_is (void);
+  ~be_visitor_root_is ();
 
   virtual int visit_root (be_root *node);
 
 private:
   /// Open file and initialize stream.
-  int init (void);
+  int init ();
 };
 
 #endif /* _BE_VISITOR_ROOT_ROOT_IS_H_ */
