@@ -28,13 +28,13 @@ class be_visitor_root_svts : public be_visitor_root
 public:
   be_visitor_root_svts (be_visitor_context *ctx);
 
-  ~be_visitor_root_svts (void);
+  ~be_visitor_root_svts ();
 
   virtual int visit_root (be_root *node);
 
 private:
   /// Set the right context and make a visitor.
-  int init (void);
+  int init ();
 };
 
 #endif /* _BE_VISITOR_ROOT_ROOT_SVTS_H_ */
