@@ -32,7 +32,7 @@ public:
   be_visitor_sequence_any_op_ch (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_sequence_any_op_ch (void);
+  ~be_visitor_sequence_any_op_ch ();
 
   /// visit sequence
   virtual int visit_sequence (be_sequence *node);
