@@ -30,7 +30,7 @@ public:
   be_visitor_typedef (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_typedef (void);
+  ~be_visitor_typedef ();
 
   /// must be overridden
   virtual int visit_typedef (be_typedef *node);
