@@ -30,7 +30,7 @@ class be_visitor_union_any_op_cs : public be_visitor_union
 public:
   be_visitor_union_any_op_cs (be_visitor_context *ctx);
 
-  ~be_visitor_union_any_op_cs (void);
+  ~be_visitor_union_any_op_cs ();
 
   virtual int visit_union (be_union *node);
 
