@@ -31,7 +31,7 @@ public:
   be_visitor_union_discriminant_cs (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_union_discriminant_cs (void);
+  ~be_visitor_union_discriminant_cs ();
 
   /// visit an enum. Required to generate the typecode for an enum definition
   /// appearing side the union
