@@ -28,7 +28,7 @@ class be_visitor_union_branch_public_cs : public be_visitor_decl
 {
 public:
   be_visitor_union_branch_public_cs (be_visitor_context *ctx);
-  ~be_visitor_union_branch_public_cs (void);
+  ~be_visitor_union_branch_public_cs ();
 
   virtual int visit_union_branch (be_union_branch *node);
 
