@@ -34,7 +34,7 @@ public:
   be_visitor_valuetype_obv_ci (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_valuetype_obv_ci (void);
+  ~be_visitor_valuetype_obv_ci ();
 
   virtual int visit_valuetype (be_valuetype *node);
   virtual int visit_eventtype (be_eventtype *node);
