@@ -28,7 +28,7 @@ public:
   be_visitor_valuetype_sh (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_valuetype_sh (void);
+  ~be_visitor_valuetype_sh ();
 
   virtual int visit_valuetype (be_valuetype *node);
   virtual int visit_eventtype (be_eventtype *node);
