@@ -76,6 +76,7 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "be_util.h"
 
 #include "ace/OS_NS_stdio.h"
+#include "ace/OS_NS_stdlib.h"
 #include "ace/OS_NS_unistd.h"
 #include "ace/os_include/os_ctype.h"
 #include "ace/Lib_Find.h"
@@ -83,6 +84,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 extern long DRV_nfiles;
 extern char *DRV_files[];
 
+void process_long_option(long ac, char **av, long &i);
+
 // Push a file into the list of files to be processed
 void
 DRV_push_file (const char *s)
@@ -115,113 +118,86 @@ DRV_prep_cpp_arg (char *s)
 
 // Print a usage message and exit.
 void
-DRV_usage (void)
+DRV_usage ()
 {
   ACE_DEBUG ((LM_DEBUG,
-              ACE_TEXT ("%C: usage: %C [flag | file]*\n"),
+              ACE_TEXT ("%C: usage: %C [[flag|file] ...] [-- file ...]\n"),
               idl_global->prog_name (),
               idl_global->prog_name ()));
 
   ACE_DEBUG ((LM_DEBUG,
-              ACE_TEXT ("Legal flags:\n")));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -A...\t\t\tlocal implementation-specific escape\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -Cw\t\t\tWarning if identifier spellings differ ")
-      ACE_TEXT ("only in case (default is error)\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -Ce\t\t\tError if identifier spellings differ ")
-      ACE_TEXT ("only in case (default)\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -ae\t\t\tError if anonymous type is seen ")
-      ACE_TEXT ("(default)\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -aw\t\t\tWarning if anonymous type is seen ")
-      ACE_TEXT ("(default is error)\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -as\t\t\tSilences the anonymous type diagnostic ")
-      ACE_TEXT ("(default is error)\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -d\t\t\tOutputs (to stdout) a dump of the AST\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -Dname[=value]\t\tdefines name for preprocessor\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -E\t\t\truns preprocessor only, prints on stdout\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -Idir\t\t\tincludes dir in search path for preprocessor\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -t\t\t\tTemporary directory to be used")
-      ACE_TEXT (" by the IDL compiler.\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -u\t\t\tprints usage message and exits\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -Uname\t\t\tundefines name for preprocessor\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -v\t\t\ttraces compilation stages\n")
-   ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -V\t\t\tprints version info then exits\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -w\t\t\tsuppresses IDL compiler warning messages\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -Wp,<arg1,...,argn>\tpasses args to preprocessor\n")
-    ));
-  ACE_DEBUG ((
-      LM_DEBUG,
-      ACE_TEXT (" -Yp,path\t\tdefines location of preprocessor\n")
-    ));
+    ACE_TEXT ("Legal flags:\n")
+    ACE_TEXT (" -h | --help | -u\tPrint this list and exit successfully\n")
+    ACE_TEXT (" -A...\t\t\tlocal implementation-specific escape\n")
+    ACE_TEXT (" -Cw\t\t\tWarning if identifier spellings differ ")
+    ACE_TEXT ("only in case (default is error)\n")
+    ACE_TEXT (" -Ce\t\t\tError if identifier spellings differ ")
+    ACE_TEXT ("only in case (default)\n")
+    ACE_TEXT (" -ae\t\t\tError if anonymous type is seen ")
+    ACE_TEXT ("(default)\n")
+    ACE_TEXT (" -aw\t\t\tWarning if anonymous type is seen ")
+    ACE_TEXT ("(default is error)\n")
+    ACE_TEXT (" -as\t\t\tSilences the anonymous type diagnostic ")
+    ACE_TEXT ("(default is error)\n")
+    ACE_TEXT (" -d | --dump\t\tPrints a dump of the AST and exits\n")
+    ACE_TEXT (" -Dname[=value]\t\tdefines name for preprocessor\n")
+    ACE_TEXT (" -E\t\t\truns preprocessor only, prints on stdout\n")
+    ACE_TEXT (" -Idir\t\t\tincludes dir in search path for preprocessor\n")
+    ACE_TEXT (" -t\t\t\tTemporary directory to be used")
+    ACE_TEXT (" by the IDL compiler.\n")
+    ACE_TEXT (" -Uname\t\t\tundefines name for preprocessor\n")
+    ACE_TEXT (" -v\t\t\ttraces compilation stages\n")
+    ACE_TEXT (" -V | --version\t\tprints version info then exits\n")
+    ACE_TEXT (" -w\t\t\tsuppresses IDL compiler warning messages\n")
+    ACE_TEXT (" -Wp,<arg1,...,argn>\tpasses args to preprocessor\n")
+    ACE_TEXT (" -Yp,path\t\tdefines location of preprocessor\n")
+    ACE_TEXT (" --idl-version VERSION\tSet the version of IDL to use\n")
+    ACE_TEXT (" --default-idl-version\tPrint the default IDL version and exit\n")
+    ACE_TEXT (" --list-idl-versions\tPrint IDL versions supported and exit\n")
+    ACE_TEXT (" --syntax-only\t\tJust check the syntax, do not create files\n")
+    ACE_TEXT (" --bison-trace\t\tEnable Bison Tracing (sets yydebug to 1)\n")
+    ACE_TEXT (" --dump-builtins\tDump the compiler and user defined IDL.\n")
+    ACE_TEXT (" --just-dump-builtins\tJust dump the compiler defined IDL and exit.\n")
+    ACE_TEXT (" --unknown-annotations ARG\t")
+      ACE_TEXT ("Set reaction to unknown annotations. ARG must be one of the following:\n")
+    ACE_TEXT ("\t\t\t\twarn-once\tThe default, warn once per unique local name\n")
+    ACE_TEXT ("\t\t\t\twarn-all\tWarn for all unknown annotations\n")
+    ACE_TEXT ("\t\t\t\terror\t\tCauses the process to exit with a failed return status\n")
+    ACE_TEXT ("\t\t\t\tignore\t\tDon't report unknown annotations\n")
+  ));
 
   be_util::usage ();
 }
 
+#define UNKNOWN_OPTION \
+  ACE_ERROR (( \
+      LM_ERROR, \
+      ACE_TEXT ("IDL: I don't understand") \
+      ACE_TEXT (" the '%s' option\n"), \
+      ACE_TEXT_CHAR_TO_TCHAR (av[i]) \
+    )); \
+  idl_global->parse_args_exit (1); \
+  return;
+
 // Parse arguments on command line
 void
 DRV_parse_args (long ac, char **av)
 {
   ACE_CString buffer;
-  char *s = 0;
+  char *s = nullptr;
   long i;
   bool has_space = false;
 
+  // After -- process all arguments as files
+  bool just_files = false;
+
   FE_store_env_include_paths ();
   DRV_cpp_init ();
   idl_global->set_prog_name (av[0]);
 
   for (i = 1; i < ac; i++)
     {
-      if (av[i][0] == '-')
+      if (!just_files && av[i][0] == '-')
         {
           idl_global->append_idl_flag (av[i]);
 
@@ -234,10 +210,9 @@ DRV_parse_args (long ac, char **av)
                   ACE_TEXT ("IDL: Space between dash and option ")
                   ACE_TEXT ("letters not allowed\n")
                 ));
+              idl_global->parse_args_exit (1);
+              return;
 
-              ++i;
-              idl_global->set_err_count (idl_global->err_count () + 1);
-              break;
             case 'A':
               if (av[i][2] == '\0')
                 {
@@ -253,12 +228,9 @@ DRV_parse_args (long ac, char **av)
                           ACE_TEXT ("IDL: incorrect use of ")
                           ACE_TEXT ("the -A option\n")
                         ));
+                      idl_global->parse_args_exit (1);
+                      return;
 
-                      idl_global->set_compile_flags (
-                                      idl_global->compile_flags ()
-                                      | IDL_CF_ONLY_USAGE
-                                    );
-                      break;
                     }
                 }
               else
@@ -287,13 +259,8 @@ DRV_parse_args (long ac, char **av)
                 }
               else
                 {
-                  ACE_ERROR ((
-                      LM_ERROR,
-                      ACE_TEXT ("IDL: I don't understand")
-                      ACE_TEXT (" the '%s' option\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR (av[i])
-                    ));
-                 }
+                  UNKNOWN_OPTION;
+                }
 
                break;
             // Temp directory for the IDL compiler to keep its files.
@@ -306,17 +273,7 @@ DRV_parse_args (long ac, char **av)
                 }
               else
                 {
-                  ACE_ERROR ((
-                      LM_ERROR,
-                      ACE_TEXT ("IDL: I don't understand")
-                      ACE_TEXT (" the '%s' option\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR (av[i])
-                    ));
-
-                  idl_global->set_compile_flags (
-                                  idl_global->compile_flags ()
-                                  | IDL_CF_ONLY_USAGE
-                                );
+                  UNKNOWN_OPTION;
                 }
 
               break;
@@ -343,18 +300,7 @@ DRV_parse_args (long ac, char **av)
                     }
                   else
                     {
-                      ACE_ERROR ((
-                          LM_ERROR,
-                          ACE_TEXT ("IDL: I don't understand")
-                          ACE_TEXT (" the '%s' option\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR (av[i])
-                        ));
-
-                      idl_global->set_compile_flags (
-                                      idl_global->compile_flags ()
-                                      | IDL_CF_ONLY_USAGE
-                                    );
-                      break;
+                      UNKNOWN_OPTION;
                     }
                 }
               else
@@ -374,12 +320,19 @@ DRV_parse_args (long ac, char **av)
 
               break;
             case 'E':
+              if (av[i][2] != '\0')
+                {
+                  UNKNOWN_OPTION;
+                }
               idl_global->set_compile_flags (idl_global->compile_flags () |
                                              IDL_CF_ONLY_PREPROC);
               break;
             case 'V':
-              idl_global->set_compile_flags (idl_global->compile_flags () |
-                                             IDL_CF_VERSION);
+              if (av[i][2] != '\0')
+                {
+                  UNKNOWN_OPTION;
+                }
+              idl_global->print_version ();
               break;
             case 'W':
               if (av[i][2] == '\0')
@@ -391,18 +344,7 @@ DRV_parse_args (long ac, char **av)
                     }
                   else
                     {
-                      ACE_ERROR ((
-                          LM_ERROR,
-                          ACE_TEXT ("IDL: I don't understand")
-                          ACE_TEXT (" the '%s' option\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR (av[i])
-                        ));
-
-                      idl_global->set_compile_flags (
-                                      idl_global->compile_flags ()
-                                      | IDL_CF_ONLY_USAGE
-                                    );
-                      break;
+                      UNKNOWN_OPTION;
                     }
                 }
               else
@@ -417,12 +359,9 @@ DRV_parse_args (long ac, char **av)
                       LM_ERROR,
                       ACE_TEXT ("IDL: Incorrect use of -W option\n")
                     ));
+                  idl_global->parse_args_exit (1);
+                  return;
 
-                  idl_global->set_compile_flags (
-                                  idl_global->compile_flags ()
-                                  | IDL_CF_ONLY_USAGE
-                                );
-                  break;
                 case 'p':
                   if (*(s + 1) == ',')
                     {
@@ -450,18 +389,7 @@ DRV_parse_args (long ac, char **av)
                     }
                   else
                     {
-                      ACE_ERROR ((
-                          LM_ERROR,
-                          ACE_TEXT ("IDL: I don't understand")
-                          ACE_TEXT (" the '%s' option\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR (av[i])
-                        ));
-
-                      idl_global->set_compile_flags (
-                                      idl_global->compile_flags ()
-                                      | IDL_CF_ONLY_USAGE
-                                    );
-                      break;
+                      UNKNOWN_OPTION;
                     }
                 }
               else
@@ -484,11 +412,8 @@ DRV_parse_args (long ac, char **av)
                             ACE_TEXT ("IDL: I don't understand")
                             ACE_TEXT (" the '-Y' option\n")
                           ));
-
-                        idl_global->set_compile_flags (
-                                        idl_global->compile_flags ()
-                                        | IDL_CF_ONLY_USAGE
-                                      );
+                        idl_global->parse_args_exit (1);
+                        return;
                       }
 
                     break;
@@ -499,27 +424,30 @@ DRV_parse_args (long ac, char **av)
                         ACE_TEXT (" %s with the '-Y' option\n"),
                         ACE_TEXT_CHAR_TO_TCHAR (s)
                       ));
-
-                    idl_global->set_compile_flags (
-                                    idl_global->compile_flags ()
-                                    | IDL_CF_ONLY_USAGE
-                                  );
-                   break;
+                    idl_global->parse_args_exit (1);
+                    return;
                 }
               break;
             case 'd':
-              idl_global->set_compile_flags (idl_global->compile_flags ()
-                                             | IDL_CF_DUMP_AST);
-              break;
-            case 'u':
-              idl_global->set_compile_flags (idl_global->compile_flags ()
-                                             | IDL_CF_ONLY_USAGE);
+              if (av[i][2] != '\0')
+                {
+                  UNKNOWN_OPTION;
+                }
+              idl_global->dump_ast ();
               break;
             case 'v':
+              if (av[i][2] != '\0')
+                {
+                  UNKNOWN_OPTION;
+                }
               idl_global->set_compile_flags (idl_global->compile_flags ()
                                              | IDL_CF_INFORMATIVE);
               break;
             case 'w':
+              if (av[i][2] != '\0')
+                {
+                  UNKNOWN_OPTION;
+                }
               idl_global->set_compile_flags (idl_global->compile_flags ()
                                              | IDL_CF_NOWARNINGS);
               break;
@@ -537,34 +465,54 @@ DRV_parse_args (long ac, char **av)
                 }
               else
                 {
-                  ACE_ERROR ((
-                      LM_ERROR,
-                      ACE_TEXT ("IDL: I don't understand the '%s' option\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR (av[i])
-                    ));
-
-                  idl_global->set_compile_flags (
-                                  idl_global->compile_flags ()
-                                  | IDL_CF_ONLY_USAGE
-                                );
+                  UNKNOWN_OPTION;
                 }
 
               break;
+
+            case 'u': // Old Help Option
+              if (av[i][2] != '\0')
+                {
+                  UNKNOWN_OPTION;
+                }
+              idl_global->print_help ();
+              break;
+
+            case 'h': // Short Help Option, else let be_global process it
+              if (av[i][2] == '\0') {
+                idl_global->print_help ();
+              } else {
+                be_global->parse_args (i, av);
+              }
+              break;
+
+            case '-': // -- or Long Options
+              if (av[i][2] == '\0')
+                {
+                  just_files = true; // Treat the following arguments as files
+                }
+              else
+                {
+                  process_long_option(ac, av, i);
+                }
+              break;
+
             default:
               be_global->parse_args (i, av);
-              break;
             } // End of switch (av[i][1])
         } // End of IF (av[i][0] == '-')
       else
         {
           DRV_push_file (av[i]);
         }
+
+      if (idl_global->parse_args_exit_) return; // Catch Exits
     } // End of FOR (i = 1; i < ac; i++)
 
   be_util::arg_post_proc ();
 
   // Make sure the output directory is valid.
-  if (idl_global->temp_dir () == 0)
+  if (idl_global->temp_dir () == nullptr)
     {
       ACE_TCHAR tmpdir[MAXPATHLEN + 1];
 
@@ -614,3 +562,149 @@ DRV_parse_args (long ac, char **av)
 
   DRV_cpp_post_init ();
 }
+
+void
+print_idl_versions()
+{
+  ACE_DEBUG ((LM_INFO,
+    ACE_TEXT ("These are the valid IDL versions this compiler will accept:\n")
+    ));
+  for (int v = 1; v < IDL_VERSION_COUNT; v++)
+    {
+      ACE_DEBUG ((LM_INFO, ACE_TEXT ("%C\n"),
+        IdlVersion (static_cast<SpecificIdlVersion>(v)).to_string ()
+        ));
+    }
+}
+
+void
+process_long_option(long ac, char **av, long &i)
+{
+  const char *long_option = av[i] + 2;
+  bool no_more_args = i + 1 >= ac;
+  if (!ACE_OS::strcmp (long_option, "idl-version"))
+    {
+      bool invalid_version = no_more_args;
+      if (no_more_args)
+        {
+          ACE_ERROR ((LM_ERROR,
+            ACE_TEXT ("--idl-version is missing a required argument, ")
+            ACE_TEXT ("the IDL version to use.\n")
+            ));
+        }
+      else
+        {
+          idl_global->idl_version_.from_string (av[++i]);
+          invalid_version = !idl_global->idl_version_.is_valid ();
+          if (invalid_version)
+            {
+              ACE_ERROR ((LM_ERROR,
+                ACE_TEXT ("\"%C\" is not a valid IDL version supported\n"),
+                av[i]
+                ));
+            }
+        }
+      if (invalid_version)
+        {
+          print_idl_versions ();
+          idl_global->parse_args_exit (1);
+        }
+    }
+  else if (!ACE_OS::strcmp (long_option, "syntax-only"))
+    {
+      idl_global->syntax_only_ = true;
+    }
+  else if (!ACE_OS::strcmp (long_option, "default-idl-version"))
+    {
+      ACE_DEBUG ((LM_INFO, ACE_TEXT ("%C\n"),
+        idl_global->default_idl_version_.to_string ()));
+      idl_global->parse_args_exit (0);
+    }
+  else if (!ACE_OS::strcmp (long_option, "list-idl-versions"))
+    {
+      print_idl_versions ();
+      idl_global->parse_args_exit (0);
+    }
+  else if (!ACE_OS::strcmp (long_option, "help"))
+    {
+      idl_global->print_help ();
+    }
+  else if (!ACE_OS::strcmp (long_option, "bison-trace"))
+    {
+      FE_yydebug (true);
+    }
+  else if (!ACE_OS::strcmp (long_option, "version"))
+    {
+      idl_global->print_version ();
+    }
+  else if (!ACE_OS::strcmp (long_option, "dump-builtins"))
+    {
+      idl_global->dump_builtins_ = true;
+      idl_global->dump_ast ();
+    }
+  else if (!ACE_OS::strcmp (long_option, "just-dump-builtins"))
+    {
+      // Don't use dump_ast because we need to dump before parsing any files.
+      idl_global->dump_builtins_ = true;
+      idl_global->just_dump_builtins_ = true;
+    }
+  else if (!ACE_OS::strcmp (long_option, "dump"))
+    {
+      idl_global->dump_ast ();
+    }
+  else if (!ACE_OS::strcmp (long_option, "unknown-annotations"))
+    {
+      bool invalid_argument = no_more_args;
+      if (no_more_args)
+        {
+          ACE_ERROR ((LM_ERROR,
+            ACE_TEXT ("--unknown-annotations is missing its required argument.")
+            ));
+        }
+      else
+        {
+          i++;
+          if (!ACE_OS::strcmp (av[i], "warn-once"))
+            {
+              idl_global->unknown_annotations_ =
+                IDL_GlobalData::UNKNOWN_ANNOTATIONS_WARN_ONCE;
+            }
+          else if (!ACE_OS::strcmp (av[i], "warn-all"))
+            {
+              idl_global->unknown_annotations_ =
+                IDL_GlobalData::UNKNOWN_ANNOTATIONS_WARN_ALL;
+            }
+          else if (!ACE_OS::strcmp (av[i], "error"))
+            {
+              idl_global->unknown_annotations_ =
+                IDL_GlobalData::UNKNOWN_ANNOTATIONS_ERROR;
+            }
+          else if (!ACE_OS::strcmp (av[i], "ignore"))
+            {
+              idl_global->unknown_annotations_ =
+                IDL_GlobalData::UNKNOWN_ANNOTATIONS_IGNORE;
+            }
+          else
+            {
+              invalid_argument = true;
+              ACE_ERROR ((LM_ERROR,
+                ACE_TEXT ("\"%C\" is not a valid argument.\n"),
+                av[i]
+                ));
+            }
+        }
+      if (invalid_argument)
+        {
+          ACE_ERROR ((LM_ERROR,
+            ACE_TEXT ("Use either \"warn-once\", \"warn-all\", ")
+            ACE_TEXT ("\"error\" or \"ignore\".\n"),
+            av[i]
+            ));
+          idl_global->parse_args_exit (1);
+        }
+    }
+  else
+    {
+      be_global->parse_args (i, av);
+    }
+}
