@@ -68,6 +68,7 @@ class AST_Root;
 class AST_Native;
 class AST_Param_Holder;
 class AST_Fixed;
+class AST_Annotation_Decl;
 
 /**
  * @class ast_visitor
@@ -84,7 +85,7 @@ class AST_Fixed;
 class TAO_IDL_FE_Export ast_visitor
 {
 public:
-  virtual ~ast_visitor (void);
+  virtual ~ast_visitor ();
 
   virtual int visit_decl (AST_Decl *d) = 0;
   virtual int visit_scope (UTL_Scope *node) = 0;
@@ -138,10 +139,11 @@ public:
   virtual int visit_native (AST_Native *node) = 0;
   virtual int visit_valuebox (AST_ValueBox *node) = 0;
   virtual int visit_fixed (AST_Fixed *node);
+  virtual int visit_annotation_decl (AST_Annotation_Decl *node);
 
 protected:
   // For abstract class.
-  ast_visitor (void);
+  ast_visitor ();
 };
 
 #endif /* TAO_IDL_FE_DLL_AST_VISITOR_H */
