@@ -117,8 +117,7 @@ private:
             const char *                        str
         ) : m_sc(sc), m_str(str) {}
         bool operator()(
-            pair<const CCS::AssetType, Thermometer_impl *> & p
-        ) const
+            pair<const CCS::AssetType, Thermometer_impl *> & p) const
         {
             switch (m_sc) {
             case CCS::Controller::LOCATION:
