@@ -18,5 +18,5 @@ test_i::method (CORBA::ULong request_number)
 void
 test_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
