@@ -43,9 +43,7 @@ class Consumer_Signal_Handler;
  */
 class Consumer_Handler
 {
-
 public:
-  // = Initialization and termination methods.
   /// Constructor.
   Consumer_Handler (void);
 
@@ -74,7 +72,7 @@ public:
   Callback_Quoter::Consumer_var consumer_var_;
 
   /// This method gives the reactor pointer.
-  ACE_Reactor* reactor_used (void) const;
+  ACE_Reactor* reactor_used () const;
 
   /// Flag which notes whether the consumer has got registered with the
   /// Notifier-server.
