@@ -34,8 +34,6 @@ template <class Servant>
 class Server
 {
 public:
-  // = Initialization and termination methods.
-
   /// Constructor.
   Server (void);
 
@@ -95,8 +93,6 @@ template <class InterfaceObj, class Var>
 class Client
 {
 public:
-
-  // = Initialization and termination methods.
   /// Constructor.
   Client (void);
 
@@ -110,7 +106,7 @@ public:
   InterfaceObj *operator-> () { return server_.in ();};
 
   /// Returns the shutdown flag.
-  int shutdown (void );
+  int shutdown ();
 
   /// Fills in the shutdwon flag.
   void shutdown (int);
