@@ -30,7 +30,6 @@ class UDP_PerformanceClient
   //    This class wrapps the client functionality into one class
   //
 public:
-  // = Initialization and termination methods.
   /// Constructor
   UDP_PerformanceClient (CORBA::ORB_ptr orb,
                          UDP_ptr udp,
@@ -42,7 +41,7 @@ public:
 
 private:
   // Runs in a separate thread.
-  virtual int svc (void );
+  virtual int svc ();
 
 private:
   CORBA::ORB_var orb_;
