@@ -7,13 +7,11 @@ UDP_i::UDP_i (void)
   : messages_count_ (0)
   , wrong_messages_count_ (0)
 {
-  // no-op
 }
 
 // Destructor
 UDP_i::~UDP_i (void)
 {
-  // no-op
 }
 
 // Set the ORB pointer.
@@ -116,7 +114,7 @@ UDP_i::shutdown (void)
   try
     {
       // Instruct the ORB to shutdown.
-      this->orb_->shutdown (0);
+      this->orb_->shutdown (false);
     }
   catch (const CORBA::Exception& ex)
     {
