@@ -35,13 +35,12 @@ typedef Job_i** JOB_LIST;
 class Builder : public ACE_Service_Object
 {
  public:
-  /// = Initialization and termination
   Builder ();
   ~Builder ();
 
   /// = Service_Object virtual method overloads.
   virtual int init (int argc, ACE_TCHAR *argv[]);
-  virtual int fini (void);
+  virtual int fini ();
 
   /// = List access
   int poa_list (POA_LIST& poa_list);
