@@ -12,7 +12,6 @@
 #define JOB_I_H
 
 #include "JobS.h"
-#include "activity_export.h"
 #include "ace/SString.h"
 #include "ace/Arg_Shifter.h"
 
@@ -21,7 +20,7 @@
  *
  * @brief Implements a Job that performs some cpu bound work.
  */
-class activity_Export Job_i : public POA_Job
+class Job_i : public POA_Job
 {
  public:
   /// Constructor
