@@ -22,7 +22,7 @@ public:
 
   virtual int init (int argc, ACE_TCHAR *argv[]);
 
-  virtual int fini (void);
+  virtual int fini ();
 
   virtual CORBA::Object_ptr create_object (CORBA::ORB_ptr orb,
                                            int argc,
@@ -37,9 +37,10 @@ private:
   ACE_Auto_Ptr<ImR_Activator_ORB_Runner> runner_;
 
 private:
-  // Disallow copying and assignment.
-  ImR_Activator_Loader (const ImR_Activator_Loader &);
-  ImR_Activator_Loader &operator = (const ImR_Activator_Loader &);
+  ImR_Activator_Loader (const ImR_Activator_Loader &) = delete;
+  ImR_Activator_Loader &operator = (const ImR_Activator_Loader &) = delete;
+  ImR_Activator_Loader (ImR_Activator_Loader &&) = delete;
+  ImR_Activator_Loader &operator = (ImR_Activator_Loader &&) = delete;
 };
 
 ACE_FACTORY_DECLARE (Activator, ImR_Activator_Loader)
