@@ -51,14 +51,14 @@ AsyncAccessManager::started_running (void)
 }
 
 bool
-AsyncAccessManager::is_terminating (void) const
+AsyncAccessManager::is_terminating () const
 {
   return this->status_ == ImplementationRepository::AAM_ACTIVE_TERMINATE ||
     remove_on_death_rh_ != 0;
 }
 
 bool
-AsyncAccessManager::is_running (void) const
+AsyncAccessManager::is_running () const
 {
   if (this->info_->is_mode (ImplementationRepository::PER_CLIENT))
     {
@@ -203,6 +203,13 @@ AsyncAccessManager::remote_state (ImplementationRepository::AAM_Status state)
 void
 AsyncAccessManager::final_state (bool active)
 {
+  if (ImR_Locator_i::debug () > 5)
+    {
+      ORBSVCS_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::final_state - ")
+                      ACE_TEXT ("server <%C> active <%d> status <%C> waiters <%d>\n"),
+                      this, info_->ping_id (), active, status_name (this->status_), this->rh_list_.size()));
+    }
   bool const success = this->status_ == ImplementationRepository::AAM_SERVER_READY;
   this->info_.edit (active)->started (success);
   this->retries_ = this->info_->start_limit_;
@@ -223,9 +230,9 @@ AsyncAccessManager::final_state (bool active)
       if (ImR_Locator_i::debug () > 5)
         {
           ORBSVCS_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::final_state ")
-                          ACE_TEXT ("removing this from map, server <%C>\n"),
-                          this, info_->ping_id ()));
+                          ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::final_state - ")
+                          ACE_TEXT ("removing this from map, server <%C> remove_on_death_rh_ <%@>\n"),
+                          this, info_->ping_id (), this->remove_on_death_rh_));
         }
       if (this->remove_on_death_rh_ != 0)
         {
@@ -240,58 +247,97 @@ AsyncAccessManager::final_state (bool active)
 }
 
 void
-AsyncAccessManager::notify_waiters (void)
+AsyncAccessManager::notify_waiter (ImR_ResponseHandler *rh)
 {
-  for (size_t i = 0; i < this->rh_list_.size(); i++)
+  if (this->status_ == ImplementationRepository::AAM_SERVER_READY)
     {
-      ImR_ResponseHandler *rh = this->rh_list_[i];
-      if (rh != 0)
+      if (this->info_->is_mode (ImplementationRepository::PER_CLIENT))
         {
-          if (this->status_ == ImplementationRepository::AAM_SERVER_READY)
+          if (ImR_Locator_i::debug () > 5)
             {
-              if (this->info_->is_mode (ImplementationRepository::PER_CLIENT))
-                {
-                  rh->send_ior (this->partial_ior_.c_str());
-                }
-              else
-                {
-                  rh->send_ior (this->info_->partial_ior.c_str());
-                }
+              ORBSVCS_DEBUG ((LM_DEBUG,
+                              ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::notify_waiter - ")
+                              ACE_TEXT ("For unique server <%C> reporting back IOR <%C>\n"),
+                              this, info_->ping_id (), this->partial_ior_.c_str()));
             }
-          else
+          rh->send_ior (this->partial_ior_.c_str());
+        }
+      else
+        {
+          if (ImR_Locator_i::debug () > 5)
             {
-              try
-                {
-                  switch (this->status_)
-                    {
-                    case ImplementationRepository::AAM_NO_ACTIVATOR:
-                      throw ImplementationRepository::CannotActivate
-                        ("No activator registered for server.");
-                    case ImplementationRepository::AAM_NOT_MANUAL:
-                      throw ImplementationRepository::CannotActivate
-                        ("Cannot implicitly activate MANUAL server.");
-                    case ImplementationRepository::AAM_NO_COMMANDLINE:
-                      throw ImplementationRepository::CannotActivate
-                        ("No command line registered for server.");
-                    case ImplementationRepository::AAM_RETRIES_EXCEEDED:
-                      throw ImplementationRepository::CannotActivate
-                        ("Restart attempt count exceeded.");
-                    case  ImplementationRepository::AAM_ACTIVE_TERMINATE:
-                      throw ImplementationRepository::CannotActivate
-                        ("Server terminating.");
-                    default: {
-                      ACE_CString reason = ACE_CString ("AAM_Status is ") +
-                        status_name (this->status_);
-                      throw ImplementationRepository::CannotActivate (reason.c_str());
-                    }
-                    }
-                }
-              catch (const CORBA::Exception &ex)
-                {
-                  rh->send_exception (ex._tao_duplicate());
-                }
+              ORBSVCS_DEBUG ((LM_DEBUG,
+                              ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::notify_waiter - ")
+                              ACE_TEXT ("For server <%C> reporting back IOR <%C>\n"),
+                              this, info_->ping_id (), this->info_->partial_ior.c_str()));
+            }
+          rh->send_ior (this->info_->partial_ior.c_str());
+        }
+    }
+  else
+    {
+      try
+        {
+          switch (this->status_)
+            {
+            case ImplementationRepository::AAM_NO_ACTIVATOR:
+              throw ImplementationRepository::CannotActivate
+                ("No activator registered for server.");
+            case ImplementationRepository::AAM_NOT_MANUAL:
+              throw ImplementationRepository::CannotActivate
+                ("Cannot implicitly activate MANUAL server.");
+            case ImplementationRepository::AAM_NO_COMMANDLINE:
+              throw ImplementationRepository::CannotActivate
+                ("No command line registered for server.");
+            case ImplementationRepository::AAM_RETRIES_EXCEEDED:
+              throw ImplementationRepository::CannotActivate
+                ("Restart attempt count exceeded.");
+            case  ImplementationRepository::AAM_ACTIVE_TERMINATE:
+              throw ImplementationRepository::CannotActivate
+                ("Server terminating.");
+            default: {
+              ACE_CString reason = ACE_CString ("AAM_Status is ") +
+                status_name (this->status_);
+              throw ImplementationRepository::CannotActivate (reason.c_str());
+              }
             }
         }
+      catch (const CORBA::Exception &ex)
+        {
+          rh->send_exception (ex._tao_duplicate());
+        }
+    }
+}
+
+void
+AsyncAccessManager::notify_waiters (void)
+{
+  if (ImR_Locator_i::debug () > 4)
+    {
+      this->report ("notify_waiters");
+    }
+
+  for (size_t i = 0; i < this->rh_list_.size(); i++)
+    {
+      // Sending the IOR through to the response handler could trigger
+      // an exception which we should catch here and log. This way when
+      // we have multiple waiters we do inform them all and not abort
+      // after the first exception
+      try
+      {
+        ImR_ResponseHandler *rh = this->rh_list_[i];
+        if (rh != 0)
+          {
+            this->notify_waiter (rh);
+          }
+      }
+      catch (const CORBA::Exception& ex)
+      {
+        if (ImR_Locator_i::debug () > 1)
+          {
+            ex._tao_print_exception ("AsyncAccessManager::notify_waiters");
+          }
+      }
     }
   this->rh_list_.clear ();
 }
@@ -316,8 +362,6 @@ AsyncAccessManager::status_name (ImplementationRepository::AAM_Status s)
       return "INIT";
     case ImplementationRepository::AAM_SERVER_STARTED_RUNNING:
       return "SERVER_STARTED_RUNNING";
-    case ImplementationRepository::AAM_ACTIVATION_SENT:
-      return "ACTIVATION_SENT";
     case ImplementationRepository::AAM_WAIT_FOR_RUNNING:
       return "WAIT_FOR_RUNNING";
     case ImplementationRepository::AAM_WAIT_FOR_PING:
@@ -348,7 +392,7 @@ AsyncAccessManager::status_name (ImplementationRepository::AAM_Status s)
 }
 
 ImplementationRepository::AAM_Status
-AsyncAccessManager::status (void) const
+AsyncAccessManager::status () const
 {
   return this->status_;
 }
@@ -368,24 +412,25 @@ void
 AsyncAccessManager::update_status (ImplementationRepository::AAM_Status s)
 {
   this->status (s);
+  if (ImR_Locator_i::debug () > 4)
+    {
+      this->report ("update_status");
+    }
   this->info_.notify_remote_access (s);
 }
 
 void
-AsyncAccessManager::activator_replied (bool success, int pid)
+AsyncAccessManager::activator_replied_start_running (bool success, int pid)
 {
+  if (ImR_Locator_i::debug () > 4)
+    {
+      this->report ("activator_replied_start_running");
+    }
+
   if (success)
     {
-      if (pid == 0)
+      if (pid != 0)
         {
-          this->update_status (ImplementationRepository::AAM_WAIT_FOR_RUNNING);
-        }
-      else
-        {
-          if (ImR_Locator_i::debug () > 4)
-            {
-              this->report ("activator_replied");
-            }
           this->update_status (ImplementationRepository::AAM_SERVER_READY);
           this->info_.edit()->pid = pid;
           this->final_state ();
@@ -420,11 +465,30 @@ AsyncAccessManager::server_is_shutting_down (void)
 {
   if (ImR_Locator_i::debug () > 4)
     {
-      this->report ("server_is_shutting_down");
+      this->report ("server_is_shutting_down-start");
     }
+  // We are informed directly by the server that it is shutting down. This doesn't
+  // imply that the server is dead at this point, there can be some time between
+  // the POA destroy and the server process exit so we have to wait for the death
+  // of the process before we can mark this server as dead
   this->prev_pid_ = this->info_->pid;
-  this->status (ImplementationRepository::AAM_SERVER_DEAD);
-  this->final_state ();
+  if (this->info_->death_notify)
+    {
+      // We get a death notify of the activator so we can wait on the death
+      // of the process
+      this->status (ImplementationRepository::AAM_WAIT_FOR_DEATH);
+    }
+  else
+    {
+      // We don't get a death notify of the activator so we have to assume at
+      // this point the server is death
+      this->status (ImplementationRepository::AAM_SERVER_DEAD);
+      this->final_state ();
+    }
+  if (ImR_Locator_i::debug () > 4)
+    {
+      this->report ("server_is_shutting_down-end");
+    }
 }
 
 void
@@ -490,23 +554,38 @@ AsyncAccessManager::notify_child_death (int pid)
   if (ImR_Locator_i::debug () > 4)
     {
       ORBSVCS_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("(%P|%t) AsyncAccessManager(%@), child death, pid <%d>, status <%C> ")
+                      ACE_TEXT ("(%P|%t) AsyncAccessManager(%@), notify_child_death, server <%C> pid <%d> status <%C> ")
                       ACE_TEXT ("this info_.pid <%d> prev_pid <%d> waiter count <%d>\n"),
-                      this, pid, status_name (status_),
-                      this->info_->pid, this->prev_pid_, this->rh_list_.size() ));
+                      this, info_->ping_id (), pid, status_name (status_),
+                      this->info_->pid, this->prev_pid_, this->rh_list_.size()));
     }
   if (this->info_->pid == pid || this->prev_pid_ == pid)
     {
-      if (this->status_ == ImplementationRepository::AAM_WAIT_FOR_DEATH &&
+      if ((this->status_ == ImplementationRepository::AAM_WAIT_FOR_DEATH) &&
           this->rh_list_.size() > 0)
         {
-          this->send_start_request ();
-          return true;
+          // When we have successfully made another start request we just let the
+          // waiters wait on the result of the new start request
+          if (this->send_start_request ())
+            {
+              return true;
+            }
         }
       this->status (ImplementationRepository::AAM_SERVER_DEAD);
       this->final_state ();
       return true;
     }
+  else
+    {
+      if (ImR_Locator_i::debug () > 1)
+        {
+          ORBSVCS_ERROR ((LM_ERROR,
+                          ACE_TEXT ("(%P|%t) AsyncAccessManager(%@), notify_child_death, server <%C> pid <%d> does not match ")
+                          ACE_TEXT ("this info_.pid <%d> prev_pid <%d>\n"),
+                          this, info_->ping_id (), pid,
+                          this->info_->pid, this->prev_pid_));
+        }
+    }
   return false;
 }
 
@@ -518,8 +597,18 @@ AsyncAccessManager::listener_disconnected (void)
       this->report ("listener_disconnected");
     }
 
-  this->status (ImplementationRepository::AAM_SERVER_DEAD);
-
+  if (this->info_->death_notify)
+    {
+      // We get a death notify of the activator so we can wait on the death
+      // of the process
+      this->status (ImplementationRepository::AAM_WAIT_FOR_DEATH);
+    }
+  else
+    {
+      // We don't get a death notify of the activator so we have to assume at
+      // this point the server is death
+      this->status (ImplementationRepository::AAM_SERVER_DEAD);
+    }
 }
 
 void
@@ -528,7 +617,7 @@ AsyncAccessManager::ping_replied (LiveStatus server)
   if (ImR_Locator_i::debug () > 4)
     {
       ORBSVCS_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied <%C>,")
+                      ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied <%C>")
                       ACE_TEXT (" this status <%C>\n"),
                       this, LiveEntry::status_name (server), status_name (this->status_)));
     }
@@ -561,8 +650,8 @@ AsyncAccessManager::ping_replied (LiveStatus server)
                 if (ImR_Locator_i::debug () > 4)
                   {
                     ORBSVCS_DEBUG ((LM_DEBUG,
-                                    ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied pid = %d,")
-                                    ACE_TEXT (" transition to WAIT_FOR_DEATH\n"),
+                                    ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied pid <%d>,")
+                                    ACE_TEXT (" waiting on ping, transition to <WAIT_FOR_DEATH>\n"),
                                     this, this->info_->pid));
                   }
                 this->status (ImplementationRepository::AAM_WAIT_FOR_DEATH);
@@ -571,7 +660,7 @@ AsyncAccessManager::ping_replied (LiveStatus server)
             if (ImR_Locator_i::debug () > 4)
               {
                 ORBSVCS_DEBUG ((LM_DEBUG,
-                                ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied pid = %d,")
+                                ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied pid <%d>,")
                                 ACE_TEXT (" trying to restart server\n"),
                                 this, this->info_->pid));
               }
@@ -582,7 +671,31 @@ AsyncAccessManager::ping_replied (LiveStatus server)
           }
         else
           {
-            this->status (ImplementationRepository::AAM_SERVER_DEAD);
+            // If we get a death notify we wait for the death of the process, the fact that the
+            // ping failed doesn't mean the process itself is already death
+            if (this->info_->death_notify && this->info_->pid != 0)
+              {
+                if (ImR_Locator_i::debug () > 4)
+                  {
+                    ORBSVCS_DEBUG ((LM_DEBUG,
+                                    ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied pid <%d>,")
+                                    ACE_TEXT (" transition to <WAIT_FOR_DEATH>\n"),
+                                    this, this->info_->pid));
+                  }
+                this->status (ImplementationRepository::AAM_WAIT_FOR_DEATH);
+                return;
+              }
+            else
+              {
+                if (ImR_Locator_i::debug () > 4)
+                  {
+                    ORBSVCS_DEBUG ((LM_DEBUG,
+                                    ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::ping_replied pid <%d>,")
+                                    ACE_TEXT (" transition to <SERVER_DEAD>\n"),
+                                    this, this->info_->pid));
+                  }
+                this->status (ImplementationRepository::AAM_SERVER_DEAD);
+              }
           }
       }
       break;
@@ -598,13 +711,19 @@ AsyncAccessManager::send_start_request (void)
   if (ImR_Locator_i::debug () > 4)
     {
       ORBSVCS_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::send_start_request, manual_start <%d>\n"),
-                      this, this->manual_start_));
+                      ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::send_start_request, server <%C> manual_start <%d> retries <%d>\n"),
+                      this, this->info_->ping_id(), this->manual_start_, this->retries_));
     }
 
   if ((this->locator_.opts ()->lockout () && !this->info_.edit ()->start_allowed ()) ||
       (this->retries_ == 0))
     {
+      if (ImR_Locator_i::debug () > 4)
+        {
+          ORBSVCS_ERROR ((LM_ERROR,
+                          ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::send_start_request, server <%C> not started because retries exceeded\n"),
+                          this, this->info_->ping_id()));
+        }
       this->status (ImplementationRepository::AAM_RETRIES_EXCEEDED);
       return false;
     }
@@ -614,6 +733,12 @@ AsyncAccessManager::send_start_request (void)
   if (this->info_->is_mode (ImplementationRepository::MANUAL) &&
       !this->manual_start_)
     {
+      if (ImR_Locator_i::debug () > 4)
+        {
+          ORBSVCS_ERROR ((LM_ERROR,
+                          ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::send_start_request, server <%C> not started because only a manual start is allowed\n"),
+                          this, this->info_->ping_id()));
+        }
       this->status (ImplementationRepository::AAM_NOT_MANUAL);
       return false;
     }
@@ -622,6 +747,12 @@ AsyncAccessManager::send_start_request (void)
 
   if (startup->cmdline.length () == 0)
     {
+      if (ImR_Locator_i::debug () > 4)
+        {
+          ORBSVCS_ERROR ((LM_ERROR,
+                          ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::send_start_request, server <%C> not started because no commandline has been configured\n"),
+                          this, this->info_->ping_id()));
+        }
       this->status (ImplementationRepository::AAM_NO_COMMANDLINE);
       return false;
     }
@@ -631,6 +762,12 @@ AsyncAccessManager::send_start_request (void)
 
   if (ainfo.null () || CORBA::is_nil (ainfo->activator.in ()))
     {
+      if (ImR_Locator_i::debug () > 4)
+        {
+          ORBSVCS_ERROR ((LM_ERROR,
+                          ACE_TEXT ("(%P|%t) AsyncAccessManager(%@)::send_start_request, server <%C> not started because no activator has been found\n"),
+                          this, this->info_->ping_id()));
+        }
       this->status (ImplementationRepository::AAM_NO_ACTIVATOR);
       return false;
     }
@@ -650,6 +787,10 @@ AsyncAccessManager::send_start_request (void)
     }
   else
     {
+      // When we start a new server we need set our process id back to zero
+      // so that we ignore an asynchronous child death which can happens after
+      // we already restarted the server
+      this->info_.edit()->pid = 0;
       servername = unique_prefix + startup->key_name_;
     }
 
@@ -658,7 +799,7 @@ AsyncAccessManager::send_start_request (void)
                                         startup->cmdline.c_str (),
                                         startup->dir.c_str (),
                                         startup->env_vars);
-  this->update_status (ImplementationRepository::AAM_ACTIVATION_SENT);
+  this->update_status (ImplementationRepository::AAM_WAIT_FOR_RUNNING);
   return true;
 }
 
@@ -695,7 +836,6 @@ ActivatorReceiver::ActivatorReceiver (AsyncAccessManager *aam,
 {
 }
 
-
 ActivatorReceiver::~ActivatorReceiver (void)
 {
 }
@@ -703,7 +843,13 @@ ActivatorReceiver::~ActivatorReceiver (void)
 void
 ActivatorReceiver::start_server (void)
 {
-  this->aam_->activator_replied (true, 0);
+  if (ImR_Locator_i::debug () > 4)
+    {
+      ORBSVCS_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("(%P|%t) ActivatorReceiver(%@)::start_server, received start_server reply\n"),
+                      this));
+    }
+
   PortableServer::ObjectId_var oid = this->poa_->servant_to_id (this);
   poa_->deactivate_object (oid.in());
 }
@@ -711,22 +857,43 @@ ActivatorReceiver::start_server (void)
 void
 ActivatorReceiver::start_server_excep (Messaging::ExceptionHolder *holder)
 {
+  if (ImR_Locator_i::debug () > 4)
+    {
+      ORBSVCS_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("(%P|%t) ActivatorReceiver(%@)::start_server_excep, received start_server_excep reply\n"),
+                      this));
+    }
+
   try
     {
       holder->raise_exception ();
     }
   catch (const ImplementationRepository::CannotActivate &ca)
     {
+      if (ImR_Locator_i::debug () > 1)
+        {
+          ORBSVCS_DEBUG ((LM_DEBUG,
+                          ACE_TEXT ("(%P|%t) ActivatorReceiver(%@)::start_server_excep, reason <%C>\n"),
+                          this, ca.reason.in ()));
+        }
       if (ACE_OS::strstr (ca.reason.in(),"pid:") == ca.reason.in())
         {
           int const pid = ACE_OS::atoi (ca.reason.in()+4);
-          this->aam_->activator_replied (true, pid);
+          this->aam_->activator_replied_start_running (true, pid);
         }
       else
         {
-          this->aam_->activator_replied (false, 0);
+          this->aam_->activator_replied_start_running (false, 0);
         }
     }
+  catch (const CORBA::Exception& ex)
+    {
+      if (ImR_Locator_i::debug () > 1)
+        {
+          ex._tao_print_exception ("ActivatorReceiver::start_server_excep");
+        }
+    }
+
   PortableServer::ObjectId_var oid = this->poa_->servant_to_id (this);
   poa_->deactivate_object (oid.in());
 }
@@ -734,25 +901,21 @@ ActivatorReceiver::start_server_excep (Messaging::ExceptionHolder *holder)
 void
 ActivatorReceiver::shutdown (void)
 {
-  // no-op, just satisfy virtual function
 }
 
 void
 ActivatorReceiver::shutdown_excep (Messaging::ExceptionHolder * )
 {
-  // no-op, just satisfy virtual function
 }
 
 void
 ActivatorReceiver::kill_server (CORBA::Boolean )
 {
-  // no-op, just satisfy virtual function
 }
 
 void
 ActivatorReceiver::kill_server_excep (Messaging::ExceptionHolder * )
 {
-  // no-op, just satisfy virtual function
 }
 
 
