@@ -21,7 +21,7 @@ public:
 
   virtual int init (int argc, ACE_TCHAR *argv[]);
 
-  virtual int fini (void);
+  virtual int fini ();
 
   virtual CORBA::Object_ptr create_object (CORBA::ORB_ptr orb,
                                            int argc,
@@ -35,9 +35,10 @@ private:
   Options opts_;
   ACE_Auto_Ptr<ImR_Locator_ORB_Runner> runner_;
 private:
-  // Disallow copying and assignment.
-  ImR_Locator_Loader (const ImR_Locator_Loader &);
-  ImR_Locator_Loader &operator = (const ImR_Locator_Loader &);
+  ImR_Locator_Loader (const ImR_Locator_Loader &) = delete;
+  ImR_Locator_Loader &operator = (const ImR_Locator_Loader &) = delete;
+  ImR_Locator_Loader (ImR_Locator_Loader &&) = delete;
+  ImR_Locator_Loader &operator = (ImR_Locator_Loader &&) = delete;
 };
 
 ACE_FACTORY_DECLARE (Locator, ImR_Locator_Loader)
