@@ -53,16 +53,16 @@ struct Server_Info
 
   /// Convert to the corba type
   void setImRInfo (ImplementationRepository::ServerInformation* info) const;
-  ImplementationRepository::ServerInformation* createImRServerInfo(void) const;
+  ImplementationRepository::ServerInformation* createImRServerInfo() const;
 
   void reset_runtime (void);
 
   bool is_server (const char *name) const;
   bool has_peer (const char *name) const;
   bool is_mode (ImplementationRepository::ActivationMode m) const;
-  ImplementationRepository::ActivationMode mode (void) const;
+  ImplementationRepository::ActivationMode mode () const;
 
-  bool is_running (void) const;
+  bool is_running () const;
   bool start_allowed (void);
   void started (bool success);
 
@@ -75,9 +75,9 @@ struct Server_Info
                     ImplementationRepository::ServerObject_ptr svrobj);
 
   Server_Info *active_info (void);
-  const Server_Info *active_info (void) const;
+  const Server_Info *active_info () const;
 
-  const char * ping_id (void) const;
+  const char * ping_id () const;
 
   static bool parse_id (const char * id,
                         ACE_CString& server_id,
@@ -130,7 +130,7 @@ struct Server_Info
 
   /// Last known process ID reported by the activator
   int pid;
-  /// the locator should expect a notification on server death from activator
+  /// The locator should expect a notification on server death from activator
   bool death_notify;
 };
 
