@@ -30,12 +30,11 @@ class TAO_RTEC_COSEC_Export TAO_CosEC_ConsumerAdmin_i :
   //   This implementation of the ConsumerAdmin uses the
   //   RtecEventChannelAdmin::ConsumerAdmin.
 public:
-  // = Initialization and termination methods.
   /// Constructor.
   TAO_CosEC_ConsumerAdmin_i (void);
 
   /// Destructor.
-  ~TAO_CosEC_ConsumerAdmin_i (void);
+  ~TAO_CosEC_ConsumerAdmin_i () = default;
 
   int init (const RtecEventChannelAdmin::ConsumerQOS &consumerqos,
             RtecEventChannelAdmin::ConsumerAdmin_ptr rtec_consumeradmin);
