@@ -107,14 +107,14 @@ ReplicaController (CORBA::ORB_ptr orb)
   ACE_DEBUG ((LM_DEBUG, "Becoming a member with id %s\n",
               uuid.to_string ()->c_str ()));
 
-  ACE_auto_ptr_reset (group_, new ACE_TMCast::Group (address, uuid.to_string ()->c_str ()));
+  group_.reset (new ACE_TMCast::Group (address, uuid.to_string ()->c_str ()));
 
   int r = ACE_Thread_Manager::instance ()->spawn (
     &ReplicaController::listener_thunk, this);
 
   if (r < 0)
   {
-    orb_->shutdown (0);
+    orb_->shutdown (false);
   }
 }
 
@@ -189,7 +189,7 @@ listener ()
     ACE_DEBUG ((LM_DEBUG, "Group::InsufficienSpace\n"));
   }
 
-  orb_->shutdown (0);
+  orb_->shutdown (false);
 }
 
 PortableServer::POA_ptr ReplicaController::
