@@ -26,14 +26,14 @@ class DynServer_ORB_Runner;
 class DynServer_Export DynServer_Loader : public TAO_Object_Loader
 {
 public:
-  DynServer_Loader(void);
+  DynServer_Loader();
 
   // spawns a thread to run an internal orb which has activated
   // a single DynServer servant.
   virtual int init (int argc, ACE_TCHAR *argv[]);
 
   // Allows the service configurator to shutdown the orb
-  virtual int fini (void);
+  virtual int fini ();
 
   // Not supported
   virtual CORBA::Object_ptr create_object (CORBA::ORB_ptr orb,
@@ -47,8 +47,8 @@ private:
   ACE_Auto_Ptr<DynServer_ORB_Runner> runner_;
 
 private:
-  ACE_UNIMPLEMENTED_FUNC (DynServer_Loader (const DynServer_Loader &))
-  ACE_UNIMPLEMENTED_FUNC (DynServer_Loader &operator = (const DynServer_Loader &))
+  DynServer_Loader (const DynServer_Loader &) = delete;
+  DynServer_Loader &operator = (const DynServer_Loader &) = delete;
 };
 
 ACE_FACTORY_DECLARE (DynServer, DynServer_Loader)
