@@ -25,5 +25,5 @@ StockFactory::get_stock (const char *symbol)
 void
 StockFactory::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
