@@ -40,7 +40,7 @@ public:
   int parse_args (int argc, ACE_TCHAR *argv[]);
 
   /// The thread entry point.
-  virtual int svc (void);
+  virtual int svc ();
 
 protected:
   /// Create an EC
