@@ -3,7 +3,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_CEC_Factory::~TAO_CEC_Factory (void)
+TAO_CEC_Factory::~TAO_CEC_Factory ()
 {
 }
 
