@@ -2,7 +2,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_CEC_Pulling_Strategy::~TAO_CEC_Pulling_Strategy (void)
+TAO_CEC_Pulling_Strategy::~TAO_CEC_Pulling_Strategy ()
 {
 }
 
