@@ -27,7 +27,7 @@ TAO_ECG_Reconnect_ConsumerEC_Control::
     this->orb_->orb_core ()->reactor ();
 }
 
-TAO_ECG_Reconnect_ConsumerEC_Control::~TAO_ECG_Reconnect_ConsumerEC_Control (void)
+TAO_ECG_Reconnect_ConsumerEC_Control::~TAO_ECG_Reconnect_ConsumerEC_Control ()
 {
 }
 
@@ -143,7 +143,7 @@ TAO_ECG_Reconnect_ConsumerEC_Control::handle_timeout (
 }
 
 int
-TAO_ECG_Reconnect_ConsumerEC_Control::activate (void)
+TAO_ECG_Reconnect_ConsumerEC_Control::activate ()
 {
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
   try
@@ -173,7 +173,7 @@ TAO_ECG_Reconnect_ConsumerEC_Control::activate (void)
         // handle_timeout uses these policies, if done in front, the channel
         // can crash when the timeout expires before initiazation is ready.
         timer_id_ = this->reactor_->schedule_timer (&this->adapter_,
-                                                    0,
+                                                    nullptr,
                                                     this->rate_,
                                                     this->rate_);
         if (timer_id_ == -1)
@@ -190,7 +190,7 @@ TAO_ECG_Reconnect_ConsumerEC_Control::activate (void)
 }
 
 int
-TAO_ECG_Reconnect_ConsumerEC_Control::shutdown (void)
+TAO_ECG_Reconnect_ConsumerEC_Control::shutdown ()
 {
   int r = 0;
 
@@ -198,7 +198,7 @@ TAO_ECG_Reconnect_ConsumerEC_Control::shutdown (void)
   r = this->reactor_->cancel_timer (timer_id_);
 #endif /* TAO_HAS_CORBA_MESSAGING */
 
-  this->adapter_.reactor (0);
+  this->adapter_.reactor (nullptr);
   return r;
 }
 
