@@ -20,11 +20,11 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_EC_Basic_Factory::TAO_EC_Basic_Factory (void)
+TAO_EC_Basic_Factory::TAO_EC_Basic_Factory ()
 {
 }
 
-TAO_EC_Basic_Factory::~TAO_EC_Basic_Factory (void)
+TAO_EC_Basic_Factory::~TAO_EC_Basic_Factory ()
 {
 }
 
@@ -116,7 +116,7 @@ TAO_EC_Timeout_Generator*
 TAO_EC_Basic_Factory::create_timeout_generator (TAO_EC_Event_Channel_Base *)
 {
   int argc = 0;
-  ACE_TCHAR **argv = 0;
+  ACE_TCHAR **argv = nullptr;
   CORBA::ORB_var orb =
     CORBA::ORB_init (argc, argv);
   ACE_Reactor *reactor = orb->orb_core ()->reactor ();
@@ -133,7 +133,7 @@ TAO_EC_ObserverStrategy*
 TAO_EC_Basic_Factory::create_observer_strategy (TAO_EC_Event_Channel_Base *ec)
 {
   ACE_Lock* lock;
-  ACE_NEW_RETURN (lock, ACE_Lock_Adapter<TAO_SYNCH_MUTEX>, 0);
+  ACE_NEW_RETURN (lock, ACE_Lock_Adapter<TAO_SYNCH_MUTEX>, nullptr);
   return new TAO_EC_Basic_ObserverStrategy (ec, lock);
 }
 
@@ -194,7 +194,7 @@ TAO_EC_Basic_Factory::destroy_proxy_push_supplier_collection (TAO_EC_ProxyPushSu
 }
 
 ACE_Lock*
-TAO_EC_Basic_Factory::create_consumer_lock (void)
+TAO_EC_Basic_Factory::create_consumer_lock ()
 {
   return new ACE_Lock_Adapter<TAO_SYNCH_MUTEX> ();
 }
@@ -206,7 +206,7 @@ TAO_EC_Basic_Factory::destroy_consumer_lock (ACE_Lock* x)
 }
 
 ACE_Lock*
-TAO_EC_Basic_Factory::create_supplier_lock (void)
+TAO_EC_Basic_Factory::create_supplier_lock ()
 {
   return new ACE_Lock_Adapter<TAO_SYNCH_RECURSIVE_MUTEX> ();
 }
@@ -221,7 +221,7 @@ TAO_EC_ConsumerControl*
 TAO_EC_Basic_Factory::create_consumer_control (TAO_EC_Event_Channel_Base* ec)
 {
   int argc = 0;
-  ACE_TCHAR **argv = 0;
+  ACE_TCHAR **argv = nullptr;
   CORBA::ORB_var orb =
     CORBA::ORB_init (argc, argv);
   // Hard-coded rate to 10 times a second
@@ -241,7 +241,7 @@ TAO_EC_SupplierControl*
 TAO_EC_Basic_Factory::create_supplier_control (TAO_EC_Event_Channel_Base* ec)
 {
   int argc = 0;
-  ACE_TCHAR **argv = 0;
+  ACE_TCHAR **argv = nullptr;
   CORBA::ORB_var orb =
     CORBA::ORB_init (argc, argv);
   // Hard-coded rate to 10 times a second
