@@ -15,7 +15,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_EC_Basic_Filter_Builder::~TAO_EC_Basic_Filter_Builder (void)
+TAO_EC_Basic_Filter_Builder::~TAO_EC_Basic_Filter_Builder ()
 {
 }
 
@@ -36,7 +36,7 @@ TAO_EC_Basic_Filter_Builder:: recursive_build (
 {
   CORBA::ULong l = qos.dependencies.length ();
   if (pos == l)
-    return 0;
+    return nullptr;
 
   const RtecEventComm::Event& e = qos.dependencies[pos].event;
   if (e.header.type == ACE_ES_CONJUNCTION_DESIGNATOR)
@@ -45,7 +45,7 @@ TAO_EC_Basic_Filter_Builder:: recursive_build (
       CORBA::ULong n = this->count_children (qos, pos);
 
       TAO_EC_Filter** children;
-      ACE_NEW_RETURN (children, TAO_EC_Filter*[n], 0);
+      ACE_NEW_RETURN (children, TAO_EC_Filter*[n], nullptr);
       CORBA::ULong i = 0;
       for (; i != n; ++i)
         {
@@ -59,7 +59,7 @@ TAO_EC_Basic_Filter_Builder:: recursive_build (
       CORBA::ULong n = this->count_children (qos, pos);
 
       TAO_EC_Filter** children;
-      ACE_NEW_RETURN (children, TAO_EC_Filter*[n], 0);
+      ACE_NEW_RETURN (children, TAO_EC_Filter*[n], nullptr);
       CORBA::ULong i = 0;
       for (; i != n; ++i)
         {
@@ -73,7 +73,7 @@ TAO_EC_Basic_Filter_Builder:: recursive_build (
       CORBA::ULong n = this->count_children (qos, pos);
 
       TAO_EC_Filter** children;
-      ACE_NEW_RETURN (children, TAO_EC_Filter*[n], 0);
+      ACE_NEW_RETURN (children, TAO_EC_Filter*[n], nullptr);
       CORBA::ULong i = 0;
       for (; i != n; ++i)
         {
@@ -94,7 +94,7 @@ TAO_EC_Basic_Filter_Builder:: recursive_build (
       pos++; // COnsumer the designator
 
       if (pos == qos.dependencies.length ())
-        return 0;
+        return nullptr;
       CORBA::ULong source_mask = qos.dependencies[pos].event.header.source;
       CORBA::ULong type_mask = qos.dependencies[pos].event.header.type;
       pos++;
@@ -110,13 +110,13 @@ TAO_EC_Basic_Filter_Builder:: recursive_build (
       pos++; // Consume the designator
 
       if (pos == qos.dependencies.length ())
-        return 0;
+        return nullptr;
       CORBA::ULong source_mask = qos.dependencies[pos].event.header.source;
       CORBA::ULong type_mask = qos.dependencies[pos].event.header.type;
       pos++;
 
       if (pos == qos.dependencies.length ())
-        return 0;
+        return nullptr;
       CORBA::ULong source_value = qos.dependencies[pos].event.header.source;
       CORBA::ULong type_value = qos.dependencies[pos].event.header.type;
       pos++;
