@@ -24,7 +24,7 @@ TAO_EC_Conjunction_Filter::
   this->clear ();
 }
 
-TAO_EC_Conjunction_Filter::~TAO_EC_Conjunction_Filter (void)
+TAO_EC_Conjunction_Filter::~TAO_EC_Conjunction_Filter ()
 {
   TAO_EC_Filter** end = this->children_ + this->n_;
   for (TAO_EC_Filter** i = this->children_;
@@ -32,18 +32,18 @@ TAO_EC_Conjunction_Filter::~TAO_EC_Conjunction_Filter (void)
        ++i)
     {
       delete *i;
-      *i = 0;
+      *i = nullptr;
     }
   delete[] this->children_;
-  this->children_ = 0;
+  this->children_ = nullptr;
   this->n_ = 0;
 
   delete[] this->bitvec_;
-  this->bitvec_ = 0;
+  this->bitvec_ = nullptr;
 }
 
 int
-TAO_EC_Conjunction_Filter::all_received (void) const
+TAO_EC_Conjunction_Filter::all_received () const
 {
   Word* i = this->bitvec_;
   for (;
@@ -57,19 +57,19 @@ TAO_EC_Conjunction_Filter::all_received (void) const
 }
 
 TAO_EC_Filter::ChildrenIterator
-TAO_EC_Conjunction_Filter::begin (void) const
+TAO_EC_Conjunction_Filter::begin () const
 {
   return this->children_;
 }
 
 TAO_EC_Filter::ChildrenIterator
-TAO_EC_Conjunction_Filter::end (void) const
+TAO_EC_Conjunction_Filter::end () const
 {
   return this->children_ + this->n_;
 }
 
 int
-TAO_EC_Conjunction_Filter::size (void) const
+TAO_EC_Conjunction_Filter::size () const
 {
   return static_cast<int> (this->n_);
 }
@@ -123,7 +123,7 @@ TAO_EC_Conjunction_Filter::push (const RtecEventComm::EventSet& event,
     {
       this->event_[l + i] = event[i];
     }
-  if (this->all_received () && this->parent () != 0)
+  if (this->all_received () && this->parent () != nullptr)
     this->parent ()->push_nocopy (this->event_, qos_info);
 }
 
@@ -135,7 +135,7 @@ TAO_EC_Conjunction_Filter::push_nocopy (RtecEventComm::EventSet& event,
 }
 
 void
-TAO_EC_Conjunction_Filter::clear (void)
+TAO_EC_Conjunction_Filter::clear ()
 {
   ChildrenIterator end = this->end ();
   for (ChildrenIterator i = this->begin ();
@@ -159,7 +159,7 @@ TAO_EC_Conjunction_Filter::clear (void)
 }
 
 CORBA::ULong
-TAO_EC_Conjunction_Filter::max_event_size (void) const
+TAO_EC_Conjunction_Filter::max_event_size () const
 {
   CORBA::ULong n = 0;
   ChildrenIterator end = this->end ();
