@@ -7,13 +7,13 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_EC_Filter_Builder::~TAO_EC_Filter_Builder (void)
+TAO_EC_Filter_Builder::~TAO_EC_Filter_Builder ()
 {
 }
 
 // ****************************************************************
 
-TAO_EC_Null_Filter_Builder::~TAO_EC_Null_Filter_Builder (void)
+TAO_EC_Null_Filter_Builder::~TAO_EC_Null_Filter_Builder ()
 {
 }
 
