@@ -10,7 +10,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_EC_Kokyu_Scheduling::~TAO_EC_Kokyu_Scheduling (void)
+TAO_EC_Kokyu_Scheduling::~TAO_EC_Kokyu_Scheduling ()
 {
 }
 
