@@ -13,7 +13,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_EC_Priority_Scheduling::~TAO_EC_Priority_Scheduling (void)
+TAO_EC_Priority_Scheduling::~TAO_EC_Priority_Scheduling ()
 {
 }
 
