@@ -35,7 +35,7 @@ TAO_EC_Reactive_SupplierControl::
     this->orb_->orb_core ()->reactor ();
 }
 
-TAO_EC_Reactive_SupplierControl::~TAO_EC_Reactive_SupplierControl (void)
+TAO_EC_Reactive_SupplierControl::~TAO_EC_Reactive_SupplierControl ()
 {
 }
 
@@ -80,7 +80,7 @@ TAO_EC_Reactive_SupplierControl::handle_timeout (
 }
 
 int
-TAO_EC_Reactive_SupplierControl::activate (void)
+TAO_EC_Reactive_SupplierControl::activate ()
 {
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
   try
@@ -110,7 +110,7 @@ TAO_EC_Reactive_SupplierControl::activate (void)
         // handle_timeout uses these policies, if done in front, the channel
         // can crash when the timeout expires before initiazation is ready.
         timer_id_ = this->reactor_->schedule_timer (&this->adapter_,
-                                                    0,
+                                                    nullptr,
                                                     this->rate_,
                                                     this->rate_);
         if (timer_id_ == -1)
@@ -127,14 +127,14 @@ TAO_EC_Reactive_SupplierControl::activate (void)
 }
 
 int
-TAO_EC_Reactive_SupplierControl::shutdown (void)
+TAO_EC_Reactive_SupplierControl::shutdown ()
 {
   int r = 0;
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
   r = this->reactor_->cancel_timer (timer_id_);
 #endif /* TAO_HAS_CORBA_MESSAGING */
-  this->adapter_.reactor (0);
+  this->adapter_.reactor (nullptr);
   return r;
 }
 
