@@ -17,18 +17,18 @@ TAO_EC_SupplierAdmin::TAO_EC_SupplierAdmin (TAO_EC_Event_Channel_Base *ec)
     this->event_channel_->supplier_poa ();
 }
 
-TAO_EC_SupplierAdmin::~TAO_EC_SupplierAdmin (void)
+TAO_EC_SupplierAdmin::~TAO_EC_SupplierAdmin ()
 {
 }
 
 RtecEventChannelAdmin::ProxyPushConsumer_ptr
-TAO_EC_SupplierAdmin::obtain_push_consumer (void)
+TAO_EC_SupplierAdmin::obtain_push_consumer ()
 {
   return this->obtain ();
 }
 
 PortableServer::POA_ptr
-TAO_EC_SupplierAdmin::_default_POA (void)
+TAO_EC_SupplierAdmin::_default_POA ()
 {
   return PortableServer::POA::_duplicate (this->default_POA_.in ());
 }
