@@ -10,7 +10,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_EC_Supplier_Filter::~TAO_EC_Supplier_Filter (void)
+TAO_EC_Supplier_Filter::~TAO_EC_Supplier_Filter ()
 {
 }
 
