@@ -4,7 +4,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_EC_Supplier_Filter_Builder::~TAO_EC_Supplier_Filter_Builder (void)
+TAO_EC_Supplier_Filter_Builder::~TAO_EC_Supplier_Filter_Builder ()
 {
 }
 
