@@ -1,4 +1,3 @@
-// This may look like C, but it's really -*- C++ -*-
 #include "orbsvcs/Log_Macros.h"
 #include "orbsvcs/Log_Macros.h"
 #include "orbsvcs/HTIOP/HTIOP_Acceptor.h"
@@ -40,7 +39,7 @@ TAO::HTIOP::Acceptor::Acceptor (ACE::HTBP::Environment *ht_env,
 {
 }
 
-TAO::HTIOP::Acceptor::~Acceptor (void)
+TAO::HTIOP::Acceptor::~Acceptor ()
 {
   // Make sure we are closed before we start destroying the
   // strategies.
@@ -246,7 +245,7 @@ TAO::HTIOP::Acceptor::is_collocated (const TAO_Endpoint *endpoint)
 }
 
 int
-TAO::HTIOP::Acceptor::close (void)
+TAO::HTIOP::Acceptor::close ()
 {
   return this->base_acceptor_.close ();
 }
@@ -671,7 +670,7 @@ TAO::HTIOP::Acceptor::probe_interfaces (TAO_ORB_Core *orb_core)
   // the list of cached hostnames unless it is the only interface.
   size_t lo_cnt = 0;  // Loopback interface count
   for (size_t j = 0; j < if_cnt; ++j)
-    if (inet_addrs[j].get_ip_address () == INADDR_LOOPBACK)
+    if (inet_addrs[j].is_loopback ())
       lo_cnt++;
 
   // The instantiation for this template is in
@@ -706,7 +705,7 @@ TAO::HTIOP::Acceptor::probe_interfaces (TAO_ORB_Core *orb_core)
       // Ignore any loopback interface if there are other
       // non-loopback interfaces.
       if (if_cnt != lo_cnt &&
-          inet_addrs[i].get_ip_address() == INADDR_LOOPBACK)
+          inet_addrs[i].is_loopback ())
         continue;
 
       if (this->hostname_in_ior_ != 0)
@@ -743,7 +742,7 @@ TAO::HTIOP::Acceptor::probe_interfaces (TAO_ORB_Core *orb_core)
 }
 
 CORBA::ULong
-TAO::HTIOP::Acceptor::endpoint_count (void)
+TAO::HTIOP::Acceptor::endpoint_count ()
 {
   return this->endpoint_count_;
 }
