@@ -46,132 +46,103 @@ public:
   virtual ~TAO_ComponentDef_i (void);
 
   /// Return our definition kind.
-  virtual CORBA::DefinitionKind def_kind (
-    );
+  virtual CORBA::DefinitionKind def_kind ();
 
   /// Remove the repository entry.
-  virtual void destroy (
-    );
+  virtual void destroy ();
 
   /// Remove the repository entry.
-  void destroy_i (
-    );
+  void destroy_i ();
 
   /// From Contained_i's pure virtual function.
-  virtual CORBA::Contained::Description *describe (
-    );
+  virtual CORBA::Contained::Description *describe ();
 
   /// From Contained_i's pure virtual function.
-  CORBA::Contained::Description *describe_i (
-    );
+  CORBA::Contained::Description *describe_i ();
 
   /// From IDLType_i's pure virtual function.
-  virtual CORBA::TypeCode_ptr type (
-    );
+  virtual CORBA::TypeCode_ptr type ();
 
   /// From IDLType_i's pure virtual function.
-  CORBA::TypeCode_ptr type_i (
-    );
+  CORBA::TypeCode_ptr type_i ();
 
-  virtual CORBA::InterfaceDefSeq *supported_interfaces (
-    );
+  virtual CORBA::InterfaceDefSeq *supported_interfaces ();
 
-  CORBA::InterfaceDefSeq *supported_interfaces_i (
-    );
+  CORBA::InterfaceDefSeq *supported_interfaces_i ();
 
-  virtual void supported_interfaces (
-      const CORBA::InterfaceDefSeq &supported_interfaces
-    );
+  virtual void supported_interfaces (const CORBA::InterfaceDefSeq &supported_interfaces);
 
-  void supported_interfaces_i (
-      const CORBA::InterfaceDefSeq &supported_interfaces
-    );
+  void supported_interfaces_i (const CORBA::InterfaceDefSeq &supported_interfaces);
 
-  virtual CORBA::ComponentIR::ComponentDef_ptr base_component (
-    );
+  virtual CORBA::ComponentIR::ComponentDef_ptr base_component ();
 
-  CORBA::ComponentIR::ComponentDef_ptr base_component_i (
-    );
+  CORBA::ComponentIR::ComponentDef_ptr base_component_i ();
 
-  virtual void base_component (
-      CORBA::ComponentIR::ComponentDef_ptr base_component
-    );
+  virtual void base_component (CORBA::ComponentIR::ComponentDef_ptr base_component);
 
-  void base_component_i (
-      CORBA::ComponentIR::ComponentDef_ptr base_component
-    );
+  void base_component_i (CORBA::ComponentIR::ComponentDef_ptr base_component);
 
   virtual CORBA::ComponentIR::ProvidesDef_ptr create_provides (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::InterfaceDef_ptr interface_type
-    );
+      CORBA::InterfaceDef_ptr interface_type);
 
   CORBA::ComponentIR::ProvidesDef_ptr create_provides_i (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::InterfaceDef_ptr interface_type
-    );
+      CORBA::InterfaceDef_ptr interface_type);
 
   virtual CORBA::ComponentIR::UsesDef_ptr create_uses (
       const char *id,
       const char *name,
       const char *version,
       CORBA::InterfaceDef_ptr interface_type,
-      CORBA::Boolean is_multiple
-    );
+      CORBA::Boolean is_multiple);
 
   CORBA::ComponentIR::UsesDef_ptr create_uses_i (
       const char *id,
       const char *name,
       const char *version,
       CORBA::InterfaceDef_ptr interface_type,
-      CORBA::Boolean is_multiple
-    );
+      CORBA::Boolean is_multiple);
 
   virtual CORBA::ComponentIR::EmitsDef_ptr create_emits (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::ValueDef_ptr value
-    );
+      CORBA::ValueDef_ptr value);
 
   CORBA::ComponentIR::EmitsDef_ptr create_emits_i (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::ValueDef_ptr value
-    );
+      CORBA::ValueDef_ptr value);
 
   virtual CORBA::ComponentIR::PublishesDef_ptr create_publishes (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::ValueDef_ptr value
-    );
+      CORBA::ValueDef_ptr value);
 
   CORBA::ComponentIR::PublishesDef_ptr create_publishes_i (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::ValueDef_ptr value
-    );
+      CORBA::ValueDef_ptr value);
 
   virtual CORBA::ComponentIR::ConsumesDef_ptr create_consumes (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::ValueDef_ptr value
-    );
+      CORBA::ValueDef_ptr value);
 
   CORBA::ComponentIR::ConsumesDef_ptr create_consumes_i (
       const char *id,
       const char *name,
       const char *version,
-      CORBA::ValueDef_ptr value
-    );
+      CORBA::ValueDef_ptr value);
 
   /// Called from TAO_IFR_Service_Utils::name_exists() when we
   /// are a base component.
