@@ -46,8 +46,7 @@ public:
   virtual ~TAO_FactoryDef_i (void);
 
   /// Return our definition kind.
-  virtual CORBA::DefinitionKind def_kind (
-    );
+  virtual CORBA::DefinitionKind def_kind (    );
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
