@@ -7,7 +7,7 @@ TAO_IDLType_i::TAO_IDLType_i (TAO_Repository_i *repo)
 {
 }
 
-TAO_IDLType_i::~TAO_IDLType_i (void)
+TAO_IDLType_i::~TAO_IDLType_i ()
 {
 }
 
