@@ -12,12 +12,12 @@ TAO_LocalInterfaceDef_i::TAO_LocalInterfaceDef_i (TAO_Repository_i *repo)
 {
 }
 
-TAO_LocalInterfaceDef_i::~TAO_LocalInterfaceDef_i (void)
+TAO_LocalInterfaceDef_i::~TAO_LocalInterfaceDef_i ()
 {
 }
 
 CORBA::DefinitionKind
-TAO_LocalInterfaceDef_i::def_kind (void)
+TAO_LocalInterfaceDef_i::def_kind ()
 {
   return CORBA::dk_LocalInterface;
 }
