@@ -13,18 +13,18 @@ TAO_NativeDef_i::TAO_NativeDef_i (TAO_Repository_i *repo)
 {
 }
 
-TAO_NativeDef_i::~TAO_NativeDef_i (void)
+TAO_NativeDef_i::~TAO_NativeDef_i ()
 {
 }
 
 CORBA::DefinitionKind
-TAO_NativeDef_i::def_kind (void)
+TAO_NativeDef_i::def_kind ()
 {
   return CORBA::dk_Native;
 }
 
 CORBA::TypeCode_ptr
-TAO_NativeDef_i::type (void)
+TAO_NativeDef_i::type ()
 {
   TAO_IFR_READ_GUARD_RETURN (CORBA::TypeCode::_nil ());
 
@@ -34,7 +34,7 @@ TAO_NativeDef_i::type (void)
 }
 
 CORBA::TypeCode_ptr
-TAO_NativeDef_i::type_i (void)
+TAO_NativeDef_i::type_i ()
 {
   ACE_TString id;
   this->repo_->config ()->get_string_value (this->section_key_,
