@@ -66,7 +66,7 @@ TAO_LB_LoadManager::TAO_LB_LoadManager (int ping_timeout,
   //       by whatever code instantiates this LoadManager.
 }
 
-TAO_LB_LoadManager::~TAO_LB_LoadManager (void)
+TAO_LB_LoadManager::~TAO_LB_LoadManager ()
 {
   this->shutdown_ = true;
   this->validate_condition_.signal ();
@@ -1162,7 +1162,7 @@ TAO_LB_LoadManager::make_strategy (const CosLoadBalancing::StrategyInfo * info)
 
 
 int
-TAO_LB_LoadManager::svc (void)
+TAO_LB_LoadManager::svc ()
 {
   while (! this->shutdown_)
   {
