@@ -47,14 +47,14 @@ TAO_LB_ObjectReferenceFactory::TAO_LB_ObjectReferenceFactory (
 }
 
 ::CORBA::ValueBase *
-TAO_LB_ObjectReferenceFactory::_copy_value (void)
+TAO_LB_ObjectReferenceFactory::_copy_value ()
 {
   ::CORBA::ValueBase *ret_val= 0;
   // Not implimented
   return ret_val;
 }
 
-TAO_LB_ObjectReferenceFactory::~TAO_LB_ObjectReferenceFactory (void)
+TAO_LB_ObjectReferenceFactory::~TAO_LB_ObjectReferenceFactory ()
 {
   // No need to call CORBA::remove_ref() on this->old_orf_.  It is a
   // "_var" object, meaning that will be done automatically.
