@@ -2,11 +2,11 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_LogRecordStore::TAO_LogRecordStore (void)
+TAO_LogRecordStore::TAO_LogRecordStore ()
 {
 }
 
-TAO_LogRecordStore::~TAO_LogRecordStore (void)
+TAO_LogRecordStore::~TAO_LogRecordStore ()
 {
 }
 
