@@ -27,13 +27,6 @@ TAO_FT_Persistent_Naming_Context::TAO_FT_Persistent_Naming_Context (
                                    map,
                                    counter)
 {
-
-}
-
-
-TAO_FT_Persistent_Naming_Context::~TAO_FT_Persistent_Naming_Context (void)
-{
-  // Perform appropriate cleanup based on the destruction level specified.
 }
 
 
