@@ -12,8 +12,7 @@
 #include "orbsvcs/Naming/FaultTolerant/nsgroup_svc.h"
 #include "ace/OS_NS_strings.h"
 
-
-NS_group_svc::NS_group_svc (bool quiet )
+NS_group_svc::NS_group_svc (bool quiet)
   : quiet_ (quiet)
 {
 }
@@ -389,7 +388,7 @@ NS_group_svc::group_unbind (const ACE_TCHAR* path)
  * Displays all object groups that currently exist in the naming service.
  */
 int
-NS_group_svc::group_list (void)
+NS_group_svc::group_list ()
 {
 
   // KCS: The group list is independent of locations. I created a new operation in the
