@@ -14,19 +14,21 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
+
 /**
  * @class NS_group_svc
  *
  * @brief Encapsulate the NS group operations in a class.
+ *
+ *
  */
 class  TAO_FtNaming_Intf_Export NS_group_svc
 {
 public:
-
   /**
    *  Constructor
    */
-  NS_group_svc (void);
+  NS_group_svc (bool quiet = false);
 
   /**
    * The naming service shall provide a command line utility for creating
@@ -156,9 +158,8 @@ public:
   int set_name_context( CosNaming::NamingContextExt_ptr value);
 
 private:
-
   /**
-   *  determine stategy based on policy string
+   *  determine strategy based on policy string
    *
    *  @param const ACE_TCHAR *policy ["round"]
    *  @param FT_Naming::LoadBalancingStrategyValue& value
@@ -176,13 +177,12 @@ private:
     const ACE_TCHAR *display_label);
 
 private:
-
   FT_Naming::NamingManager_var naming_manager_;
 
   CosNaming::NamingContextExt_var name_service_;
 
   CORBA::ORB_var orb_;
-
+  bool quiet_;
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
