@@ -1,4 +1,3 @@
-
 //=============================================================================
 /**
  *  @file   Naming_Context_Interface.cpp
@@ -7,7 +6,6 @@
  */
 //=============================================================================
 
-
 #include "orbsvcs/Naming/Naming_Context_Interface.h"
 #include "ace/ACE.h"
 #include "ace/OS_NS_string.h"
@@ -20,7 +18,7 @@ TAO_Naming_Context::TAO_Naming_Context (TAO_Naming_Context_Impl *impl)
 {
 }
 
-TAO_Naming_Context::~TAO_Naming_Context (void)
+TAO_Naming_Context::~TAO_Naming_Context ()
 {
   delete impl_;
 }
@@ -70,7 +68,7 @@ TAO_Naming_Context::unbind (const CosNaming::Name &n)
 }
 
 CosNaming::NamingContext_ptr
-TAO_Naming_Context::new_context (void)
+TAO_Naming_Context::new_context ()
 {
   return impl_->new_context ();
 }
@@ -82,7 +80,7 @@ TAO_Naming_Context::bind_new_context (const CosNaming::Name &n)
 }
 
 void
-TAO_Naming_Context::destroy (void)
+TAO_Naming_Context::destroy ()
 {
   impl_->destroy ();
 }
@@ -465,7 +463,7 @@ TAO_Naming_Context::stale (bool value)
   this->impl_->stale (value);
 }
 
-TAO_Naming_Context_Impl::~TAO_Naming_Context_Impl (void)
+TAO_Naming_Context_Impl::~TAO_Naming_Context_Impl ()
 {
 }
 
@@ -477,7 +475,7 @@ TAO_Naming_Context_Impl::stale (bool value)
 }
 
 bool
-TAO_Naming_Context_Impl::stale (void)
+TAO_Naming_Context_Impl::stale ()
 {
   // Default implementation is to reply false
   return false;
