@@ -8,7 +8,6 @@
  */
 //=============================================================================
 
-
 #ifndef TAO_PERSISTENT_CONTEXT_INDEX_H
 #define TAO_PERSISTENT_CONTEXT_INDEX_H
 #include /**/ "ace/pre.h"
@@ -62,8 +61,6 @@ public:
   typedef ACE_Allocator_Adapter <ACE_Malloc <ACE_MMAP_MEMORY_POOL, TAO_SYNCH_MUTEX>
   > ALLOCATOR;
 
-  // = Initialization and termination methods.
-
   /// Constructor.
   TAO_Persistent_Context_Index (
     CORBA::ORB_ptr orb,
@@ -130,13 +127,12 @@ public:
   CosNaming::NamingContext_ptr root_context (void);
 
 private:
-
   /// Helper for the <init> method.  Iterates over <index_>, and
   /// creates a servant for each entry.
-  int recreate_all (void);
+  int recreate_all ();
 
   /// Helper for the <open> method.
-  int create_index (void);
+  int create_index ();
 
   /// Helper for <create_index> method: places hash table into an
   /// allocated space.
