@@ -4,14 +4,14 @@
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /// Constructor.
-TAO_Persistent_Naming_Context_Factory::TAO_Persistent_Naming_Context_Factory (void)
+TAO_Persistent_Naming_Context_Factory::TAO_Persistent_Naming_Context_Factory ()
 {
 
 }
 
 /// Destructor.  Does not deallocate the hash map: if an instance of
 /// this class goes out of scope, its hash_map remains in persistent storage.
-TAO_Persistent_Naming_Context_Factory::~TAO_Persistent_Naming_Context_Factory (void)
+TAO_Persistent_Naming_Context_Factory::~TAO_Persistent_Naming_Context_Factory ()
 {
 }
 
@@ -27,20 +27,11 @@ TAO_Persistent_Naming_Context_Factory::create_naming_context_impl (
 {
   // Construct the naming context, forwarding the map and counter even if they
   // are defaulted
-#if defined (ACE_HAS_NEW_NOTHROW)
-  return new (ACE_nothrow) TAO_Persistent_Naming_Context (poa,
+  return new (std::nothrow) TAO_Persistent_Naming_Context (poa,
                                                           poa_id,
                                                           context_index,
                                                           map,
                                                           counter);
-#else
-  return new TAO_Persistent_Naming_Context (poa,
-                                            poa_id,
-                                            context_index,
-                                            map,
-                                            counter);
-
-#endif /* ACE_HAS_NEW_NOTHROW */
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
