@@ -1,4 +1,3 @@
-
 #include "orbsvcs/Log_Macros.h"
 #include "orbsvcs/Naming/Storable_Naming_Context.h"
 #include "orbsvcs/Naming/Storable_Naming_Context_Factory.h"
@@ -20,7 +19,7 @@ ACE_UINT32 TAO_Storable_Naming_Context::gcounter_;
 ACE_Auto_Ptr<TAO::Storable_Base> TAO_Storable_Naming_Context::gfl_;
 int TAO_Storable_Naming_Context::redundant_;
 
-TAO_Storable_IntId::TAO_Storable_IntId (void)
+TAO_Storable_IntId::TAO_Storable_IntId ()
   : ref_ (CORBA::string_dup ("")),
     type_ (CosNaming::nobject)
 {
@@ -39,7 +38,7 @@ TAO_Storable_IntId::TAO_Storable_IntId (const TAO_Storable_IntId &rhs)
   type_ = rhs.type_;
 }
 
-TAO_Storable_IntId::~TAO_Storable_IntId (void)
+TAO_Storable_IntId::~TAO_Storable_IntId ()
 {
 }
 
@@ -54,7 +53,7 @@ TAO_Storable_IntId::operator= (const TAO_Storable_IntId &rhs)
   ref_ = rhs.ref_;
 }
 
-TAO_Storable_ExtId::TAO_Storable_ExtId (void)
+TAO_Storable_ExtId::TAO_Storable_ExtId ()
   : id_ (CORBA::string_dup ("")),
     kind_ (CORBA::string_dup (""))
 {
@@ -72,7 +71,7 @@ TAO_Storable_ExtId::TAO_Storable_ExtId (const TAO_Storable_ExtId &rhs)
   kind_ = rhs.kind_;
 }
 
-TAO_Storable_ExtId::~TAO_Storable_ExtId (void)
+TAO_Storable_ExtId::~TAO_Storable_ExtId ()
 {
 }
 
@@ -102,7 +101,7 @@ TAO_Storable_ExtId::operator!= (const TAO_Storable_ExtId &rhs) const
 }
 
 u_long
-TAO_Storable_ExtId::hash (void) const
+TAO_Storable_ExtId::hash () const
 {
   // @CJC I wager this could be optimized a bit better, but I'm not
   // sure how much it's called.  At the very least, we could allocate
@@ -115,13 +114,13 @@ TAO_Storable_ExtId::hash (void) const
 }
 
 const char *
-TAO_Storable_ExtId::id (void)
+TAO_Storable_ExtId::id ()
 {
   return id_.in();
 }
 
 const char *
-TAO_Storable_ExtId::kind (void)
+TAO_Storable_ExtId::kind ()
 {
   return kind_.in();
 }
@@ -185,27 +184,27 @@ TAO_Storable_Bindings_Map::TAO_Storable_Bindings_Map (size_t hash_table_size,
   ACE_TRACE("TAO_Storable_Bindings_Map");
 }
 
-TAO_Storable_Bindings_Map::~TAO_Storable_Bindings_Map (void)
+TAO_Storable_Bindings_Map::~TAO_Storable_Bindings_Map ()
 {
   ACE_TRACE("~TAO_Storable_Bindings_Map");
 }
 
 TAO_Storable_Bindings_Map::HASH_MAP &
-TAO_Storable_Bindings_Map::map (void)
+TAO_Storable_Bindings_Map::map ()
 {
   ACE_TRACE("map");
   return map_;
 }
 
 size_t
-TAO_Storable_Bindings_Map::current_size (void)
+TAO_Storable_Bindings_Map::current_size ()
 {
   ACE_TRACE("current_size");
   return map_.current_size ();
 }
 
 size_t
-TAO_Storable_Bindings_Map::total_size (void)
+TAO_Storable_Bindings_Map::total_size ()
 {
   ACE_TRACE("total_size");
   return map_.total_size ();
@@ -306,7 +305,7 @@ File_Open_Lock_and_Check::~File_Open_Lock_and_Check ()
 
 bool
 TAO_Storable_Naming_Context::
-File_Open_Lock_and_Check::object_obsolete (void)
+File_Open_Lock_and_Check::object_obsolete ()
 {
 
   // Query the underlying context if it is obsolete with respect
@@ -316,7 +315,7 @@ File_Open_Lock_and_Check::object_obsolete (void)
 
 void
 TAO_Storable_Naming_Context::
-File_Open_Lock_and_Check::mark_object_current (void)
+File_Open_Lock_and_Check::mark_object_current ()
 {
   // Reset the stale flag
   context_->stale (false);
@@ -403,7 +402,7 @@ TAO_Storable_Naming_Context::TAO_Storable_Naming_Context (
   ACE_TRACE("TAO_Storable_Naming_Context");
 }
 
-TAO_Storable_Naming_Context::~TAO_Storable_Naming_Context (void)
+TAO_Storable_Naming_Context::~TAO_Storable_Naming_Context ()
 {
   ACE_TRACE("~TAO_Storable_Naming_Context");
 
@@ -431,7 +430,7 @@ TAO_Storable_Naming_Context::~TAO_Storable_Naming_Context (void)
 }
 
 void
-TAO_Storable_Naming_Context::context_written (void)
+TAO_Storable_Naming_Context::context_written ()
 {
   // No-op. Overridden by derived class.
 }
@@ -446,7 +445,7 @@ TAO_Storable_Naming_Context::is_obsolete (time_t stored_time)
 }
 
 void
-TAO_Storable_Naming_Context::verify_not_destroyed (void)
+TAO_Storable_Naming_Context::verify_not_destroyed ()
 {
   File_Open_Lock_and_Check flck (this, SFG::ACCESSOR, false);
   if (this->destroyed_)
@@ -540,7 +539,7 @@ TAO_Storable_Naming_Context::make_new_context (
 }
 
 CosNaming::NamingContext_ptr
-TAO_Storable_Naming_Context::new_context (void)
+TAO_Storable_Naming_Context::new_context ()
 {
   ACE_TRACE ("new_context");
 
@@ -837,7 +836,7 @@ TAO_Storable_Naming_Context::bind (const CosNaming::Name& n,
 }
 
 void
-TAO_Storable_Naming_Context::destroy (void)
+TAO_Storable_Naming_Context::destroy ()
 {
   ACE_TRACE("TAO_Storable_Naming_Context::destroy");
   ACE_WRITE_GUARD_THROW_EX (ACE_SYNCH_RW_MUTEX,
