@@ -99,7 +99,7 @@ TAO_Notify_Admin::subscribed_types (TAO_Notify_EventTypeSeq& subscribed_types)
 }
 
 int
-TAO_Notify_Admin::shutdown (void)
+TAO_Notify_Admin::shutdown ()
 {
   if (TAO_Notify_Object::shutdown () == 1)
     return 1;
@@ -209,7 +209,7 @@ TAO_Notify_Admin::load_child (const ACE_CString &type,
 }
 
 void
-TAO_Notify_Admin::reconnect (void)
+TAO_Notify_Admin::reconnect ()
 {
   TAO_Notify::Reconnect_Worker<TAO_Notify_Proxy> wrk;
   this->proxy_container().collection()->for_each(&wrk);
