@@ -50,7 +50,7 @@ public:
   /// Destructor
   virtual ~TAO_Notify_ProxyPushSupplier ();
 
-  virtual const char * get_proxy_type_name (void) const;
+  virtual const char * get_proxy_type_name () const;
 
   virtual void load_attrs (const TAO_Notify::NVPList& attrs);
   virtual void validate ();
