@@ -40,7 +40,7 @@ public:
   void init (CosEventComm::PushSupplier_ptr push_supplier);
 
   /// Retrieve the ior of this peer
-  virtual ACE_CString get_ior (void) const;
+  virtual ACE_CString get_ior () const;
 
 protected:
 
