@@ -11,7 +11,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Notify_Constraint_Expr::TAO_Notify_Constraint_Expr (void)
+TAO_Notify_Constraint_Expr::TAO_Notify_Constraint_Expr ()
 {
 }
 
@@ -86,7 +86,7 @@ TAO_Notify_Constraint_Expr::load_child (
 
 
 void
-TAO_Notify_Constraint_Expr::release (void)
+TAO_Notify_Constraint_Expr::release ()
 {
   delete this;
   //@@ inform factory
@@ -124,7 +124,7 @@ TAO_Notify_ETCL_Filter::~TAO_Notify_ETCL_Filter ()
 }
 
 char*
-TAO_Notify_ETCL_Filter::constraint_grammar (void)
+TAO_Notify_ETCL_Filter::constraint_grammar ()
 {
   return CORBA::string_dup (this->grammar_.c_str ());
 }
@@ -147,7 +147,7 @@ TAO_Notify_ETCL_Filter::add_constraint_i (CosNotifyFilter::ConstraintID cnstr_id
   ACE_NEW_THROW_EX (notify_constr_expr,
     TAO_Notify_Constraint_Expr (),
     CORBA::NO_MEMORY ());
-  auto_ptr <TAO_Notify_Constraint_Expr> auto_expr (notify_constr_expr);
+  std::unique_ptr <TAO_Notify_Constraint_Expr> auto_expr (notify_constr_expr);
 
   if (TAO_debug_level > 1)
     ORBSVCS_DEBUG ((LM_DEBUG,
@@ -172,7 +172,7 @@ TAO_Notify_ETCL_Filter::add_constraint_i
   ACE_NEW_THROW_EX (notify_constr_expr,
     TAO_Notify_Constraint_Expr (),
     CORBA::NO_MEMORY ());
-  auto_ptr <TAO_Notify_Constraint_Expr> auto_expr (notify_constr_expr);
+  std::unique_ptr <TAO_Notify_Constraint_Expr> auto_expr (notify_constr_expr);
 
   CosNotifyFilter::ConstraintExp const & expr =
     constraint.constraint_expression;
@@ -364,7 +364,7 @@ TAO_Notify_ETCL_Filter::get_constraints (
 }
 
 CosNotifyFilter::ConstraintInfoSeq *
-TAO_Notify_ETCL_Filter::get_all_constraints (void)
+TAO_Notify_ETCL_Filter::get_all_constraints ()
 {
   ACE_GUARD_THROW_EX (TAO_SYNCH_MUTEX, ace_mon, this->lock_,
                       CORBA::INTERNAL ());
@@ -404,7 +404,7 @@ TAO_Notify_ETCL_Filter::get_all_constraints (void)
 }
 
 void
-TAO_Notify_ETCL_Filter::remove_all_constraints (void)
+TAO_Notify_ETCL_Filter::remove_all_constraints ()
 {
   ACE_GUARD_THROW_EX (TAO_SYNCH_MUTEX, ace_mon, this->lock_,
                       CORBA::INTERNAL ());
@@ -413,7 +413,7 @@ TAO_Notify_ETCL_Filter::remove_all_constraints (void)
 }
 
 void
-TAO_Notify_ETCL_Filter::remove_all_constraints_i (void)
+TAO_Notify_ETCL_Filter::remove_all_constraints_i ()
 {
   CONSTRAINT_EXPR_LIST::ITERATOR iter (this->constraint_expr_list_);
   CONSTRAINT_EXPR_LIST::ENTRY *entry;
@@ -431,7 +431,7 @@ TAO_Notify_ETCL_Filter::remove_all_constraints_i (void)
 }
 
 void
-TAO_Notify_ETCL_Filter::destroy (void)
+TAO_Notify_ETCL_Filter::destroy ()
 {
   ACE_GUARD_THROW_EX (TAO_SYNCH_MUTEX, ace_mon, this->lock_,
                       CORBA::INTERNAL ());
@@ -507,7 +507,7 @@ TAO_Notify_ETCL_Filter::detach_callback (
 }
 
 CosNotifyFilter::CallbackIDSeq *
-TAO_Notify_ETCL_Filter::get_callbacks (void)
+TAO_Notify_ETCL_Filter::get_callbacks ()
 {
   throw CORBA::NO_IMPLEMENT ();
 }
@@ -548,7 +548,7 @@ TAO_Notify_ETCL_Filter::save_persistent (TAO_Notify::Topology_Saver& saver)
 
 
 void
-TAO_Notify_ETCL_Filter::release (void)
+TAO_Notify_ETCL_Filter::release ()
 {
   delete this;
   //@@ inform factory
