@@ -10,7 +10,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Notify_ETCL_FilterFactory::TAO_Notify_ETCL_FilterFactory (void) :
+TAO_Notify_ETCL_FilterFactory::TAO_Notify_ETCL_FilterFactory () :
   filter_poa_ (PortableServer::POA::_nil ())
 {
 }
@@ -59,7 +59,7 @@ TAO_Notify_ETCL_FilterFactory::create (PortableServer::POA_ptr filter_poa)
 }
 
 void
-TAO_Notify_ETCL_FilterFactory::destroy (void)
+TAO_Notify_ETCL_FilterFactory::destroy ()
 {
   if (CORBA::is_nil(this->filter_poa_.in ()))
     return;
@@ -241,7 +241,7 @@ TAO_Notify_ETCL_FilterFactory::load_child (const ACE_CString &type,
 
 
 void
-TAO_Notify_ETCL_FilterFactory::release (void)
+TAO_Notify_ETCL_FilterFactory::release ()
 {
   delete this;
   //@@ inform factory
