@@ -1,4 +1,4 @@
-#include "orbsvcs/orbsvcs/Notify/MonitorControl/Timestamp_Monitor.h"
+#include "orbsvcs/Notify/MonitorControl/Timestamp_Monitor.h"
 
 #if defined (TAO_HAS_MONITOR_FRAMEWORK) && (TAO_HAS_MONITOR_FRAMEWORK == 1)
 
