@@ -3,7 +3,7 @@
 #include "orbsvcs/Log_Macros.h"
 #include "ace/Guard_T.h"
 
-#if ( TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0 )
+#if (TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0)
 
 #include <map>
 #include <string>
@@ -32,11 +32,11 @@ public:
 
   static TAO_Notify_Tracker& get_instance();
 
-  void add( TAO_Notify_Refcountable* p );
+  void add( TAO_Notify_Refcountable* p);
 
-  void remove( const TAO_Notify_Refcountable* p );
+  void remove( const TAO_Notify_Refcountable* p);
 
-  Entry find( const TAO_Notify_Refcountable* p ) const;
+  Entry find( const TAO_Notify_Refcountable* p) const;
 
   void dump( const char* title = 0 );
 
@@ -62,13 +62,13 @@ TAO_Notify_Refcountable::diagnostic_dump( const char* title )
 #endif /* TAO_NOTIFY_REFCOUNT_DIAGNOSTICS */
 
 
-TAO_Notify_Refcountable::TAO_Notify_Refcountable (void)
+TAO_Notify_Refcountable::TAO_Notify_Refcountable ()
 {
 }
 
 TAO_Notify_Refcountable::~TAO_Notify_Refcountable ()
 {
-#if ( TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0 )
+#if (TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0)
   TAO_Notify_Tracker::Entry e = TAO_Notify_Tracker::get_instance().find( this );
   if ( e.obj != 0 )
   {
@@ -90,14 +90,14 @@ TAO_Notify_Refcountable::~TAO_Notify_Refcountable ()
 
 
 CORBA::ULong
-TAO_Notify_Refcountable::_incr_refcnt (void)
+TAO_Notify_Refcountable::_incr_refcnt ()
 {
   CORBA::Long refcount = ++this->refcount_;
   if (TAO_debug_level > 1 )
   {
     ORBSVCS_DEBUG ((LM_DEBUG,"object:%x incr refcount = %d\n", this, refcount ));
   }
-#if ( TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0 )
+#if (TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0)
   // Stack-instantiated-non-servants should never have _incr_refcnt called.
   // We do not care about stack-instances. Stack-instantiated servants break
   // the tracker.
@@ -110,7 +110,7 @@ TAO_Notify_Refcountable::_incr_refcnt (void)
 }
 
 CORBA::ULong
-TAO_Notify_Refcountable::_decr_refcnt (void)
+TAO_Notify_Refcountable::_decr_refcnt ()
 {
   CORBA::Long refcount = --this->refcount_;
 
@@ -131,7 +131,7 @@ TAO_Notify_Refcountable::_decr_refcnt (void)
   return refcount;
 }
 
-#if ( TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0 )
+#if (TAO_NOTIFY_REFCOUNT_DIAGNOSTICS != 0)
 
 std::auto_ptr< TAO_Notify_Tracker > TAO_Notify_Tracker::s_instance;
 
@@ -227,7 +227,7 @@ TAO_Notify_Tracker::remove( const TAO_Notify_Refcountable* p )
 
 
 TAO_Notify_Tracker::Entry
-TAO_Notify_Tracker::find( const TAO_Notify_Refcountable* p ) const
+TAO_Notify_Tracker::find( const TAO_Notify_Refcountable* p) const
 {
   Entry e = { 0, "" };
   if ( p == 0 ) return e;
