@@ -277,7 +277,7 @@ Routing_Slip_Persistence_Manager::Block_Header::Block_Header(Header_Type type)
   , data_size(0)
 {
 }
-Routing_Slip_Persistence_Manager::Block_Header::~Block_Header (void)
+Routing_Slip_Persistence_Manager::Block_Header::~Block_Header ()
 {
 }
 
