@@ -251,8 +251,7 @@ TAO::PG_Object_Group_Storable::PG_Object_Group_Storable (
   // version already exists.
   bool stream_exists = false;
   {
-    ACE_Auto_Ptr<TAO::Storable_Base> stream (
-      this->create_stream ("r"));
+    ACE_Auto_Ptr<TAO::Storable_Base> stream (this->create_stream ("r"));
 
     if (stream->exists ())
       stream_exists = true;
@@ -290,8 +289,7 @@ TAO::PG_Object_Group_Storable::PG_Object_Group_Storable (
   // version already exists.
   bool stream_exists = false;
   {
-    ACE_Auto_Ptr<TAO::Storable_Base> stream (
-      this->create_stream ("r"));
+    ACE_Auto_Ptr<TAO::Storable_Base> stream (this->create_stream ("r"));
 
     if (stream->exists ())
       stream_exists = true;
@@ -307,20 +305,17 @@ TAO::PG_Object_Group_Storable::PG_Object_Group_Storable (
     }
 }
 
-TAO::PG_Object_Group_Storable::~PG_Object_Group_Storable (void)
+TAO::PG_Object_Group_Storable::~PG_Object_Group_Storable ()
 {
   if (destroyed_)
     {
-      ACE_Auto_Ptr<TAO::Storable_Base> stream (
-        this->create_stream ("r"));
+      ACE_Auto_Ptr<TAO::Storable_Base> stream (this->create_stream ("r"));
 
       if (stream->exists ())
         {
           stream->remove ();
         }
-
     }
-
 }
 
 void
@@ -330,7 +325,7 @@ TAO::PG_Object_Group_Storable::set_destroyed (bool destroyed)
 }
 
 const PortableGroup::Location &
-TAO::PG_Object_Group_Storable::get_primary_location (void)
+TAO::PG_Object_Group_Storable::get_primary_location ()
 {
   Object_Group_File_Guard fg (*this, SFG::ACCESSOR);
   return TAO::PG_Object_Group::get_primary_location ();
@@ -369,7 +364,7 @@ TAO::PG_Object_Group_Storable::remove_member (
 
 
 PortableGroup::Locations *
-TAO::PG_Object_Group_Storable::locations_of_members (void)
+TAO::PG_Object_Group_Storable::locations_of_members ()
 {
   Object_Group_File_Guard fg (*this, SFG::ACCESSOR);
   return PG_Object_Group::locations_of_members ();
@@ -397,14 +392,14 @@ TAO::PG_Object_Group_Storable::set_name (const char* group_name)
 }
 
 const char*
-TAO::PG_Object_Group_Storable::get_name (void)
+TAO::PG_Object_Group_Storable::get_name ()
 {
   Object_Group_File_Guard fg (*this, SFG::ACCESSOR);
   return PG_Object_Group::get_name ();
 }
 
 void
-TAO::PG_Object_Group_Storable::initial_populate (void)
+TAO::PG_Object_Group_Storable::initial_populate ()
 {
   Object_Group_File_Guard fg (*this, SFG::MUTATOR);
   PG_Object_Group::initial_populate ();
@@ -412,7 +407,7 @@ TAO::PG_Object_Group_Storable::initial_populate (void)
 }
 
 void
-TAO::PG_Object_Group_Storable::minimum_populate (void)
+TAO::PG_Object_Group_Storable::minimum_populate ()
 {
   Object_Group_File_Guard fg (*this, SFG::MUTATOR);
   PG_Object_Group::minimum_populate ();
@@ -601,8 +596,8 @@ TAO::PG_Object_Group_Storable::write (TAO::Storable_Base & stream)
   stream << properties_cdr;
 
   ///// members_ /////
-  int num_members = this->members_.current_size  ();
-  stream << num_members;
+  size_t const num_members = this->members_.current_size  ();
+  stream << static_cast<ACE_UINT64> (num_members);
   for (MemberMap_Iterator it = this->members_.begin ();
        it != this->members_.end ();
        ++it)
@@ -650,7 +645,7 @@ TAO::PG_Object_Group_Storable::stale ()
 }
 
 void
-TAO::PG_Object_Group_Storable::state_written (void)
+TAO::PG_Object_Group_Storable::state_written ()
 {
   // No-op. Overridden by derived class.
 }
