@@ -169,7 +169,7 @@ TAO::SSLIOP::ORBInitializer::post_init (
                     TAO::SSLIOP::CredentialsAcquirerFactory,
                     CORBA::NO_MEMORY ());
 
-  auto_ptr<TAO::SSLIOP::CredentialsAcquirerFactory> safe_factory;
+  std::unique_ptr<TAO::SSLIOP::CredentialsAcquirerFactory> safe_factory;
 
   tao_curator->register_acquirer_factory ("SL3TLS", factory);
 
