@@ -21,7 +21,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-Task_Entry::Task_Entry (void)
+Task_Entry::Task_Entry ()
   : rt_info_ (0),
     effective_period_(0),
     dfs_status_ (NOT_VISITED),
@@ -35,7 +35,7 @@ Task_Entry::Task_Entry (void)
 {
 }
 
-Task_Entry::~Task_Entry (void)
+Task_Entry::~Task_Entry ()
 {
   // Zero out the task entry ACT in the corresponding rt_info
   rt_info_->volatile_token = 0;
@@ -758,7 +758,7 @@ Dispatch_Proxy_Iterator::first (u_int sub_frame)
 // and -1 if an error occurred.
 
 int
-Dispatch_Proxy_Iterator::last (void)
+Dispatch_Proxy_Iterator::last ()
 {
   // use the last call
   current_call_ = number_of_calls_ - 1;
@@ -775,7 +775,7 @@ Dispatch_Proxy_Iterator::last (void)
 // and -1 if an error occurred.
 
 int
-Dispatch_Proxy_Iterator::advance (void)
+Dispatch_Proxy_Iterator::advance ()
 {
   int result = 1;
 
@@ -814,7 +814,7 @@ Dispatch_Proxy_Iterator::advance (void)
 // and -1 if an error occurred.
 
 int
-Dispatch_Proxy_Iterator::retreat (void)
+Dispatch_Proxy_Iterator::retreat ()
 {
   int result = 1;
 
@@ -851,7 +851,7 @@ Dispatch_Proxy_Iterator::retreat (void)
 // returns the adjusted arrival time of the virtual entry
 
 RtecScheduler::Time
-Dispatch_Proxy_Iterator::arrival (void) const
+Dispatch_Proxy_Iterator::arrival () const
 {
   Dispatch_Entry_Link *link;
   if (iter_.done ()
@@ -868,7 +868,7 @@ Dispatch_Proxy_Iterator::arrival (void) const
 // returns the adjusted deadline time of the virtual entry
 
 RtecScheduler::Time
-Dispatch_Proxy_Iterator::deadline (void) const
+Dispatch_Proxy_Iterator::deadline () const
 {
   Dispatch_Entry_Link *link;
   if (iter_.done ()
@@ -885,7 +885,7 @@ Dispatch_Proxy_Iterator::deadline (void) const
 // returns the scheduler priority of the virtual entry
 
 Dispatch_Proxy_Iterator::Preemption_Priority
-Dispatch_Proxy_Iterator::priority (void) const
+Dispatch_Proxy_Iterator::priority () const
 {
   Dispatch_Entry_Link *link;
 
@@ -900,7 +900,7 @@ Dispatch_Proxy_Iterator::priority (void) const
 // returns the OS priority of the virtual entry
 
 Dispatch_Proxy_Iterator::OS_Priority
-Dispatch_Proxy_Iterator::OS_priority (void) const
+Dispatch_Proxy_Iterator::OS_priority () const
 {
   Dispatch_Entry_Link *link;
   if (iter_.done ()
