@@ -3,7 +3,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO::Security::Current_Impl::~Current_Impl (void)
+TAO::Security::Current_Impl::~Current_Impl ()
 {
 }
 
