@@ -6,10 +6,6 @@
 
 #include "EC_Destroyer.h"
 
-#if !defined(__ACE_INLINE__)
-#include "EC_Destroyer.inl"
-#endif /* __ACE_INLINE__ */
-
 EC_Destroyer::EC_Destroyer (RtecEventChannelAdmin::EventChannel_ptr ec)
   :  ec_ (RtecEventChannelAdmin::EventChannel::_duplicate (ec))
 {
