@@ -75,10 +75,7 @@ Low_Priority_Setup (int consumer_count,
                             this->clients_[j].supplier (),
                             barrier);
       this->tasks_[j].thr_mgr (&this->thr_mgr_);
-      ACE_auto_ptr_reset (this->stoppers_[j],
-                          new Send_Task_Stopper (thread_priority,
-                                                 thread_sched_class,
-                                                 &this->tasks_[j]));
+      this->stoppers_[j].reset (new Send_Task_Stopper (thread_priority, thread_sched_class, &this->tasks_[j]));
     }
 }
 
