@@ -9,10 +9,6 @@
 #include "RIR_Narrow.h"
 #include "tao/Policy_ManagerC.h"
 
-#if !defined(__ACE_INLINE__)
-#include "PriorityBand_Setup.inl"
-#endif /* __ACE_INLINE__ */
-
 PriorityBand_Setup::PriorityBand_Setup (CORBA::ORB_ptr orb,
                                         const RTCORBA_Setup &rtcorba_setup)
 {
