@@ -11,7 +11,7 @@
 #include "RTCORBA_Setup.h"
 #include "PriorityBand_Setup.h"
 #include "SyncScope_Setup.h"
-#include "ace/Auto_Ptr.h"
+#include <memory>
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -34,7 +34,7 @@ public:
                   int nthreads);
 
   /// Return non-zero if RTCORBA is enabled
-  int use_rt_corba (void) const;
+  int use_rt_corba () const;
 
   /// Return the underlying RTCORBA_Setup pointer
   RTCORBA_Setup *rtcorba_setup (void);
@@ -42,8 +42,7 @@ public:
 private:
   int use_rt_corba_;
 
-  auto_ptr<RTCORBA_Setup> rtcorba_setup_;
-  auto_ptr<PriorityBand_Setup> priorityband_setup_;
+  std::unique_ptr<RTCORBA_Setup> rtcorba_setup_;
   SyncScope_Setup syncscope_setup_;
 };
 
