@@ -19,7 +19,7 @@ Hello::get_string (void)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 void
