@@ -111,7 +111,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
         {
           hello->check_extended_context ();
         }
-      catch (Test::MyException& my_ex)
+      catch (const Test::MyException&)
         {
           ACE_DEBUG ((LM_ERROR, "Error - REGRESSION - extended format service context not transmitted\n"));
           result = 1;
@@ -130,7 +130,6 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       return 1;
     }
 
-
   if (result)
     {
       ACE_DEBUG ((LM_ERROR, "Error: REGRESSION identified!!!\n"));
