@@ -220,7 +220,7 @@ Test_Supplier::disconnect_push_supplier (void)
 {
 }
 
-int Test_Supplier::supplier_id (void) const
+int Test_Supplier::supplier_id () const
 {
   return this->supplier_id_;
 }
