@@ -72,7 +72,7 @@ EC_Consumer::disconnect (void)
 
   this->ec_->destroy ();
 
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 ////////////////////////////////////////////////////////////
