@@ -31,7 +31,7 @@ public:
   // = The EC_Driver methods
   /// add some command line args to enable/disable throughputions
   virtual int parse_args (int& argc, ACE_TCHAR* argv[]);
-  virtual void print_args (void) const;
+  virtual void print_args () const;
   virtual void print_usage (void);
 
   /// set the throughpution flags
