@@ -52,7 +52,7 @@ McastHello::send_large_octet_array (const Test::Octets &payload)
 void
 McastHello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 CORBA::Boolean
