@@ -1,5 +1,3 @@
-// $Id: Test_impl.cpp 96016 2012-08-08 15:48:50Z sma $
-
 #include "Test_impl.h"
 
 
@@ -11,5 +9,5 @@ Server_impl::Server_impl (CORBA::ORB_ptr orb)
 
 void Server_impl::shutdown ()
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
