@@ -191,7 +191,7 @@ ExtendedFilter::add_filter (CosNotifyFilter::FilterAdmin_ptr filter_admin)
   constraint_list[0].event_types.length (0);
   constraint_list[0].constraint_expr = CORBA::string_dup (test_filter_string);
 
-  filter->add_constraints (constraint_list);
+  CosNotifyFilter::ConstraintInfoSeq_var cons_info = filter->add_constraints (constraint_list);
 
   CosNotifyFilter::FilterID id = filter_admin->add_filter (filter.in ());
 
