@@ -47,10 +47,10 @@ $nfs->DeleteFile ($nfsiorfile);
 $sup->DeleteFile ($supiorfile);
 $con->DeleteFile ($supiorfile);
 
-$NS = $ns->CreateProcess ("../../../Naming_Service/tao_cosnaming",
+$NS = $ns->CreateProcess ("$ENV{TAO_ROOT}/orbsvcs/Naming_Service/tao_cosnaming",
                           " -ORBEndpoint iiop://$ns_host:$ns_port");
 
-$NFS = $nfs->CreateProcess ("../../../Notify_Service/tao_cosnotification",
+$NFS = $nfs->CreateProcess ("$ENV{TAO_ROOT}/orbsvcs/Notify_Service/tao_cosnotification",
                             "-ORBInitRef NameService=corbaloc::" .
                             "$ns_host:$ns_port/NameService " .
                             "-IORoutput $nfs_nfsiorfile -ORBSvcConf " .
@@ -204,7 +204,7 @@ $sup->DeleteFile ($supiorfile);
 $con->DeleteFile ($supiorfile);
 $nfs->DeleteFile ($nfsiorfile);
 
-$NFS = $nfs->CreateProcess ("../../../Notify_Service/tao_cosnotification",
+$NFS = $nfs->CreateProcess ("$ENV{TAO_ROOT}/orbsvcs/Notify_Service/tao_cosnotification",
                             "-ORBInitRef NameService=corbaloc::" .
                             "$ns_host:$ns_port/NameService " .
                             "-IORoutput $nfs_nfsiorfile -ORBSvcConf " .
