@@ -44,10 +44,10 @@ $nfs->DeleteFile ($nfsiorfile);
 $sup->DeleteFile ($supiorfile);
 $con->DeleteFile ($supiorfile);
 
-$NS = $ns->CreateProcess ("../../../Naming_Service/tao_cosnaming",
+$NS = $ns->CreateProcess ("$ENV{TAO_ROOT}/orbsvcs/Naming_Service/tao_cosnaming",
                             "-ORBEndpoint iiop://$host:$port ".
                             "-o $ns_nsiorfile");
-$NFS = $nfs->CreateProcess ("../../../Notify_Service/tao_cosnotification",
+$NFS = $nfs->CreateProcess ("$ENV{TAO_ROOT}/orbsvcs/Notify_Service/tao_cosnotification",
                             "-ORBInitRef NameService=iioploc://" .
                             "$host:$port/NameService " .
                             "-IORoutput $nfs_nfsiorfile -ORBSvcConf " .
