@@ -31,9 +31,7 @@ class TAO_Notify_Tests_Peer;
  */
 class TAO_NOTIFY_TEST_Export Notify_Test_Client
 {
-
 public:
-  // = Initialization and Termination
   Notify_Test_Client (void);
   virtual ~Notify_Test_Client ();
 
@@ -54,7 +52,7 @@ public:
   void consumer_done (TAO_Notify_Tests_Peer*);
 
   /// Access the done boolean.
-  bool is_done (void) const;
+  bool is_done () const;
 
   /// Access the ORB.  This class retains ownership.
   CORBA::ORB_ptr orb (void);
