@@ -130,7 +130,7 @@ RedGreen_Test::run (void)
     }
 
     this->destroy_ec ();
-    this->orb_->shutdown (0);
+    this->orb_->shutdown (false);
   }
   catch (const CORBA::Exception& ex)
   {
@@ -395,8 +395,7 @@ RedGreen_Test_StructuredPushConsumer::~RedGreen_Test_StructuredPushConsumer (
 
 void
 RedGreen_Test_StructuredPushConsumer::accumulate_into (
-    ACE_Throughput_Stats &throughput
-  ) const
+    ACE_Throughput_Stats &throughput) const
 {
   throughput.accumulate (this->throughput_);
 }
