@@ -27,5 +27,5 @@ Simple_Server_i::send_line (const char *)
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
