@@ -36,7 +36,7 @@ public:
   Server_Worker (CORBA::ORB_ptr orb);
 
   /// The thread entry point.
-  virtual int svc (void);
+  virtual int svc ();
 
 
 private:
