@@ -38,7 +38,7 @@ public:
                  int niterations);
 
   /// thread entry point
-  virtual int svc (void);
+  virtual int svc ();
 
 private:
   /// Validate the connection
