@@ -18,7 +18,7 @@ Simple_Server_i::test_method (CORBA::Long x)
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 //---------------------------------------------------------------------------
