@@ -11,5 +11,5 @@ void
 Foo_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,"SUCCESS: server received expected shutdown\n"));
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
