@@ -14,7 +14,7 @@ public:
   Worker_Thread (CORBA::ORB_ptr orb);
 
   // = The service method
-  virtual int svc (void);
+  virtual int svc ();
 
 private:
   CORBA::ORB_var orb_;
