@@ -22,5 +22,5 @@ Factory::create_simple_object (void)
 void
 Factory::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
