@@ -142,8 +142,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       ACE_DEBUG ((LM_DEBUG, "event loop finished\n"));
 
-      root_poa->destroy (1,
-                         1);
+      root_poa->destroy (true, true);
     }
   catch (const CORBA::Exception& ex)
     {
