@@ -469,7 +469,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       roundtrip->shutdown ();
 
-      root_poa->destroy (1, 1);
+      root_poa->destroy (true, true);
 
       orb->destroy ();
     }
