@@ -2,7 +2,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Adapter::~TAO_Adapter (void)
+TAO_Adapter::~TAO_Adapter ()
 {
 }
 
