@@ -4,7 +4,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Adapter_Factory::~TAO_Adapter_Factory (void)
+TAO_Adapter_Factory::~TAO_Adapter_Factory ()
 {
 }
 
