@@ -9,19 +9,20 @@
 #include "ace/Log_Msg.h"
 #include "ace/OS_NS_string.h"
 #include "ace/CORBA_macros.h"
+#include <cstring>
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Adapter_Registry::TAO_Adapter_Registry (TAO_ORB_Core *)
   : adapters_capacity_ (16), // @@ Make it configurable
     adapters_count_ (0),
-    adapters_ (0)
+    adapters_ (nullptr)
 {
   ACE_NEW (this->adapters_,
            TAO_Adapter*[this->adapters_capacity_]);
 }
 
-TAO_Adapter_Registry::~TAO_Adapter_Registry (void)
+TAO_Adapter_Registry::~TAO_Adapter_Registry ()
 {
   for (size_t i = 0; i != this->adapters_count_; ++i)
     delete this->adapters_[i];
@@ -67,7 +68,7 @@ TAO_Adapter_Registry::insert (TAO_Adapter *adapter)
   if (this->adapters_capacity_ == this->adapters_count_)
     {
       this->adapters_capacity_ *= 2;
-      TAO_Adapter **tmp = 0;
+      TAO_Adapter **tmp = nullptr;
       ACE_NEW_THROW_EX (tmp,
                         TAO_Adapter*[this->adapters_capacity_],
                         CORBA::NO_MEMORY ());
@@ -126,7 +127,7 @@ TAO_Adapter_Registry::create_collocated_object (TAO_Stub *stub,
     {
       CORBA::Object_ptr x =
         this->adapters_[i]->create_collocated_object (stub, mprofile);
-      if (x != 0)
+      if (x != nullptr)
         {
           if (!stub->collocated_servant ())
             {
@@ -145,7 +146,7 @@ TAO_Adapter_Registry::create_collocated_object (TAO_Stub *stub,
           return x;
         }
     }
-  return 0;
+  return nullptr;
 }
 
 CORBA::Long
@@ -171,10 +172,10 @@ TAO_Adapter_Registry::find_adapter (const char *name) const
   for (TAO_Adapter **i = this->adapters_;
        i != this->adapters_ + this->adapters_count_;
        ++i)
-    if (ACE_OS::strcmp ((*i)->name (), name) == 0)
+    if (std::strcmp ((*i)->name (), name) == 0)
       return *i;
 
-  return 0;
+  return nullptr;
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
