@@ -35,7 +35,7 @@ namespace TAO
   {
   public:
 
-    virtual ~TAO_Allocator (void) {}
+    virtual ~TAO_Allocator () {}
 
     virtual handler_type *allocate () = 0;
     virtual void release (handler_type *ptr) = 0;
