@@ -158,11 +158,7 @@ TAO::Any_Dual_Impl_T<T>::replace (TAO_InputCDR &cdr,
   ACE_NEW_RETURN (empty_value,
                   T,
                   false);
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<T> empty_value_safety (empty_value);
-#else
-  auto_ptr<T> empty_value_safety (empty_value);
-#endif /* ACE_HAS_CPP11 */
   TAO::Any_Dual_Impl_T<T> *replacement = 0;
   ACE_NEW_RETURN (replacement,
                   TAO::Any_Dual_Impl_T<T> (destructor,
@@ -170,11 +166,7 @@ TAO::Any_Dual_Impl_T<T>::replace (TAO_InputCDR &cdr,
                                            empty_value),
                   false);
 
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO::Any_Dual_Impl_T<T> > replacement_safety (replacement);
-#else
-  auto_ptr<TAO::Any_Dual_Impl_T<T> > replacement_safety (replacement);
-#endif /* ACE_HAS_CPP11 */
 
   CORBA::Boolean const good_decode = replacement->demarshal_value (cdr);
 
@@ -201,7 +193,7 @@ TAO::Any_Dual_Impl_T<T>::marshal_value (TAO_OutputCDR &cdr)
 
 template<typename T>
 const void *
-TAO::Any_Dual_Impl_T<T>::value (void) const
+TAO::Any_Dual_Impl_T<T>::value () const
 {
   return this->value_;
 }
