@@ -1,5 +1,3 @@
-// $Id: Struct_TypeCode.cpp 97508 2014-01-07 11:39:31Z johnnyw $
-
 #ifndef TAO_STRUCT_TYPECODE_CPP
 #define TAO_STRUCT_TYPECODE_CPP
 
@@ -17,6 +15,7 @@
 #endif  /* !__ACE_INLINE__ */
 
 #include "ace/Dynamic_Service.h"
+#include "ace/Truncate.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -44,8 +43,9 @@ TAO::TypeCode::Struct<StringType,
   // Aligning on an octet since the next value after the CDR
   // encapsulation length will always be the byte order octet/boolean
   // in this case.
-  offset = ACE_align_binary (offset + 4,
-                             ACE_CDR::OCTET_ALIGN);
+  offset = ACE_Utils::truncate_cast<CORBA::ULong> (
+              ACE_align_binary (offset + 4,
+                                ACE_CDR::OCTET_ALIGN));
 
   bool const success =
     (enc << TAO_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER))
@@ -69,7 +69,8 @@ TAO::TypeCode::Struct<StringType,
                        Traits<StringType>::get_string (field.name), 0))
           || !marshal (enc,
                        Traits<StringType>::get_typecode (field.type),
-                       offset + enc.total_length ()))
+                       ACE_Utils::truncate_cast<CORBA::ULong> (
+                           offset + enc.total_length ())))
         return false;
     }
 
@@ -112,7 +113,7 @@ const FieldArrayType&
 TAO::TypeCode::Struct<StringType,
                       TypeCodeType,
                       FieldArrayType,
-                      RefCountPolicy>::fields (void) const
+                      RefCountPolicy>::fields () const
 {
   return fields_;
 }
@@ -146,7 +147,7 @@ TAO::TypeCode::Struct<StringType,
         Traits<StringType>::get_string (lhs_field.name);
       char const * const rhs_name = tc->member_name (i);
 
-      if (ACE_OS::strcmp (lhs_name, rhs_name) != 0)
+      if (std::strcmp (lhs_name, rhs_name) != 0)
         return false;
 
       CORBA::TypeCode_ptr const lhs_tc =
@@ -209,7 +210,7 @@ CORBA::TypeCode_ptr
 TAO::TypeCode::Struct<StringType,
                       TypeCodeType,
                       FieldArrayType,
-                      RefCountPolicy>::get_compact_typecode_i (void) const
+                      RefCountPolicy>::get_compact_typecode_i () const
 {
   ACE_Array_Base<Struct_Field<CORBA::String_var,
                               CORBA::TypeCode_var> >
@@ -259,7 +260,7 @@ char const *
 TAO::TypeCode::Struct<StringType,
                       TypeCodeType,
                       FieldArrayType,
-                      RefCountPolicy>::id_i (void) const
+                      RefCountPolicy>::id_i () const
 {
   // Ownership is retained by the TypeCode, as required by the C++
   // mapping.
@@ -274,7 +275,7 @@ char const *
 TAO::TypeCode::Struct<StringType,
                       TypeCodeType,
                       FieldArrayType,
-                      RefCountPolicy>::name_i (void) const
+                      RefCountPolicy>::name_i () const
 {
   // Ownership is retained by the TypeCode, as required by the C++
   // mapping.
@@ -289,7 +290,7 @@ CORBA::ULong
 TAO::TypeCode::Struct<StringType,
                       TypeCodeType,
                       FieldArrayType,
-                      RefCountPolicy>::member_count_i (void) const
+                      RefCountPolicy>::member_count_i () const
 {
   return this->nfields_;
 }
