@@ -38,7 +38,6 @@ namespace TAO
               class FieldArrayType,
               class RefCountPolicy> class Struct;
 
-
     /**
      * @class Struct
      *
@@ -58,7 +57,6 @@ namespace TAO
         private TAO::Null_RefCount_Policy
     {
     public:
-
       /// Constructor.
       Struct (CORBA::TCKind kind,
               char const * id,
@@ -78,12 +76,11 @@ namespace TAO
       //@{
       virtual bool tao_marshal (TAO_OutputCDR & cdr,
                                 CORBA::ULong offset) const;
-      virtual void tao_duplicate (void);
-      virtual void tao_release (void);
+      virtual void tao_duplicate ();
+      virtual void tao_release ();
       //@}
 
     protected:
-
       /**
        * @name @c TAO CORBA::TypeCode Template Methods
        *
@@ -95,16 +92,15 @@ namespace TAO
       //@{
       virtual CORBA::Boolean equal_i (CORBA::TypeCode_ptr tc) const;
       virtual CORBA::Boolean equivalent_i (CORBA::TypeCode_ptr tc) const;
-      virtual CORBA::TypeCode_ptr get_compact_typecode_i (void) const;
-      virtual char const * id_i (void) const;
-      virtual char const * name_i (void) const;
-      virtual CORBA::ULong member_count_i (void) const;
+      virtual CORBA::TypeCode_ptr get_compact_typecode_i () const;
+      virtual char const * id_i () const;
+      virtual char const * name_i () const;
+      virtual CORBA::ULong member_count_i () const;
       virtual char const * member_name_i (CORBA::ULong index) const;
       virtual CORBA::TypeCode_ptr member_type_i (CORBA::ULong index) const;
       //@}
 
     private:
-
       /**
        * @c Struct Attributes
        *
@@ -128,9 +124,7 @@ namespace TAO
       /// OMG IDL defined @c struct.
       Struct_Field<char const *,
                    CORBA::TypeCode_ptr const *> const * const fields_;
-
       //@}
-
     };
 
   }  // End namespace TypeCode
