@@ -2,7 +2,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_ClientRequestInterceptor_Adapter_Factory::~TAO_ClientRequestInterceptor_Adapter_Factory (void)
+TAO_ClientRequestInterceptor_Adapter_Factory::~TAO_ClientRequestInterceptor_Adapter_Factory ()
 {
 }
 
