@@ -121,7 +121,6 @@ ACE_CDR::Boolean
 TAO_UTF8_Latin1_Translator::read_string (ACE_InputCDR &cdr,
                                          std::string &x)
 {
-#if defined (ACE_HAS_CPP11)
   ACE_CDR::ULong len;
   if (!cdr.read_ulong (len))
     return false;
@@ -161,9 +160,6 @@ TAO_UTF8_Latin1_Translator::read_string (ACE_InputCDR &cdr,
 
   x.clear ();
   return false;
-#else
-  return this->ACE_Char_Codeset_Translator::read_string (cdr, x);
-#endif
 }
 
 ACE_CDR::Boolean
