@@ -4,14 +4,14 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Codeset_Manager::~TAO_Codeset_Manager (void)
+TAO_Codeset_Manager::~TAO_Codeset_Manager ()
 {
 }
 
 // Add the destructor for the codeset_descriptor_base here, because
 // it is only ever used in conjunction with the codeset manager.
 
-TAO_Codeset_Descriptor_Base::~TAO_Codeset_Descriptor_Base (void)
+TAO_Codeset_Descriptor_Base::~TAO_Codeset_Descriptor_Base ()
 {
 }
 
