@@ -16,7 +16,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Codeset_Translator_Base::~TAO_Codeset_Translator_Base (void)
+TAO_Codeset_Translator_Base::~TAO_Codeset_Translator_Base ()
 {
 
 }
