@@ -40,8 +40,8 @@ namespace TAO
         ::Compression::CompressionLevel compression_level);
 
   private:
-    ACE_UNIMPLEMENTED_FUNC (Zlib_CompressorFactory (const Zlib_CompressorFactory &))
-    ACE_UNIMPLEMENTED_FUNC (Zlib_CompressorFactory &operator= (const Zlib_CompressorFactory &))
+    Zlib_CompressorFactory (const Zlib_CompressorFactory &) = delete;
+    Zlib_CompressorFactory &operator= (const Zlib_CompressorFactory &) = delete;
 
     // Ensure we can lock with imutability (i.e. const)
     mutable TAO_SYNCH_MUTEX mutex_;
