@@ -8,16 +8,12 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Default_Stub_Factory::~TAO_Default_Stub_Factory (void)
-{
-}
-
 TAO_Stub *
 TAO_Default_Stub_Factory::create_stub (const char *repository_id,
                                        const TAO_MProfile &profiles,
                                        TAO_ORB_Core *orb_core)
 {
-  TAO_Stub *retval = 0;
+  TAO_Stub *retval = nullptr;
 
   ACE_NEW_THROW_EX (retval,
                     TAO_Stub (repository_id, profiles, orb_core),
