@@ -31,11 +31,7 @@
 #include "tao/default_environment.h"
 
 #include "ace/Unbounded_Queue.h"
-#if defined (ACE_HAS_CPP11)
-# include <atomic>
-#else
-# include "ace/Atomic_Op.h"
-#endif /* ACE_HAS_CPP11 */
+#include <atomic>
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -73,25 +69,23 @@ namespace CORBA
   class TAO_DynamicInterface_Export Context
   {
   public:
-
-    Context (void);
-
-    ~Context (void);
+    Context () = default;
+    ~Context () = default;
 
     // = Pseudo-object methods
     static Context *_duplicate (Context*);
-    static Context *_nil (void);
+    static Context *_nil ();
 
     // = Reference counting.
-    CORBA::ULong _incr_refcount (void);
-    CORBA::ULong _decr_refcount (void);
+    CORBA::ULong _incr_refcount ();
+    CORBA::ULong _decr_refcount ();
 
     // = All the spec-required functions below will just throw a
     //   CORBA::NO_IMPLEMENT exception and do nothing else.
 
-    const char *context_name (void) const;
+    const char *context_name () const;
 
-    CORBA::Context_ptr parent (void) const;
+    CORBA::Context_ptr parent () const;
 
     void create_child (const char *child_ctx_name,
                        CORBA::Context_out child_ctx);
@@ -114,11 +108,7 @@ namespace CORBA
 
   private:
     /// Reference counter.
-#if defined (ACE_HAS_CPP11)
-    std::atomic<uint32_t> refcount_;
-#else
-    ACE_Atomic_Op<TAO_SYNCH_MUTEX, unsigned long> refcount_;
-#endif /* ACE_HAS_CPP11 */
+    std::atomic<uint32_t> refcount_ { 1 };
   };
 
   /**
@@ -132,7 +122,7 @@ namespace CORBA
   {
   public:
     /// Constructor.
-    ContextList (void);
+    ContextList () = default;
 
     /// Constructor - initialize given a length and an array of
     /// strings.
@@ -169,8 +159,8 @@ namespace CORBA
     void remove (CORBA::ULong slot);
 
     /// Increment and decrement ref counts.
-    void _incr_refcount (void);
-    void  _decr_refcount (void);
+    void _incr_refcount ();
+    void  _decr_refcount ();
 
     // Useful for template programming.
     typedef CORBA::ContextList_ptr _ptr_type;
@@ -178,16 +168,11 @@ namespace CORBA
     typedef CORBA::ContextList_out _out_type;
 
   private:
-    // Not allowed.
-    ContextList (const ContextList &);
-    ContextList &operator= (const ContextList &);
+    ContextList (const ContextList &) = delete;
+    ContextList &operator= (const ContextList &) = delete;
 
     /// Reference counter.
-#if defined (ACE_HAS_CPP11)
     std::atomic<uint32_t> refcount_;
-#else
-    ACE_Atomic_Op<TAO_SYNCH_MUTEX, unsigned long> refcount_;
-#endif /* ACE_HAS_CPP11 */
 
     /// Internal list of typecodes.
     ACE_Unbounded_Queue<char *> ctx_list_;
