@@ -40,11 +40,7 @@
 #endif /* TAO_HAS_AMI */
 
 #include "ace/SString.h"
-#if defined (ACE_HAS_CPP11)
-# include <atomic>
-#else
-# include "ace/Atomic_Op.h"
-#endif /* ACE_HAS_CPP11 */
+#include <atomic>
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -70,12 +66,11 @@ namespace CORBA
   class TAO_DynamicInterface_Export Request
   {
   public:
-
     /// Return the target of this request.
-    CORBA::Object_ptr target (void) const;
+    CORBA::Object_ptr target () const;
 
     /// Return the operation name for the request.
-    const CORBA::Char *operation (void) const;
+    const CORBA::Char *operation () const;
 
     /// Return the arguments for the request.
     CORBA::NVList_ptr arguments (void);
@@ -87,7 +82,7 @@ namespace CORBA
     CORBA::ExceptionList_ptr exceptions (void);
 
     /// Accessor for the Context member.
-    CORBA::Context_ptr ctx (void) const;
+    CORBA::Context_ptr ctx () const;
 
     /// Mutator for the Context member.
     void ctx (CORBA::Context_ptr);
@@ -104,11 +99,11 @@ namespace CORBA
      * <<=.
      */
     //@{
-    CORBA::Any &add_in_arg (void);
+    CORBA::Any &add_in_arg ();
     CORBA::Any &add_in_arg (const char* name);
-    CORBA::Any &add_inout_arg (void);
+    CORBA::Any &add_inout_arg ();
     CORBA::Any &add_inout_arg (const char* name);
-    CORBA::Any &add_out_arg (void);
+    CORBA::Any &add_out_arg ();
     CORBA::Any &add_out_arg (const char* name);
     //@}
 
@@ -116,7 +111,7 @@ namespace CORBA
     void set_return_type (CORBA::TypeCode_ptr tc);
 
     /// Returns reference to Any for extraction using >>=.
-    CORBA::Any &return_value (void);
+    CORBA::Any &return_value ();
 
     /// Perform method resolution and invoke an appropriate method.
     /**
@@ -130,7 +125,7 @@ namespace CORBA
      *       recommended as the user may not be able to propagate the
      *       exceptions.
      */
-    void invoke (void);
+    void invoke ();
 
     /// Send a oneway request.
     /**
@@ -138,7 +133,7 @@ namespace CORBA
      *       recommended as the user may not be able to propagate the
      *       exceptions.
      */
-    void send_oneway (void);
+    void send_oneway ();
 
     /**
      * @name The 'deferred synchronous' methods.
@@ -146,8 +141,8 @@ namespace CORBA
      * The 'deferred synchronous' methods.
      */
     //@{
-    void send_deferred (void);
-    void get_response (void);
+    void send_deferred ();
+    void get_response ();
     CORBA::Boolean poll_response (void);
     //@}
 
@@ -155,7 +150,7 @@ namespace CORBA
     void handle_response (TAO_InputCDR &incoming, GIOP::ReplyStatusType reply_status);
 
 #if defined (TAO_HAS_AMI)
-    /// The 'asychronous' send method. The object is a DSI based callback
+    /// The 'asynchronous' send method. The object is a DSI based callback
     /// handler. This handler must implement Messaging::ReplyHandler
     void sendc (CORBA::Object_ptr handler);
 
@@ -167,17 +162,17 @@ namespace CORBA
 
     /// Pseudo object methods.
     static CORBA::Request* _duplicate (CORBA::Request*);
-    static CORBA::Request* _nil (void);
+    static CORBA::Request* _nil ();
 
     // = Reference counting.
-    CORBA::ULong _incr_refcount (void);
-    CORBA::ULong _decr_refcount (void);
+    CORBA::ULong _incr_refcount ();
+    CORBA::ULong _decr_refcount ();
 
     /// Set the lazy evaluation flag.
     void _tao_lazy_evaluation (bool lazy_evaluation);
 
     /// Get the byte order member.
-    int _tao_byte_order (void) const;
+    int _tao_byte_order () const;
 
     /// Set the byte order member.
     void _tao_byte_order (int byte_order);
@@ -218,7 +213,6 @@ namespace CORBA
     ~Request (void);
 
   private:
-
     /// Target object.
     CORBA::Object_ptr target_;
 
@@ -250,11 +244,7 @@ namespace CORBA
     CORBA::Context_ptr ctx_;
 
     /// Reference counting.
-#if defined (ACE_HAS_CPP11)
     std::atomic<uint32_t> refcount_;
-#else
-    ACE_Atomic_Op<TAO_SYNCH_MUTEX, unsigned long> refcount_;
-#endif /* ACE_HAS_CPP11 */
 
     /// Protect the response_received_.
     TAO_SYNCH_MUTEX lock_;
