@@ -29,11 +29,7 @@
 
 #include "tao/TAO_Server_Request.h"
 #include "tao/CDR.h"
-#if defined (ACE_HAS_CPP11)
-# include <atomic>
-#else
-# include "ace/Atomic_Op.h"
-#endif /* ACE_HAS_CPP11 */
+#include <atomic>
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -96,27 +92,27 @@ namespace CORBA
     void dsi_marshal (void);
 
     /// Accessor for the Context member.
-    CORBA::Context_ptr ctx (void) const;
+    CORBA::Context_ptr ctx () const;
 
     /// Mutator for the Context member.
     void ctx (CORBA::Context_ptr);
 
     /// Get the operation name.
-    const char *operation (void) const;
+    const char *operation () const;
 
     // Pseudo object methods.
     static ServerRequest_ptr _duplicate (ServerRequest_ptr);
-    static ServerRequest_ptr _nil (void);
+    static ServerRequest_ptr _nil ();
 
     // = Reference counting.
-    CORBA::ULong _incr_refcount (void);
-    CORBA::ULong _decr_refcount (void);
+    CORBA::ULong _incr_refcount ();
+    CORBA::ULong _decr_refcount ();
 
     /// Set the lazy evaluation flag.
     void _tao_lazy_evaluation (bool lazy_evaluation);
 
     /// Get the byte order of the incoming CDR stream.
-    int _tao_incoming_byte_order (void) const;
+    int _tao_incoming_byte_order () const;
 
     /// Set the byte order of the outgoing CDR stream.
     void _tao_reply_byte_order (int byte_order);
@@ -150,11 +146,7 @@ namespace CORBA
     CORBA::Any_ptr exception_;
 
     /// Reference counting.
-#if defined (ACE_HAS_CPP11)
     std::atomic<uint32_t> refcount_;
-#else
-    ACE_Atomic_Op<TAO_SYNCH_MUTEX, unsigned long> refcount_;
-#endif /* ACE_HAS_CPP11 */
 
     /// Request from the ORB.
     TAO_ServerRequest &orb_server_request_;
