@@ -2,7 +2,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Flushing_Strategy::~TAO_Flushing_Strategy (void)
+TAO_Flushing_Strategy::~TAO_Flushing_Strategy ()
 {
 }
 
