@@ -46,11 +46,7 @@ TAO_IOR_Manipulation_impl::merge_iors (
   // get the profile lists, start by initialize the composite reference
   // by using the first Object.  Then for each subsequent Object verify
   // they are the same type and they do not have duplicate profiles.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_MProfile> tmp_pfiles (iors[0]->_stubobj ()->make_profiles ());
-#else
-  auto_ptr<TAO_MProfile> tmp_pfiles (iors[0]->_stubobj ()->make_profiles ());
-#endif /* ACE_HAS_CPP11 */
   if (Merged_Profiles.add_profiles (tmp_pfiles.get ())< 0)
     throw TAO_IOP::Invalid_IOR ();
   CORBA::String_var id =
@@ -59,8 +55,7 @@ TAO_IOR_Manipulation_impl::merge_iors (
   for (i = 1; i < iors.length () ; i++)
     {
       // this gets a copy of the MProfile, hence the auto_ptr;
-      ACE_auto_ptr_reset (tmp_pfiles,
-                          iors[i]->_stubobj ()->make_profiles ());
+      tmp_pfiles.reset (iors[i]->_stubobj ()->make_profiles ());
 
       // check to see if any of the profiles in tmp_pfiles are already
       // in Merged_Profiles.  If so raise exception.
@@ -75,12 +70,10 @@ TAO_IOR_Manipulation_impl::merge_iors (
       // append profiles
       if (Merged_Profiles.add_profiles (tmp_pfiles.get ()) < 0)
         throw TAO_IOP::Invalid_IOR ();
-
     }
 
   // MS C++ knows nothing about reset!
   // tmp_pfiles.reset (0); // get rid of last MProfile
-
   TAO_ORB_Core *orb_core = TAO_ORB_Core_instance ();
 
   TAO_Stub *stub = orb_core->create_stub (id.in (), // give the id string
@@ -98,7 +91,6 @@ TAO_IOR_Manipulation_impl::merge_iors (
 
   CORBA::Object_var new_obj = temp_obj;
 
-
   // Clean up in case of errors.
   if (CORBA::is_nil (new_obj.in ()))
     {
@@ -117,7 +109,6 @@ TAO_IOR_Manipulation_impl::add_profiles (
     CORBA::Object_ptr ior1,
     CORBA::Object_ptr ior2)
 {
-
   // Get an estimate of the number of profiles
   CORBA::Object_ptr buffer [2];
   buffer [0] = ior1;
@@ -129,8 +120,7 @@ TAO_IOR_Manipulation_impl::add_profiles (
 CORBA::Object_ptr
 TAO_IOR_Manipulation_impl::remove_profiles (
     CORBA::Object_ptr group,
-    CORBA::Object_ptr ior2
-    )
+    CORBA::Object_ptr ior2)
 {
   // First verify they are the same type!
   CORBA::String_var id =
@@ -150,11 +140,7 @@ TAO_IOR_Manipulation_impl::remove_profiles (
   // initialize with estimated pfile count.
   TAO_MProfile Diff_Profiles (count);
 
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_MProfile> tmp_pfiles (group->_stubobj ()->make_profiles ());
-#else
-  auto_ptr<TAO_MProfile> tmp_pfiles (group->_stubobj ()->make_profiles ());
-#endif /* ACE_HAS_CPP11 */
   if (Diff_Profiles.add_profiles (tmp_pfiles.get ()) < 0)
     throw TAO_IOP::Invalid_IOR ();
 
@@ -170,8 +156,7 @@ TAO_IOR_Manipulation_impl::remove_profiles (
   TAO_ORB_Core *orb_core = TAO_ORB_Core_instance ();
 
   TAO_Stub *stub = orb_core->create_stub (id.in (), // give the id string
-                                          Diff_Profiles
-                                         );
+                                          Diff_Profiles);
 
   // Make the stub memory allocation exception safe for the duration
   // of this method.
@@ -197,8 +182,7 @@ TAO_IOR_Manipulation_impl::remove_profiles (
 
   // Now we can remove the profiles which we want to eliminate from
   // the Object.
-  ACE_auto_ptr_reset (tmp_pfiles,
-                      ior2->_stubobj ()->make_profiles ());
+  tmp_pfiles.reset (ior2->_stubobj ()->make_profiles ());
 
   TAO_MProfile& mp = stub -> base_profiles();
   if (mp.remove_profiles (tmp_pfiles.get ()) < 0)
@@ -283,13 +267,8 @@ TAO_IOR_Manipulation_impl::is_in_ior (
   CORBA::ULong count = 0;
   TAO_Profile *pfile1 = 0;
   TAO_Profile *pfile2 = 0;
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_MProfile> tmp_pfiles1 (ior1->_stubobj ()->make_profiles ());
   std::unique_ptr<TAO_MProfile> tmp_pfiles2 (ior2->_stubobj ()->make_profiles ());
-#else
-  auto_ptr<TAO_MProfile> tmp_pfiles1 (ior1->_stubobj ()->make_profiles ());
-  auto_ptr<TAO_MProfile> tmp_pfiles2 (ior2->_stubobj ()->make_profiles ());
-#endif /* ACE_HAS_CPP11 */
 
   tmp_pfiles1->rewind ();
   while ((pfile1 = tmp_pfiles1->get_next ()) != 0)
