@@ -56,9 +56,8 @@ public:
 
   //@{
 protected:
-
   /// Check whether we have reached the final state..
-  virtual bool is_state_final (void) const;
+  virtual bool is_state_final () const;
 
   //@}
 private:
@@ -101,11 +100,11 @@ private:
 
   /// Return true if the condition was satisfied successfully, false if it
   /// has not
-  virtual bool successful_i (void) const;
+  virtual bool successful_i () const;
 
   /// Return true if an error was detected while waiting for the
   /// event
-  virtual bool error_detected_i (void) const;
+  virtual bool error_detected_i () const;
 
   /// Set the state irrespective of anything.
   virtual void set_state (LFS_STATE new_state);
@@ -114,7 +113,6 @@ private:
   virtual int unbind (TAO_LF_Follower *follower);
 
 private:
-
   /// The previous state that the LF_CH_Event was in
   LFS_STATE prev_state_;
 
