@@ -29,7 +29,7 @@ TAO_AMH_Response_Handler::TAO_AMH_Response_Handler ()
 {
 }
 
-TAO_AMH_Response_Handler::~TAO_AMH_Response_Handler (void)
+TAO_AMH_Response_Handler::~TAO_AMH_Response_Handler ()
 {
   this->transport_->remove_reference ();
 
@@ -86,7 +86,7 @@ TAO_AMH_Response_Handler::init(TAO_ServerRequest &server_request,
 }
 
 void
-TAO_AMH_Response_Handler::_tao_rh_init_reply (void)
+TAO_AMH_Response_Handler::_tao_rh_init_reply ()
 {
   {
     ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->mutex_);
@@ -126,7 +126,7 @@ TAO_AMH_Response_Handler::_tao_rh_init_reply (void)
 }
 
 void
-TAO_AMH_Response_Handler::_tao_rh_send_reply (void)
+TAO_AMH_Response_Handler::_tao_rh_send_reply ()
 {
   {
     ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->mutex_);
@@ -262,12 +262,10 @@ TAO_AMH_Response_Handler::_tao_rh_send_location_forward (CORBA::Object_ptr fwd,
     this->rh_reply_status_ = TAO_RS_SENDING;
   }
 
-
   TAO_Pluggable_Reply_Params_Base reply_params;
   reply_params.request_id_ = this->request_id_;
   reply_params.svc_ctx_.length (0);
-  reply_params.service_context_notowned
-    (&this->reply_service_context_.service_info ());
+  reply_params.service_context_notowned (&this->reply_service_context_.service_info ());
   reply_params.argument_flag_ = true;
   if (is_perm)
     {
@@ -313,7 +311,7 @@ TAO_AMH_Response_Handler::_tao_rh_send_location_forward (CORBA::Object_ptr fwd,
 }
 
 void
-TAO_AMH_Response_Handler::_remove_ref (void)
+TAO_AMH_Response_Handler::_remove_ref ()
 {
   if (--this->refcount_ == 0)
     {
