@@ -84,9 +84,10 @@ namespace TAO
   private:
     Nested_Upcall_Guard (void);
 
-    /// Disallow copying and assignment.
-    Nested_Upcall_Guard (const Nested_Upcall_Guard&);
-    Nested_Upcall_Guard &operator= (const Nested_Upcall_Guard&);
+    Nested_Upcall_Guard (const Nested_Upcall_Guard&) = delete;
+    Nested_Upcall_Guard &operator= (const Nested_Upcall_Guard&) = delete;
+    Nested_Upcall_Guard (Nested_Upcall_Guard&&) = delete;
+    Nested_Upcall_Guard &operator= (Nested_Upcall_Guard&&) = delete;
 
   private:
     /// Pointer to the transport that we plan to use.
