@@ -4,7 +4,7 @@
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Network_Priority_Protocols_Hooks::
-~TAO_Network_Priority_Protocols_Hooks (void)
+~TAO_Network_Priority_Protocols_Hooks ()
 {
 }
 
