@@ -3,7 +3,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_New_Leader_Generator::~TAO_New_Leader_Generator (void)
+TAO_New_Leader_Generator::~TAO_New_Leader_Generator ()
 {
 }
 
