@@ -2,7 +2,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Object_Loader::~TAO_Object_Loader (void)
+TAO_Object_Loader::~TAO_Object_Loader ()
 {
 }
 
