@@ -20,7 +20,7 @@
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO::ClientRequestInterceptor_Adapter*
-TAO_ClientRequestInterceptor_Adapter_Factory_Impl::create (void)
+TAO_ClientRequestInterceptor_Adapter_Factory_Impl::create ()
 {
   TAO::ClientRequestInterceptor_Adapter_Impl* obj = 0;
   ACE_NEW_RETURN (obj,
