@@ -11,7 +11,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 CORBA::PolicyList *
 TAO_Policy_Manager::get_policy_overrides (const CORBA::PolicyTypeSeq & ts)
 {
-  ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon, this->mutex_, 0);
+  ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon, this->mutex_, nullptr);
   return this->impl_.get_policy_overrides (ts);
 }
 
