@@ -116,11 +116,7 @@ TAO_Active_Object_Map::TAO_Active_Object_Map (
     }
 
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Id_Uniqueness_Strategy> new_id_uniqueness_strategy (id_uniqueness_strategy);
-#else
-  auto_ptr<TAO_Id_Uniqueness_Strategy> new_id_uniqueness_strategy (id_uniqueness_strategy);
-#endif /* ACE_HAS_CPP11 */
 
   TAO_Lifespan_Strategy *lifespan_strategy = 0;
 
@@ -144,11 +140,7 @@ TAO_Active_Object_Map::TAO_Active_Object_Map (
     }
 
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Lifespan_Strategy> new_lifespan_strategy (lifespan_strategy);
-#else
-  auto_ptr<TAO_Lifespan_Strategy> new_lifespan_strategy (lifespan_strategy);
-#endif /* ACE_HAS_CPP11 */
 
   TAO_Id_Assignment_Strategy *id_assignment_strategy = 0;
 
@@ -183,11 +175,7 @@ TAO_Active_Object_Map::TAO_Active_Object_Map (
     }
 
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Id_Assignment_Strategy> new_id_assignment_strategy (id_assignment_strategy);
-#else
-  auto_ptr<TAO_Id_Assignment_Strategy> new_id_assignment_strategy (id_assignment_strategy);
-#endif /* ACE_HAS_CPP11 */
 
   TAO_Id_Hint_Strategy *id_hint_strategy = 0;
   if ((user_id_policy
@@ -209,11 +197,7 @@ TAO_Active_Object_Map::TAO_Active_Object_Map (
     }
 
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Id_Hint_Strategy> new_id_hint_strategy (id_hint_strategy);
-#else
-  auto_ptr<TAO_Id_Hint_Strategy> new_id_hint_strategy (id_hint_strategy);
-#endif /* ACE_HAS_CPP11 */
 
   servant_map *sm = 0;
   if (unique_id_policy)
@@ -247,11 +231,7 @@ TAO_Active_Object_Map::TAO_Active_Object_Map (
     }
 
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<servant_map> new_servant_map (sm);
-#else
-  auto_ptr<servant_map> new_servant_map (sm);
-#endif /* ACE_HAS_CPP11 */
 
   user_id_map *uim = 0;
   if (user_id_policy
@@ -321,11 +301,7 @@ TAO_Active_Object_Map::TAO_Active_Object_Map (
     }
 
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<user_id_map> new_user_id_map (uim);
-#else
-  auto_ptr<user_id_map> new_user_id_map (uim);
-#endif /* ACE_HAS_CPP11 */
 
   id_uniqueness_strategy->set_active_object_map (this);
   lifespan_strategy->set_active_object_map (this);
@@ -333,21 +309,12 @@ TAO_Active_Object_Map::TAO_Active_Object_Map (
 
   // Finally everything is fine.  Make sure to take ownership away
   // from the auto pointer.
-#if defined (ACE_HAS_CPP11)
   this->id_uniqueness_strategy_ = std::move(new_id_uniqueness_strategy);
   this->lifespan_strategy_ =  std::move(new_lifespan_strategy);
   this->id_assignment_strategy_ = std::move(new_id_assignment_strategy);
   this->id_hint_strategy_ = std::move(new_id_hint_strategy);
   this->servant_map_ = std::move(new_servant_map);
   this->user_id_map_ = std::move(new_user_id_map);
-#else
-  this->id_uniqueness_strategy_ = new_id_uniqueness_strategy;
-  this->lifespan_strategy_ =  new_lifespan_strategy;
-  this->id_assignment_strategy_ = new_id_assignment_strategy;
-  this->id_hint_strategy_ = new_id_hint_strategy;
-  this->servant_map_ = new_servant_map;
-  this->user_id_map_ = new_user_id_map;
-#endif /* ACE_HAS_CPP11 */
 
 #if defined (TAO_HAS_MONITOR_POINTS) && (TAO_HAS_MONITOR_POINTS == 1)
   ACE_NEW (this->monitor_,
@@ -541,8 +508,7 @@ TAO_Unique_Id_Strategy::bind_using_user_id (
                   "TAO (%P|%t) - TAO_Unique_Id_Strategy::"
                   "bind_using_user_id: type=%C, id=%C\n",
                   repository_id.in (),
-                  hex_idstr.c_str()
-                  ));
+                  hex_idstr.c_str()));
     }
 #endif
 
@@ -567,8 +533,7 @@ TAO_Unique_Id_Strategy::unbind_using_user_id (
 
           TAOLIB_DEBUG ((LM_DEBUG,
                       "TAO (%P|%t) - TAO_Unique_Id_Strategy::unbind_using_user_id: id=%C\n",
-                      hex_idstr.c_str()
-                      ));
+                      hex_idstr.c_str()));
         }
 
       if (entry->servant_ != 0)
@@ -764,8 +729,7 @@ TAO_Multiple_Id_Strategy::unbind_using_user_id (
 
           TAOLIB_DEBUG ((LM_DEBUG,
                       "TAO (%P|%t) - TAO_Multiple_Id_Strategy::unbind_using_user_id: id=%C\n",
-                      hex_idstr.c_str()
-                      ));
+                      hex_idstr.c_str()));
         }
 
       result = this->active_object_map_->id_hint_strategy_->unbind (*entry);
