@@ -57,7 +57,7 @@ public:
     const TAO_Server_Strategy_Factory::Active_Object_Map_Creation_Parameters &creation_parameters);
 
   /// Destructor.
-  ~TAO_Active_Object_Map (void);
+  ~TAO_Active_Object_Map ();
 
   /// Must be used with UNIQUE_ID policy.
   int
@@ -179,11 +179,11 @@ public:
 
   /// Size of the map.
   size_t
-  current_size (void);
+  current_size ();
 
   /// Can be used with any policy.
   static size_t
-  system_id_size (void);
+  system_id_size ();
 
   /// Set the system id size.
   static void
@@ -237,46 +237,22 @@ public:
 #endif /* TAO_HAS_MINIMUM_POA_MAPS == 0 */
 
   /// Id map.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<user_id_map> user_id_map_;
-#else
-  auto_ptr<user_id_map> user_id_map_;
-#endif /* ACE_HAS_CPP11 */
 
   /// Servant map.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<servant_map> servant_map_;
-#else
-  auto_ptr<servant_map> servant_map_;
-#endif /* ACE_HAS_CPP11 */
 
   /// Id uniqueness strategy.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Id_Uniqueness_Strategy> id_uniqueness_strategy_;
-#else
-  auto_ptr<TAO_Id_Uniqueness_Strategy> id_uniqueness_strategy_;
-#endif /* ACE_HAS_CPP11 */
 
   /// Lifespan strategy.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Lifespan_Strategy> lifespan_strategy_;
-#else
-  auto_ptr<TAO_Lifespan_Strategy> lifespan_strategy_;
-#endif /* ACE_HAS_CPP11 */
 
   /// Id assignment strategy.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Id_Assignment_Strategy> id_assignment_strategy_;
-#else
-  auto_ptr<TAO_Id_Assignment_Strategy> id_assignment_strategy_;
-#endif /* ACE_HAS_CPP11 */
 
   /// Id hint strategy.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Id_Hint_Strategy> id_hint_strategy_;
-#else
-  auto_ptr<TAO_Id_Hint_Strategy> id_hint_strategy_;
-#endif /* ACE_HAS_CPP11 */
 
   /// Flag to see if we are using active maps in this active object
   /// map.
@@ -302,7 +278,7 @@ class TAO_Id_Uniqueness_Strategy
 {
 public:
   /// Virtual destructor.
-  virtual ~TAO_Id_Uniqueness_Strategy (void);
+  virtual ~TAO_Id_Uniqueness_Strategy ();
 
   /// Must be used with UNIQUE_ID policy.
   virtual int
@@ -461,7 +437,7 @@ class TAO_Lifespan_Strategy
 public:
 
   /// Virtual destructor.
-  virtual ~TAO_Lifespan_Strategy (void);
+  virtual ~TAO_Lifespan_Strategy ();
 
   /// Can be used with any policy.
   virtual int
@@ -533,7 +509,7 @@ class TAO_Id_Assignment_Strategy
 {
 public:
   /// Virtual destructor.
-  virtual ~TAO_Id_Assignment_Strategy (void);
+  virtual ~TAO_Id_Assignment_Strategy ();
 
   /// Must be used with SYSTEM_ID policy.
   virtual int
@@ -620,7 +596,7 @@ class TAO_Id_Hint_Strategy
 {
 public:
   /// Virtual destructor.
-  virtual ~TAO_Id_Hint_Strategy (void);
+  virtual ~TAO_Id_Hint_Strategy ();
 
   /// Find the user id from the system id.
   virtual int
@@ -642,7 +618,7 @@ public:
 
   /// How big is the hint generated by this strategy?
   virtual size_t
-  hint_size (void) = 0;
+  hint_size () = 0;
 
   /// Get the system id associated with this entry.
   virtual int
@@ -663,7 +639,7 @@ public:
   TAO_Active_Hint_Strategy (CORBA::ULong map_size);
 
   /// Virtual destructor.
-  virtual ~TAO_Active_Hint_Strategy (void);
+  virtual ~TAO_Active_Hint_Strategy ();
 
   virtual int
   recover_key (const PortableServer::ObjectId &system_id,
@@ -680,7 +656,7 @@ public:
         TAO_Active_Object_Map_Entry *&entry);
 
   virtual size_t
-  hint_size (void);
+  hint_size ();
 
   virtual int
   system_id (PortableServer::ObjectId_out system_id,
@@ -705,7 +681,7 @@ class TAO_No_Hint_Strategy : public TAO_Id_Hint_Strategy
 {
 public:
   /// Virtual destructor.
-  virtual ~TAO_No_Hint_Strategy (void);
+  virtual ~TAO_No_Hint_Strategy ();
 
   virtual int
   recover_key (const PortableServer::ObjectId &system_id,
@@ -722,7 +698,7 @@ public:
         TAO_Active_Object_Map_Entry *&entry);
 
   virtual size_t
-  hint_size (void);
+  hint_size ();
 
   virtual int
   system_id (PortableServer::ObjectId_out system_id,
