@@ -133,8 +133,7 @@ template<typename S_var,
          template <typename> class Insert_Policy>
 CORBA::Boolean
 TAO::Ret_BD_String_SArgument_T<S_var,BOUND,Insert_Policy>::marshal (
-    TAO_OutputCDR & cdr
-  )
+    TAO_OutputCDR & cdr)
 {
   if (this->x_.in () != 0 && ACE_OS::strlen (this->x_.in ()) > BOUND)
     {
@@ -155,8 +154,7 @@ interceptor_value (CORBA::Any *any) const
   typedef typename S_var::s_traits::from_type from_type;
   Insert_Policy<from_type>::any_insert (
       any,
-      from_type (this->x_.in (), BOUND)
-    );
+      from_type (this->x_.in (), BOUND));
 }
 
 #endif /* TAO_HAS_INTERCEPTORS */
