@@ -34,7 +34,7 @@ namespace TAO
 
       if (strategy == 0)
         TAOLIB_ERROR ((LM_ERROR,
-                   ACE_TEXT ("(%P|%t) ERROR, Unable to get %s\n"),
+                   ACE_TEXT ("(%P|%t) ERROR, Unable to get %C\n"),
                    strategy_name));
 
       return strategy;
@@ -49,8 +49,6 @@ namespace TAO
   }
 }
 
-
-
 ACE_STATIC_SVC_DEFINE (
   IdAssignmentStrategyFactoryImpl,
   ACE_TEXT ("IdAssignmentStrategyFactory"),
