@@ -26,13 +26,13 @@ namespace TAO
     }
 
     void
-    LifespanStrategy::strategy_cleanup (void)
+    LifespanStrategy::strategy_cleanup ()
     {
       poa_ = 0;
     }
 
     CORBA::ULong
-    LifespanStrategy::key_type_length (void) const
+    LifespanStrategy::key_type_length () const
     {
       return sizeof (char);
     }
