@@ -4,7 +4,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
-  ORT_Adapter_Factory::~ORT_Adapter_Factory (void)
+  ORT_Adapter_Factory::~ORT_Adapter_Factory ()
   {
   }
 }
