@@ -166,11 +166,7 @@ TAO_Object_Adapter::TAO_Object_Adapter (const TAO_Server_Strategy_Factory::Activ
              No_Hint_Strategy);
 
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<Hint_Strategy> new_hint_strategy (hint_strategy);
-#else
-  auto_ptr<Hint_Strategy> new_hint_strategy (hint_strategy);
-#endif /* ACE_HAS_CPP11 */
 
   new_hint_strategy->object_adapter (this);
 
@@ -197,11 +193,7 @@ TAO_Object_Adapter::TAO_Object_Adapter (const TAO_Server_Strategy_Factory::Activ
       break;
     }
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<persistent_poa_name_map> new_persistent_poa_name_map (ppnm);
-#else
-  auto_ptr<persistent_poa_name_map> new_persistent_poa_name_map (ppnm);
-#endif /* ACE_HAS_CPP11 */
 
   transient_poa_map *tpm = 0;
   switch (creation_parameters.poa_lookup_strategy_for_transient_id_policy_)
@@ -231,11 +223,7 @@ TAO_Object_Adapter::TAO_Object_Adapter (const TAO_Server_Strategy_Factory::Activ
       break;
     }
   // Give ownership to the auto pointer.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<transient_poa_map> new_transient_poa_map (tpm);
-#else
-  auto_ptr<transient_poa_map> new_transient_poa_map (tpm);
-#endif /* ACE_HAS_CPP11 */
 
   this->hint_strategy_ = new_hint_strategy.release ();
   this->persistent_poa_name_map_ = new_persistent_poa_name_map.release ();
@@ -292,7 +280,7 @@ TAO_Object_Adapter::init_default_policies (TAO_POA_Policy_Set &policies)
 #endif
 }
 
-TAO_Object_Adapter::~TAO_Object_Adapter (void)
+TAO_Object_Adapter::~TAO_Object_Adapter ()
 {
   delete this->hint_strategy_;
   delete this->persistent_poa_name_map_;
@@ -552,7 +540,7 @@ TAO_Object_Adapter::find_servant_i (const TAO::ObjectKey &key,
 }
 
 void
-TAO_Object_Adapter::open (void)
+TAO_Object_Adapter::open ()
 {
   // Add in the default POA policies to the default list.
   this->init_default_policies (this->default_poa_policies ());
@@ -691,7 +679,7 @@ TAO_Object_Adapter::check_close (int wait_for_completion)
 }
 
 int
-TAO_Object_Adapter::priority (void) const
+TAO_Object_Adapter::priority () const
 {
   return 0;
 }
@@ -757,7 +745,7 @@ TAO_Object_Adapter::dispatch (TAO::ObjectKey &key,
                                                          0,  // nargs
                                                          0,  // servant_upcall
                                                          0,  // exceptions
-                                                         0);   // nexceptions
+                                                         0); // nexceptions
 
           // If a PortableInterceptor::ForwardRequest exception was
           // thrown, then set the forward_to object reference and return
@@ -786,8 +774,7 @@ TAO_Object_Adapter::dispatch (TAO::ObjectKey &key,
                                        0,  // nargs
                                        0,  // servant_upcall
                                        0,  // exceptions
-                                       0   // nexceptions
-                                      );
+                                       0); // nexceptions
             }
         }
     }
@@ -829,13 +816,13 @@ TAO_Object_Adapter::dispatch (TAO::ObjectKey &key,
 }
 
 const char *
-TAO_Object_Adapter::name (void) const
+TAO_Object_Adapter::name () const
 {
   return TAO_OBJID_ROOTPOA;
 }
 
 CORBA::Object_ptr
-TAO_Object_Adapter::root (void)
+TAO_Object_Adapter::root ()
 {
   return CORBA::Object::_duplicate (this->root_);
 }
@@ -936,7 +923,7 @@ TAO_Object_Adapter::get_collocated_servant (const TAO_MProfile &mp)
 
 // ****************************************************************
 
-TAO_Object_Adapter::Hint_Strategy::~Hint_Strategy (void)
+TAO_Object_Adapter::Hint_Strategy::~Hint_Strategy ()
 {
 }
 
@@ -951,7 +938,7 @@ TAO_Object_Adapter::Active_Hint_Strategy::Active_Hint_Strategy (CORBA::ULong map
 {
 }
 
-TAO_Object_Adapter::Active_Hint_Strategy::~Active_Hint_Strategy (void)
+TAO_Object_Adapter::Active_Hint_Strategy::~Active_Hint_Strategy ()
 {
 }
 
@@ -1024,7 +1011,7 @@ TAO_Object_Adapter::Active_Hint_Strategy::unbind_persistent_poa (
   return result;
 }
 
-TAO_Object_Adapter::No_Hint_Strategy::~No_Hint_Strategy (void)
+TAO_Object_Adapter::No_Hint_Strategy::~No_Hint_Strategy ()
 {
 }
 
@@ -1115,7 +1102,7 @@ TAO_Object_Adapter::poa_name_iterator::operator* () const
 }
 
 TAO_Object_Adapter::poa_name_iterator &
-TAO_Object_Adapter::poa_name_iterator::operator++ (void)
+TAO_Object_Adapter::poa_name_iterator::operator++ ()
 {
   for (this->last_separator_ = this->position_;
        ;
@@ -1141,7 +1128,7 @@ TAO_Object_Adapter::iteratable_poa_name::iteratable_poa_name (
 }
 
 TAO_Object_Adapter::iteratable_poa_name::iterator
-TAO_Object_Adapter::iteratable_poa_name::begin (void) const
+TAO_Object_Adapter::iteratable_poa_name::begin () const
 {
   return iterator (1,
                    this->folded_name_.length (),
@@ -1149,7 +1136,7 @@ TAO_Object_Adapter::iteratable_poa_name::begin (void) const
 }
 
 TAO_Object_Adapter::iteratable_poa_name::iterator
-TAO_Object_Adapter::iteratable_poa_name::end (void) const
+TAO_Object_Adapter::iteratable_poa_name::end () const
 {
   return iterator (0,
                    this->folded_name_.length (),
@@ -1157,7 +1144,7 @@ TAO_Object_Adapter::iteratable_poa_name::end (void) const
 }
 
 void
-TAO_Object_Adapter::wait_for_non_servant_upcalls_to_complete (void)
+TAO_Object_Adapter::wait_for_non_servant_upcalls_to_complete ()
 {
   // Check if a non-servant upcall is in progress.  If a non-servant
   // upcall is in progress, wait for it to complete.  Unless of
@@ -1174,7 +1161,7 @@ TAO_Object_Adapter::wait_for_non_servant_upcalls_to_complete (void)
 }
 
 void
-TAO_Object_Adapter::wait_for_non_servant_upcalls_to_complete_no_throw (void)
+TAO_Object_Adapter::wait_for_non_servant_upcalls_to_complete_no_throw ()
 {
   // Non-exception throwing version.
   try
