@@ -27,7 +27,7 @@ ACE_TIMEPROBE_EVENT_DESCRIPTIONS (TAO_Operation_Table_Timeprobe_Description,
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Linear_Search_OpTable::~TAO_Linear_Search_OpTable (void)
+TAO_Linear_Search_OpTable::~TAO_Linear_Search_OpTable ()
 {
 }
 
