@@ -11,7 +11,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_POA_Policy_Set::TAO_POA_Policy_Set (void)
+TAO_POA_Policy_Set::TAO_POA_Policy_Set ()
   : impl_ (TAO_POLICY_POA_SCOPE)
 {
 }
@@ -22,7 +22,7 @@ TAO_POA_Policy_Set::TAO_POA_Policy_Set (const TAO_POA_Policy_Set &rhs)
 {
 }
 
-TAO_POA_Policy_Set::~TAO_POA_Policy_Set (void)
+TAO_POA_Policy_Set::~TAO_POA_Policy_Set ()
 {
 }
 
