@@ -34,9 +34,9 @@ namespace TAO
     public:
       virtual void strategy_init(TAO_Root_POA *poa) = 0;
 
-      virtual void strategy_cleanup(void) = 0;
+      virtual void strategy_cleanup() = 0;
 
-      virtual ~Policy_Strategy (void) {};
+      virtual ~Policy_Strategy () {};
     };
   }
 }
