@@ -37,8 +37,7 @@ namespace TAO
 
     void
     RequestProcessingStrategyAOMOnlyFactoryImpl::destroy (
-      RequestProcessingStrategy *strategy
-      )
+      RequestProcessingStrategy *strategy)
     {
       strategy->strategy_cleanup ();
 
@@ -47,7 +46,6 @@ namespace TAO
   }
 }
 
-
 ACE_STATIC_SVC_DEFINE (
   RequestProcessingStrategyAOMOnlyFactoryImpl,
   ACE_TEXT ("RequestProcessingStrategyAOMOnlyFactory"),
