@@ -40,8 +40,7 @@ namespace TAO
 
     void
     RequestProcessingStrategyDefaultServantFactoryImpl::destroy (
-      RequestProcessingStrategy *strategy
-      )
+      RequestProcessingStrategy *strategy)
     {
       strategy->strategy_cleanup ();
 
@@ -50,8 +49,6 @@ namespace TAO
   }
 }
 
-
-
 ACE_STATIC_SVC_DEFINE (
   RequestProcessingStrategyDefaultServantFactoryImpl,
   ACE_TEXT ("RequestProcessingStrategyDefaultServantFactory"),
