@@ -52,8 +52,7 @@ namespace TAO
 
     void
     RequestProcessingStrategyServantActivatorFactoryImpl::destroy (
-      RequestProcessingStrategy *strategy
-      )
+      RequestProcessingStrategy *strategy)
     {
       strategy->strategy_cleanup ();
 
@@ -62,7 +61,6 @@ namespace TAO
   }
 }
 
-
 ACE_STATIC_SVC_DEFINE (
   RequestProcessingStrategyServantActivatorFactoryImpl,
   ACE_TEXT ("RequestProcessingStrategyServantActivatorFactory"),
