@@ -27,8 +27,7 @@ template<typename S,
          template <typename> class Insert_Policy>
 void
 TAO::In_Var_Size_SArgument_T<S,Insert_Policy>::interceptor_value (
-    CORBA::Any *any
-  ) const
+    CORBA::Any *any) const
 {
   Insert_Policy<S>::any_insert (any, this->x_);
 }
@@ -59,8 +58,7 @@ template<typename S,
          template <typename> class Insert_Policy>
 void
 TAO::Inout_Var_Size_SArgument_T<S,Insert_Policy>::interceptor_value (
-    CORBA::Any *any
-  ) const
+    CORBA::Any *any) const
 {
   Insert_Policy<S>::any_insert (any, this->x_);
 }
