@@ -384,7 +384,7 @@ TAO_Thread_Lane::is_collocated (const TAO_MProfile &mprofile)
 }
 
 CORBA::ULong
-TAO_Thread_Lane::current_threads (void) const
+TAO_Thread_Lane::current_threads () const
 {
   ACE_GUARD_RETURN (TAO_SYNCH_MUTEX,
                     mon,
@@ -516,8 +516,7 @@ TAO_Thread_Pool::TAO_Thread_Pool (TAO_Thread_Pool_Manager &manager,
                             static_threads,
                             dynamic_threads,
                             lifespan,
-                            dynamic_thread_time
-                           ));
+                            dynamic_thread_time));
 }
 
 TAO_Thread_Pool::TAO_Thread_Pool (TAO_Thread_Pool_Manager &manager,
@@ -561,8 +560,7 @@ TAO_Thread_Pool::TAO_Thread_Pool (TAO_Thread_Pool_Manager &manager,
                               lanes[i].static_threads,
                               lanes[i].dynamic_threads,
                               lifespan,
-                              dynamic_thread_time
-                             ));
+                              dynamic_thread_time));
 }
 
 void
@@ -890,11 +888,7 @@ RTCORBA::ThreadpoolId
 TAO_Thread_Pool_Manager::create_threadpool_helper (TAO_Thread_Pool *thread_pool)
 {
   // Make sure of safe deletion in case of errors.
-#if defined (ACE_HAS_CPP11)
   std::unique_ptr<TAO_Thread_Pool> safe_thread_pool (thread_pool);
-#else
-  auto_ptr<TAO_Thread_Pool> safe_thread_pool (thread_pool);
-#endif /* ACE_HAS_CPP11 */
 
   // Open the pool.
   thread_pool->open ();
@@ -949,7 +943,7 @@ TAO_Thread_Pool_Manager::get_threadpool (RTCORBA::ThreadpoolId thread_pool_id )
 }
 
 TAO_ORB_Core &
-TAO_Thread_Pool_Manager::orb_core (void) const
+TAO_Thread_Pool_Manager::orb_core () const
 {
   return this->orb_core_;
 }
