@@ -11,7 +11,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-ACE_Atomic_Op<TAO_SYNCH_MUTEX, long> TAO_RTScheduler_Current::guid_counter;
+std::atomic<long> TAO_RTScheduler_Current::guid_counter;
 
 u_long
 TAO_DTId_Hash::operator () (const IdType &id) const
@@ -20,12 +20,7 @@ TAO_DTId_Hash::operator () (const IdType &id) const
                         id.length ());
 }
 
-TAO_RTScheduler_Current::TAO_RTScheduler_Current (void) :
-  orb_ (0)
-{
-}
-
-TAO_RTScheduler_Current::~TAO_RTScheduler_Current (void)
+TAO_RTScheduler_Current::~TAO_RTScheduler_Current ()
 {
 }
 
@@ -52,18 +47,17 @@ TAO_RTScheduler_Current::rt_current (RTCORBA::Current_ptr rt_current)
 }
 
 TAO_ORB_Core*
-TAO_RTScheduler_Current::orb (void)
+TAO_RTScheduler_Current::orb ()
 {
   return this->orb_;
 }
 
 DT_Hash_Map*
-TAO_RTScheduler_Current::dt_hash (void)
+TAO_RTScheduler_Current::dt_hash ()
 {
   return &this->dt_hash_;
 }
 
-
 void
 TAO_RTScheduler_Current::begin_scheduling_segment (
     const char * name,
@@ -88,16 +82,13 @@ TAO_RTScheduler_Current::begin_scheduling_segment (
 
   impl->begin_scheduling_segment (name,
                                   sched_param,
-                                  implicit_sched_param
-                                 );
+                                  implicit_sched_param);
 }
 
-
 void
 TAO_RTScheduler_Current::update_scheduling_segment (const char * name,
                                                     CORBA::Policy_ptr sched_param,
-                                                    CORBA::Policy_ptr implicit_sched_param
-                                                    )
+                                                    CORBA::Policy_ptr implicit_sched_param)
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
@@ -106,8 +97,7 @@ TAO_RTScheduler_Current::update_scheduling_segment (const char * name,
 
   impl->update_scheduling_segment (name,
                                    sched_param,
-                                   implicit_sched_param
-                                  );
+                                   implicit_sched_param);
 }
 
 void
@@ -123,8 +113,7 @@ TAO_RTScheduler_Current::end_scheduling_segment (const char * name)
       return;
     }
 
-  impl->end_scheduling_segment (name
-                               );
+  impl->end_scheduling_segment (name);
 }
 
 RTScheduling::DistributableThread_ptr
@@ -141,7 +130,6 @@ TAO_RTScheduler_Current::lookup(const RTScheduling::Current::IdType & id)
 // returns a null reference if
 // the distributable thread is
 // not known to the local scheduler
-
 RTScheduling::DistributableThread_ptr
 TAO_RTScheduler_Current::spawn (RTScheduling::ThreadAction_ptr start,
                                 CORBA::VoidData data,
@@ -162,8 +150,7 @@ TAO_RTScheduler_Current::spawn (RTScheduling::ThreadAction_ptr start,
                       sched_param,
                       implicit_sched_param,
                       stack_size,
-                      base_priority
-                     );
+                      base_priority);
 }
 
 RTScheduling::Current::IdType *
@@ -248,19 +235,19 @@ TAO_RTScheduler_Current::implementation (void)
 }
 
 TAO_ORB_Core*
-TAO_RTScheduler_Current_i::orb (void)
+TAO_RTScheduler_Current_i::orb ()
 {
   return this->orb_;
 }
 
 DT_Hash_Map*
-TAO_RTScheduler_Current_i::dt_hash (void)
+TAO_RTScheduler_Current_i::dt_hash ()
 {
   return this->dt_hash_;
 }
 
  RTScheduling::Scheduler_ptr
-TAO_RTScheduler_Current_i::scheduler (void)
+TAO_RTScheduler_Current_i::scheduler ()
 {
   return RTScheduling::Scheduler::_duplicate (this->scheduler_.in ());
 }
@@ -301,11 +288,10 @@ TAO_RTScheduler_Current_i::TAO_RTScheduler_Current_i (
     orb->object_ref_table ().resolve_initial_reference (
       "RTScheduler");
 
-  this->scheduler_ = RTScheduling::Scheduler::_narrow (scheduler_obj.in ()
-                                                      );
+  this->scheduler_ = RTScheduling::Scheduler::_narrow (scheduler_obj.in ());
 }
 
-TAO_RTScheduler_Current_i::~TAO_RTScheduler_Current_i (void)
+TAO_RTScheduler_Current_i::~TAO_RTScheduler_Current_i ()
 {
 }
 
@@ -335,8 +321,7 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
       this->scheduler_->begin_new_scheduling_segment (this->guid_,
                                                       name,
                                                       sched_param,
-                                                      implicit_sched_param
-                                                     );
+                                                      implicit_sched_param);
 
       if (CORBA::is_nil (this->dt_.in ()))
         //Create new DT.
@@ -371,8 +356,7 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
         (this->guid_,
          name,
          sched_param,
-         implicit_sched_param
-        );
+         implicit_sched_param);
 
       TAO_TSS_Resources *tss =
         TAO_TSS_Resources::instance ();
@@ -400,8 +384,7 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
 void
 TAO_RTScheduler_Current_i::update_scheduling_segment (const char * name,
                                                       CORBA::Policy_ptr sched_param,
-                                                      CORBA::Policy_ptr implicit_sched_param
-                                                      )
+                                                      CORBA::Policy_ptr implicit_sched_param)
 {
   // Check if DT has been cancelled
   if (this->dt_->state () == RTScheduling::DistributableThread::CANCELLED)
@@ -413,8 +396,7 @@ TAO_RTScheduler_Current_i::update_scheduling_segment (const char * name,
   this->scheduler_->update_scheduling_segment (this->guid_,
                                                name,
                                                sched_param,
-                                               implicit_sched_param
-                                              );
+                                               implicit_sched_param);
 
   // Remember the new values.
   this->name_ = CORBA::string_dup (name);
@@ -435,9 +417,7 @@ TAO_RTScheduler_Current_i::end_scheduling_segment (const char * name)
     {
       // Let the scheduler know that the DT is
       // terminating.
-      this->scheduler_->end_scheduling_segment(this->guid_,
-                                               name
-                                              );
+      this->scheduler_->end_scheduling_segment(this->guid_, name);
 
       // Cleanup DT.
       this->cleanup_DT ();
@@ -452,15 +432,13 @@ TAO_RTScheduler_Current_i::end_scheduling_segment (const char * name)
       // scheduling segment.
       this->scheduler_->end_nested_scheduling_segment (this->guid_,
                                                        name,
-                                                       this->previous_current_->sched_param_.in ()
-                                                      );
+                                                       this->previous_current_->sched_param_.in ());
 
       // Cleanup current.
       this->cleanup_current ();
     }
 }
 
-
 // returns a null reference if
 // the distributable thread is
 // not known to the local scheduler
@@ -471,8 +449,7 @@ TAO_RTScheduler_Current_i::spawn (RTScheduling::ThreadAction_ptr start,
                                   CORBA::Policy_ptr sched_param,
                                   CORBA::Policy_ptr implicit_sched_param,
                                   CORBA::ULong stack_size,
-                                  RTCORBA::Priority base_priority
-                                  )
+                                  RTCORBA::Priority base_priority)
 {
   // Check if DT has been cancelled.
   if (this->dt_->state () == RTScheduling::DistributableThread::CANCELLED)
@@ -525,8 +502,7 @@ TAO_RTScheduler_Current_i::spawn (RTScheduling::ThreadAction_ptr start,
 
 int
 DTTask::activate_task (RTCORBA::Priority base_priority,
-                       CORBA::ULong stack_size
-                       )
+                       CORBA::ULong stack_size)
 {
   // Activate thread.
   long default_flags = THR_NEW_LWP | THR_JOINABLE;
@@ -540,8 +516,7 @@ DTTask::activate_task (RTCORBA::Priority base_priority,
     TAO_OBJID_PRIORITYMAPPINGMANAGER);
 
   RTCORBA::PriorityMappingManager_var mapping_manager =
-    RTCORBA::PriorityMappingManager::_narrow (object.in ()
-                                             );
+    RTCORBA::PriorityMappingManager::_narrow (object.in ());
 
   RTCORBA::PriorityMapping *pm =
     mapping_manager->mapping ();
@@ -590,13 +565,13 @@ DTTask::DTTask (TAO_ORB_Core *orb,
 {
 }
 
-DTTask::~DTTask (void)
+DTTask::~DTTask ()
 {
   delete this->current_;
 }
 
 int
-DTTask::svc (void)
+DTTask::svc ()
 {
   try
     {
@@ -608,15 +583,12 @@ DTTask::svc (void)
 
       this->current_->begin_scheduling_segment (this->name_.in (),
                                                 this->sched_param_.in (),
-                                                this->implicit_sched_param_.in ()
-                                               );
+                                                this->implicit_sched_param_.in ());
 
       // Invoke entry point into new DT.
-      this->start_->_cxx_do (this->data_
-                            );
+      this->start_->_cxx_do (this->data_);
 
-      this->current_->end_scheduling_segment (this->name_.in ()
-                                            );
+      this->current_->end_scheduling_segment (this->name_.in ());
     }
   catch (const ::CORBA::Exception& ex)
     {
@@ -628,7 +600,7 @@ DTTask::svc (void)
 }
 
 RTScheduling::Current::IdType *
-TAO_RTScheduler_Current_i::id (void)
+TAO_RTScheduler_Current_i::id ()
 {
 
   RTScheduling::Current::IdType_var guid = this->guid_;
@@ -637,13 +609,13 @@ TAO_RTScheduler_Current_i::id (void)
 
 
 CORBA::Policy_ptr
-TAO_RTScheduler_Current_i::scheduling_parameter (void)
+TAO_RTScheduler_Current_i::scheduling_parameter ()
 {
   return CORBA::Policy::_duplicate (this->sched_param_.in ());
 }
 
 CORBA::Policy_ptr
-TAO_RTScheduler_Current_i::implicit_scheduling_parameter (void)
+TAO_RTScheduler_Current_i::implicit_scheduling_parameter ()
 {
   return CORBA::Policy::_duplicate (this->implicit_sched_param_.in ());
 }
@@ -669,7 +641,7 @@ TAO_RTScheduler_Current_i::current_scheduling_segment_names (void)
 }
 
 const char*
-TAO_RTScheduler_Current_i::name (void)
+TAO_RTScheduler_Current_i::name ()
 {
   return this->name_.in ();
 }
@@ -679,7 +651,7 @@ TAO_RTScheduler_Current_i::name (void)
 #endif /* THREAD_CANCELLED */
 
 void
-TAO_RTScheduler_Current_i::cancel_thread (void)
+TAO_RTScheduler_Current_i::cancel_thread ()
 {
   size_t guid;
   ACE_OS::memcpy (&guid,
@@ -692,8 +664,7 @@ TAO_RTScheduler_Current_i::cancel_thread (void)
 
   // Let the scheduler know that the thread has
   // been cancelled.
-  this->scheduler_->cancel (this->guid_
-                           );
+  this->scheduler_->cancel (this->guid_);
 
   this->cleanup_DT ();
 
@@ -705,14 +676,14 @@ TAO_RTScheduler_Current_i::cancel_thread (void)
 }
 
 void
-TAO_RTScheduler_Current_i::cleanup_DT (void)
+TAO_RTScheduler_Current_i::cleanup_DT ()
 {
   // Remove DT from map.
   this->dt_hash_->unbind (this->guid_);
 }
 
 void
-TAO_RTScheduler_Current_i::cleanup_current (void)
+TAO_RTScheduler_Current_i::cleanup_current ()
 {
   TAO_TSS_Resources *tss =
     TAO_TSS_Resources::instance ();
@@ -724,7 +695,7 @@ TAO_RTScheduler_Current_i::cleanup_current (void)
 }
 
 void
-TAO_RTScheduler_Current_i::delete_all_currents (void)
+TAO_RTScheduler_Current_i::delete_all_currents ()
 {
   TAO_RTScheduler_Current_i* current = this;
 
@@ -754,7 +725,7 @@ TAO_RTScheduler_Current_i::name (const char * name)
 }
 
 RTScheduling::DistributableThread_ptr
-TAO_RTScheduler_Current_i::DT (void)
+TAO_RTScheduler_Current_i::DT ()
 {
   return this->dt_._retn ();
 }
@@ -783,13 +754,12 @@ TAO_RTScheduler_Current_i::implicit_scheduling_parameter (CORBA::Policy_ptr impl
 // *************************************************************
 // Operations for class TAO_RTScheduler_Current_var
 // *************************************************************
-
-TAO_RTScheduler_Current_var::TAO_RTScheduler_Current_var (void) // default constructor
+TAO_RTScheduler_Current_var::TAO_RTScheduler_Current_var () // default constructor
   : ptr_ (TAO_RTScheduler_Current::_nil ())
 {}
 
 ::TAO_RTScheduler_Current_ptr
-TAO_RTScheduler_Current_var::ptr (void) const
+TAO_RTScheduler_Current_var::ptr () const
 {
   return this->ptr_;
 }
@@ -799,7 +769,7 @@ TAO_RTScheduler_Current_var::TAO_RTScheduler_Current_var (const ::TAO_RTSchedule
     ptr_ (TAO_RTScheduler_Current::_duplicate (p.ptr ()))
 {}
 
-TAO_RTScheduler_Current_var::~TAO_RTScheduler_Current_var (void) // destructor
+TAO_RTScheduler_Current_var::~TAO_RTScheduler_Current_var () // destructor
 {
   ::CORBA::release (this->ptr_);
 }
@@ -834,25 +804,25 @@ TAO_RTScheduler_Current_var::operator ::TAO_RTScheduler_Current_ptr &()
 }
 
 TAO_RTScheduler_Current_ptr
-TAO_RTScheduler_Current_var::operator-> (void) const
+TAO_RTScheduler_Current_var::operator-> () const
 {
   return this->ptr_;
 }
 
 TAO_RTScheduler_Current_ptr
-TAO_RTScheduler_Current_var::in (void) const
+TAO_RTScheduler_Current_var::in () const
 {
   return this->ptr_;
 }
 
 TAO_RTScheduler_Current_ptr &
-TAO_RTScheduler_Current_var::inout (void)
+TAO_RTScheduler_Current_var::inout ()
 {
   return this->ptr_;
 }
 
 TAO_RTScheduler_Current_ptr &
-TAO_RTScheduler_Current_var::out (void)
+TAO_RTScheduler_Current_var::out ()
 {
   ::CORBA::release (this->ptr_);
   this->ptr_ = ::TAO_RTScheduler_Current::_nil ();
@@ -860,7 +830,7 @@ TAO_RTScheduler_Current_var::out (void)
 }
 
 TAO_RTScheduler_Current_ptr
-TAO_RTScheduler_Current_var::_retn (void)
+TAO_RTScheduler_Current_var::_retn ()
 {
   // yield ownership of managed obj reference
   ::TAO_RTScheduler_Current_ptr val = this->ptr_;
@@ -881,16 +851,13 @@ TAO_RTScheduler_Current_var::release (TAO_RTScheduler_Current_ptr p)
 }
 
 TAO_RTScheduler_Current_ptr
-TAO_RTScheduler_Current_var::nil (void)
+TAO_RTScheduler_Current_var::nil ()
 {
   return ::TAO_RTScheduler_Current::_nil ();
 }
 
 TAO_RTScheduler_Current_ptr
-TAO_RTScheduler_Current_var::narrow (
-    CORBA::Object *p
-
-  )
+TAO_RTScheduler_Current_var::narrow (CORBA::Object *p)
 {
   return ::TAO_RTScheduler_Current::_narrow (p);
 }
@@ -904,14 +871,11 @@ TAO_RTScheduler_Current_var::upcast (void *src)
 }
 
 TAO_RTScheduler_Current_ptr TAO_RTScheduler_Current::_narrow (
-    CORBA::Object_ptr obj
-
-  )
+    CORBA::Object_ptr obj)
 {
   return
     TAO_RTScheduler_Current::_duplicate (
-        dynamic_cast<TAO_RTScheduler_Current *> (obj)
-      );
+        dynamic_cast<TAO_RTScheduler_Current *> (obj));
 }
 
 TAO_RTScheduler_Current_ptr
@@ -922,7 +886,7 @@ TAO_RTScheduler_Current::_duplicate (TAO_RTScheduler_Current_ptr obj)
   return obj;
 }
 
-const char* TAO_RTScheduler_Current::_interface_repository_id (void) const
+const char* TAO_RTScheduler_Current::_interface_repository_id () const
 {
   return "IDL:TAO_RTScheduler_Current:1.0";
 }
