@@ -31,13 +31,13 @@ class TAO_RTScheduler_Export TAO_RTScheduler_Loader : public ACE_Service_Object
 {
 public:
   /// Constructor.
-  TAO_RTScheduler_Loader (void);
+  TAO_RTScheduler_Loader ();
 
   /// Destructor.
-  virtual ~TAO_RTScheduler_Loader (void);
+  virtual ~TAO_RTScheduler_Loader ();
 
   /// Initialize the RTScheduler loader hooks.
-  virtual int init (int argc, ACE_TCHAR* []);
+  int init (int argc, ACE_TCHAR* []) override;
 
 private:
   /// Set to true after init is called.
