@@ -7,23 +7,12 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_RTScheduler_Manager::TAO_RTScheduler_Manager (void) :
-  orb_ (0)
-{
-
-}
-
-TAO_RTScheduler_Manager::~TAO_RTScheduler_Manager (void)
-{
-}
-
 TAO_RTScheduler_Manager_ptr
 TAO_RTScheduler_Manager::_narrow (CORBA::Object_ptr obj)
 {
   return
     TAO_RTScheduler_Manager::_duplicate (
-        dynamic_cast<TAO_RTScheduler_Manager *> (obj)
-      );
+        dynamic_cast<TAO_RTScheduler_Manager *> (obj));
 }
 
 TAO_RTScheduler_Manager_ptr
@@ -35,7 +24,7 @@ TAO_RTScheduler_Manager::_duplicate (TAO_RTScheduler_Manager_ptr obj)
 }
 
 const char*
-TAO_RTScheduler_Manager::_interface_repository_id (void) const
+TAO_RTScheduler_Manager::_interface_repository_id () const
 {
   return "IDL:RTScheduler_Manager:1.0";
 }
