@@ -3,7 +3,7 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_Services_Activate::~TAO_Services_Activate (void)
+TAO_Services_Activate::~TAO_Services_Activate ()
 {
 }
 
