@@ -27,18 +27,16 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
-
   /**
    * @brief A Storable_Base derived class that works with a file stream.
-   *
    */
   class TAO_Export Storable_FlatFileStream : public Storable_Base
   {
   public:
 
     Storable_FlatFileStream(const ACE_CString & file, const char * mode,
-                            bool use_backup =
-                            Storable_Base::use_backup_default);
+                            bool use_backup = Storable_Base::use_backup_default,
+                            bool retry_on_ebadf = Storable_Base::retry_on_ebadf_default);
 
     virtual ~Storable_FlatFileStream();
 
@@ -48,6 +46,11 @@ namespace TAO
     /// Open a file (the remaining methods below all require an open file)
     virtual int open ();
 
+    /// When the locked file resides on an NFS mounted volume, occasionally
+    /// the FD of the opened file becomes stale, when that happens the handle
+    /// needs to be refreshed and the lock verified
+    virtual int reopen ();
+
     /// Acquire a file lock
     virtual int close ();
 
@@ -68,17 +71,16 @@ namespace TAO
     /// Returns 0 on success, otherwise EOF
     virtual int sync (void);
 
-    virtual Storable_Base& operator << (const ACE_CString& str);
-
-    virtual Storable_Base& operator >> (ACE_CString& str);
-
-    virtual Storable_Base& operator << (int i);
-
-    virtual Storable_Base& operator >> (int &i);
-
-    virtual Storable_Base& operator << (unsigned int i);
-
-    virtual Storable_Base& operator >> (unsigned int &i);
+    virtual Storable_Base& operator << (const ACE_CString&);
+    virtual Storable_Base& operator >> (ACE_CString&);
+    virtual Storable_Base& operator << (ACE_UINT32 );
+    virtual Storable_Base& operator >> (ACE_UINT32 &);
+    virtual Storable_Base& operator << (ACE_UINT64 );
+    virtual Storable_Base& operator >> (ACE_UINT64 &);
+    virtual Storable_Base& operator << (ACE_INT32 );
+    virtual Storable_Base& operator >> (ACE_INT32 &);
+    virtual Storable_Base& operator << (ACE_INT64 );
+    virtual Storable_Base& operator >> (ACE_INT64 &);
 
     virtual Storable_Base& operator << (const TAO_OutputCDR & cdr);
 
@@ -89,7 +91,6 @@ namespace TAO
     virtual int restore_backup ();
 
   protected:
-
     virtual void do_remove ();
 
     virtual void remove_backup ();
@@ -97,7 +98,6 @@ namespace TAO
     virtual int create_backup ();
 
   private:
-
     /// Throw a Storable_Read_Exception if the state
     /// is not good due to a read error.
     void throw_on_read_error (Storable_State state);
@@ -117,10 +117,13 @@ namespace TAO
   class TAO_Export Storable_FlatFileFactory : public Storable_Factory
   {
   public:
-
     /// @param directory Directory to contain file passed in
     /// create_stream (). The directory is assumed to already exist.
-    Storable_FlatFileFactory(const ACE_CString & directory);
+    Storable_FlatFileFactory(const ACE_CString & directory,
+                             bool use_backup = Storable_Base::use_backup_default);
+    Storable_FlatFileFactory(const ACE_CString & directory,
+                             bool use_backup,
+                             bool retry_on_ebadf);
 
     const ACE_CString & get_directory () const;
 
@@ -128,14 +131,15 @@ namespace TAO
 
   // Factory Methods
 
-  /// Create the stream that can operate on a disk file
+    /// Create the stream that can operate on a disk file
     virtual Storable_Base *create_stream (const ACE_CString & file,
                                           const char * mode,
-                                          bool use_backup =
-                                          Storable_Base::use_backup_default);
+                                          bool = false);
   private:
+    static bool is_nfs (const ACE_CString &dir);
     ACE_CString directory_;
-
+    bool use_backup_;
+    bool retry_on_ebadf_;
   };
 }
 
