@@ -41,12 +41,9 @@ class TAO_COIOP_Connection_Handler;
 class TAO_Strategies_Export TAO_COIOP_Endpoint : public TAO_Endpoint
 {
 public:
-
   friend class TAO_COIOP_Profile;
   friend class TAO_SSLIOP_Profile;
 
-  // = Initialization and termination methods.
-
   /// Default constructor.
   TAO_COIOP_Endpoint (void);
 
@@ -55,7 +52,7 @@ public:
   TAO_COIOP_Endpoint (const ACE_Utils::UUID& uuid);
 
   /// Destructor.
-  ~TAO_COIOP_Endpoint (void);
+  ~TAO_COIOP_Endpoint () = default;
 
   /**
    * @name TAO_Endpoint Methods
@@ -79,7 +76,7 @@ public:
 
   /// Return a pointer to the host string.  This object maintains
   /// ownership of this string.
-  const ACE_Utils::UUID& uuid (void) const;
+  const ACE_Utils::UUID& uuid () const;
 
 private:
   /// UUID uniquely identifying this COIOP endpoint
