@@ -250,8 +250,7 @@ TAO_DIOP_Connection_Handler::open_server (void)
                   ACE_TEXT("TAO (%P|%t) - DIOP_Connection_Handler::open_server, ")
                   ACE_TEXT("listening on %C:%d\n"),
                   this->local_addr_.get_host_name (),
-                  this->local_addr_.get_port_number ()
-                ));
+                  this->local_addr_.get_port_number ()));
     }
 
   this->transport ()->id ((size_t) this->peer ().get_handle ());
