@@ -1,4 +1,3 @@
-// This may look like C, but it's really -*- C++ -*-
 #include "tao/Strategies/DIOP_Connector.h"
 
 #if defined (TAO_HAS_DIOP) && (TAO_HAS_DIOP != 0)
@@ -16,6 +15,7 @@
 #include "ace/os_include/os_netdb.h"
 
 #include "tao/Strategies/DIOP_Profile.h"
+#include <cstring>
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -24,10 +24,6 @@ TAO_DIOP_Connector::TAO_DIOP_Connector (void)
 {
 }
 
-TAO_DIOP_Connector::~TAO_DIOP_Connector (void)
-{
-}
-
 int
 TAO_DIOP_Connector::open (TAO_ORB_Core *orb_core)
 {
@@ -254,10 +250,10 @@ TAO_DIOP_Connector::check_prefix (const char *endpoint)
 
   const char *protocol[] = { "diop", "dioploc" };
 
-  size_t const slot = ACE_OS::strchr (endpoint, ':') - endpoint;
+  size_t const slot = std::strchr (endpoint, ':') - endpoint;
 
-  size_t const len0 = ACE_OS::strlen (protocol[0]);
-  size_t const len1 = ACE_OS::strlen (protocol[1]);
+  size_t const len0 = std::strlen (protocol[0]);
+  size_t const len1 = std::strlen (protocol[1]);
 
   // Check for the proper prefix in the IOR.  If the proper prefix
   // isn't in the IOR then it is not an IOR we can use.
@@ -274,7 +270,7 @@ TAO_DIOP_Connector::check_prefix (const char *endpoint)
 }
 
 char
-TAO_DIOP_Connector::object_key_delimiter (void) const
+TAO_DIOP_Connector::object_key_delimiter () const
 {
   return TAO_DIOP_Profile::object_key_delimiter_;
 }
