@@ -13,6 +13,7 @@
 #include "ace/OS_NS_string.h"
 #include "ace/os_include/os_netdb.h"
 #include "ace/Truncate.h"
+#include <cstring>
 
 static const char prefix_[] = "shmiop";
 
@@ -21,7 +22,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 const char TAO_SHMIOP_Profile::object_key_delimiter_ = '/';
 
 char
-TAO_SHMIOP_Profile::object_key_delimiter (void) const
+TAO_SHMIOP_Profile::object_key_delimiter () const
 {
   return TAO_SHMIOP_Profile::object_key_delimiter_;
 }
@@ -86,7 +87,7 @@ TAO_SHMIOP_Profile::endpoint (void)
 }
 
 CORBA::ULong
-TAO_SHMIOP_Profile::endpoint_count (void) const
+TAO_SHMIOP_Profile::endpoint_count () const
 {
   return this->count_;
 }
@@ -123,15 +124,14 @@ TAO_SHMIOP_Profile::decode_profile (TAO_InputCDR& cdr)
 }
 
 void
-TAO_SHMIOP_Profile::parse_string_i (const char *string
-                                    )
+TAO_SHMIOP_Profile::parse_string_i (const char *string)
 {
   // Pull off the "hostname:port/" part of the objref
   // Copy the string because we are going to modify it...
   CORBA::String_var copy (string);
 
   char *start = copy.inout ();
-  char *cp = ACE_OS::strchr (start, ':');  // Look for a port
+  char *cp = std::strchr (start, ':');  // Look for a port
 
   if (cp == 0)
     {
@@ -143,7 +143,7 @@ TAO_SHMIOP_Profile::parse_string_i (const char *string
                    CORBA::COMPLETED_NO);
     }
 
-  char *okd = ACE_OS::strchr (start, this->object_key_delimiter_);
+  char *okd = std::strchr (start, this->object_key_delimiter_);
 
   if (okd == 0)
     {
@@ -284,8 +284,7 @@ TAO_SHMIOP_Profile::do_is_equivalent (const TAO_Profile *other_profile)
 }
 
 CORBA::ULong
-TAO_SHMIOP_Profile::hash (CORBA::ULong max
-                          )
+TAO_SHMIOP_Profile::hash (CORBA::ULong max)
 {
   // Get the hashvalue for all endpoints.
   CORBA::ULong hashval = 0;
@@ -323,7 +322,7 @@ TAO_SHMIOP_Profile::add_endpoint (TAO_SHMIOP_Endpoint *endp)
 }
 
 char *
-TAO_SHMIOP_Profile::to_string (void) const
+TAO_SHMIOP_Profile::to_string () const
 {
   CORBA::String_var key;
   TAO::ObjectKey::encode_sequence_to_string (key.inout(),
@@ -386,7 +385,7 @@ TAO_SHMIOP_Profile::create_profile_body (TAO_OutputCDR &encap) const
   else
     {
       TAOLIB_ERROR ((LM_ERROR,
-                  "(%P|%t) TAO - UIOP_Profile::create_profile_body "
+                  "(%P|%t) TAO - SHMIOP_Profile::create_profile_body "
                   "no object key marshalled\n"));
     }
 
