@@ -386,7 +386,7 @@ TAO_Advanced_Resource_Factory::init_protocol_factories (void)
 
       (*factory)->factory (
         ACE_Dynamic_Service<TAO_Protocol_Factory>::instance (name.c_str ()));
-      if ((*factory)->factory () == 0)
+      if ((*factory)->factory () == nullptr)
         {
           TAOLIB_ERROR_RETURN ((LM_ERROR,
                              ACE_TEXT("TAO (%P|%t) Unable to load ")
@@ -414,7 +414,7 @@ TAO_Advanced_Resource_Factory::get_protocol_factories (void)
 }
 
 ACE_Reactor_Impl *
-TAO_Advanced_Resource_Factory::allocate_reactor_impl (void) const
+TAO_Advanced_Resource_Factory::allocate_reactor_impl () const
 {
   ACE_Reactor_Impl *impl = 0;
 
@@ -424,7 +424,6 @@ TAO_Advanced_Resource_Factory::allocate_reactor_impl (void) const
   // get a timer queue (or not) from a possibly configured
   // time policy
   TAO_RSF_Timer_Queue_Ptr tmq (*this, this->create_timer_queue ());
-//@@ TAO_ADVANCED_RESOURCE_REACTOR_SPL_COMMENT_HOOK_START
   switch (this->reactor_type_)
     {
     case TAO_REACTOR_SELECT_MT:
@@ -496,8 +495,6 @@ TAO_Advanced_Resource_Factory::allocate_reactor_impl (void) const
       break;
     }
 
-//@@ TAO_ADVANCED_RESOURCE_REACTOR_SPL_COMMENT_HOOK_END
-
   // safe to release timer queue
   tmq.release ();
   return impl;
