@@ -1,5 +1,4 @@
 // -*- C++ -*-
-//
 //=============================================================================
 /**
  *  @file    Synch_Invocation.h
@@ -72,7 +71,7 @@ namespace TAO
     /// remote object.
     /**
      * There is a exception declaration in this method which ensures
-     * that the exceptions propogated by the remote objects are
+     * that the exceptions propagated by the remote objects are
      * converted a CORBA exceptions for the clients. This method does
      * a bunch of things necessary to create and send the
      * invocation. This method is also nerve centre for the
@@ -82,12 +81,11 @@ namespace TAO
 
     /**
      * Indicate that retry state should be tracked and controlled
-     * in the presense of exceptions.
+     * in the presence of exceptions.
      */
     void set_retry_state (Invocation_Retry_State *retry_state);
 
   protected:
-
     /**
      * This method is selectively made virtual, so that inherited
      * classes can overload the  user exception handling type. For
@@ -114,7 +112,6 @@ namespace TAO
     Invocation_Retry_State *retry_state_;
 
   private:
-
     /// Helper method that checks the reply status of the
     /// replies and takes appropriate action.
     /**
@@ -139,7 +136,6 @@ namespace TAO
    * - For some SYNC_SCOPE policies namely SYNC_WITH_TARGET and
    *   SYNC_WITH_SERVER the invocation classes have to treat the
    *   invocation as a twoway invocation (more or less)
-   *
    */
   class TAO_Export Synch_Oneway_Invocation
     : public Synch_Twoway_Invocation
@@ -173,23 +169,20 @@ namespace TAO
   class TAO_Export Reply_Guard
   {
   public:
-
     Reply_Guard (Invocation_Base *s, Invocation_Status is);
 
     /// The destructor calls Invocation_Base::invoke_status with the
     /// right invoke status, which is useful for PI's.
-    ~Reply_Guard (void);
+    ~Reply_Guard ();
 
     /// Mutator to set the invocation status.
     void set_status (Invocation_Status s);
 
   private:
-
     Reply_Guard (Reply_Guard const &);
     Reply_Guard & operator= (Reply_Guard const &);
 
   private:
-
     Invocation_Base * const invocation_;
     Invocation_Status status_;
   };
