@@ -42,7 +42,7 @@ namespace TAO
 #if TAO_HAS_INTERCEPTORS == 1
     virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
-    const typename S_var::s_traits::char_type * arg (void) const;
+    const typename S_var::s_traits::char_type * arg () const;
 
   protected:
     typename S_var::s_traits::char_type const * x_;
@@ -61,9 +61,9 @@ namespace TAO
   {
   public:
     In_UB_String_Clonable_Argument_T (const typename S_var::s_traits::char_type * x);
-    virtual ~In_UB_String_Clonable_Argument_T (void);
+    virtual ~In_UB_String_Clonable_Argument_T ();
 
-    virtual Argument* clone (void);
+    virtual Argument* clone ();
 
   private:
     bool is_clone_;
@@ -87,7 +87,7 @@ namespace TAO
 #if TAO_HAS_INTERCEPTORS == 1
     virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
-    typename S_var::s_traits::char_type *& arg (void);
+    typename S_var::s_traits::char_type *& arg ();
 
   private:
     typename S_var::s_traits::char_type *& x_;
@@ -110,7 +110,7 @@ namespace TAO
 #if TAO_HAS_INTERCEPTORS == 1
     virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
-    typename S_var::s_traits::char_type *& arg (void);
+    typename S_var::s_traits::char_type *& arg ();
 
   private:
     typename S_var::s_traits::char_type *& x_;
@@ -127,15 +127,15 @@ namespace TAO
   class Ret_UB_String_Argument_T : public RetArgument
   {
   public:
-    Ret_UB_String_Argument_T (void);
+    Ret_UB_String_Argument_T ();
 
     virtual CORBA::Boolean demarshal (TAO_InputCDR &);
 #if TAO_HAS_INTERCEPTORS == 1
     virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
-    typename S_var::s_traits::char_type *& arg (void);
-    typename S_var::s_traits::char_type * excp (void);
-    typename S_var::s_traits::char_type * retn (void);
+    typename S_var::s_traits::char_type *& arg ();
+    typename S_var::s_traits::char_type * excp ();
+    typename S_var::s_traits::char_type * retn ();
 
   private:
     S_var x_;
