@@ -51,7 +51,7 @@ namespace TAO
                       TAO_Synch_Reply_Dispatcher &rd);
 
     /*! @copydoc TAO_Wait_Strategy::can_process_upcalls() */
-    virtual bool can_process_upcalls (void) const;
+    virtual bool can_process_upcalls () const;
 
     /*! @copydoc TAO_Wait_Strategy::defer_upcall() */
     virtual int defer_upcall (ACE_Event_Handler*);
