@@ -13,20 +13,12 @@ TAO_Wait_On_Leader_Follower::TAO_Wait_On_Leader_Follower
 {
 }
 
-TAO_Wait_On_Leader_Follower::~TAO_Wait_On_Leader_Follower (void)
+TAO_Wait_On_Leader_Follower::~TAO_Wait_On_Leader_Follower ()
 {
 }
 
-/*
- * Hook to specialize the wait strategy when the concrete strategy is
- * a simple "lf" strategy. Add all public/protected/private methods
- * within the *COPY* hooks.
- */
-
-//@@ WAIT_STRATEGY_SPL_COPY_HOOK_START
-
 int
-TAO_Wait_On_Leader_Follower::register_handler (void)
+TAO_Wait_On_Leader_Follower::register_handler ()
 {
   if (!this->is_registered_)
     {
@@ -37,7 +29,7 @@ TAO_Wait_On_Leader_Follower::register_handler (void)
 }
 
 bool
-TAO_Wait_On_Leader_Follower::non_blocking (void) const
+TAO_Wait_On_Leader_Follower::non_blocking () const
 {
   return true;
 }
@@ -52,8 +44,6 @@ TAO_Wait_On_Leader_Follower::sending_request (TAO_ORB_Core *orb_core,
       this->transport_->register_handler ();
     }
 
-  // Send the request.
-//@@ LF_WAIT_STRATEGY_SPL_SENDING_REQUEST_HOOK
   return this->TAO_Wait_Strategy::sending_request (orb_core, msg_semantics);
 }
 
@@ -67,14 +57,9 @@ TAO_Wait_On_Leader_Follower::wait (ACE_Time_Value *max_wait_time,
 }
 
 bool
-TAO_Wait_On_Leader_Follower::can_process_upcalls (void) const
+TAO_Wait_On_Leader_Follower::can_process_upcalls () const
 {
   return true;
 }
 
-//@@ WAIT_STRATEGY_SPL_COPY_HOOK_END
-/*
- * End copy hook.
- */
-
 TAO_END_VERSIONED_NAMESPACE_DECL
