@@ -1,7 +1,5 @@
 #include "tao/Wait_Strategy.h"
 
-//@@ WAIT_STRATEGY_SPL_COPY_HOOK_START
-
 #if !defined (__ACE_INLINE__)
 # include "tao/Wait_Strategy.inl"
 #endif /* __ACE_INLINE__ */
@@ -16,7 +14,7 @@ TAO_Wait_Strategy::TAO_Wait_Strategy (TAO_Transport *transport)
 }
 
 // Destructor.
-TAO_Wait_Strategy::~TAO_Wait_Strategy (void)
+TAO_Wait_Strategy::~TAO_Wait_Strategy ()
 {
 }
 
@@ -26,25 +24,15 @@ TAO_Wait_Strategy::defer_upcall (ACE_Event_Handler*)
   return -1;
 }
 
-/*
- * Hook to comment out this method in the lf wait strategy
- */
-//@@ LF_WAIT_STRATEGY_SPL_COMMENT_HOOK_START
 int
 TAO_Wait_Strategy::sending_request (TAO_ORB_Core *, TAO_Message_Semantics)
 {
   return 0;
 }
-//@@ LF_WAIT_STRATEGY_SPL_COMMENT_HOOK_END
 
 void
 TAO_Wait_Strategy::finished_request ()
 {
 }
 
-/*
- * Hook to specialize the Wait Strategy
- */
-//@@ TAO_WAIT_STRATEGY_SPL_ADD_HOOK
-
 TAO_END_VERSIONED_NAMESPACE_DECL
