@@ -8,8 +8,8 @@ namespace TAO
 {
 
   XtResource_Factory::XtResource_Factory (XtAppContext p_context):
-    reactor_impl_( 0 ),
-    context_( p_context )
+    reactor_impl_(nullptr),
+    context_(p_context)
   {
   }
 
@@ -17,19 +17,19 @@ namespace TAO
   XtResource_Factory::reactor_impl (void)
   {
     // synchronized by external locks
-    if (this->context_ == 0)
+    if (!this->context_)
     {
       TAOLIB_ERROR ((LM_ERROR,
                   ACE_TEXT("TAO (%P|%t) - XtAppContext is undefined.")
                   ACE_TEXT(" Cannot create ACE_XtReactor\n")));
-      return 0;
+      return nullptr; // Private and undefined;
     }
 
     if (!this->reactor_impl_)
     {
       ACE_NEW_RETURN (this->reactor_impl_,
                       ACE_XtReactor (this->context_),
-                      0);
+                      nullptr);
 
       if (TAO_debug_level > 0)
         TAOLIB_DEBUG ((LM_DEBUG,
