@@ -541,8 +541,7 @@ TAO_ZIOP_Loader::complete_compression (Compression::Compressor_ptr compressor,
                           ACE_TEXT ("compressed length (%u >= %u) ")
                           ACE_TEXT ("uncompressed length, (did not compress).\n"),
                           static_cast <unsigned int> (output.length () + Compression_Overhead),
-                          static_cast <unsigned int> (original_data_length)
-                        ));
+                          static_cast <unsigned int> (original_data_length)));
             }
           return false;
         }
