@@ -4,8 +4,6 @@
 /**
  *  @file     default_client.h
  *
- *  $Id: default_client.h 97469 2013-12-13 15:18:38Z mesnier_p $
- *
  *  @author  Chris Cleeland
  */
 //=============================================================================
@@ -38,7 +36,6 @@ class TAO_Export TAO_Default_Client_Strategy_Factory
   : public TAO_Client_Strategy_Factory
 {
 public:
-  // = Initialization and termination methods.
   /// Constructor.
   TAO_Default_Client_Strategy_Factory (void);
 
@@ -56,13 +53,13 @@ public:
   //   following methods.
   virtual TAO_Transport_Mux_Strategy *create_transport_mux_strategy (TAO_Transport *transport);
   virtual ACE_Lock *create_transport_mux_strategy_lock (void);
-  virtual int reply_dispatcher_table_size (void) const;
+  virtual int reply_dispatcher_table_size () const;
   virtual int allow_callback (void);
   virtual TAO_Wait_Strategy *create_wait_strategy (TAO_Transport *transport);
   virtual TAO_Connect_Strategy *create_connect_strategy (TAO_ORB_Core *);
-  virtual bool use_cleanup_options (void) const;
-  virtual Connect_Strategy connect_strategy (void) const;
-  virtual const TAO::Invocation_Retry_Params &invocation_retry_params (void) const;
+  virtual bool use_cleanup_options () const;
+  virtual Connect_Strategy connect_strategy () const;
+  virtual const TAO::Invocation_Retry_Params &invocation_retry_params () const;
   virtual Messaging::SyncScope sync_scope () const;
 
 protected:
