@@ -34,5 +34,5 @@ AMI_Buffering_Admin::flush (void)
 void
 AMI_Buffering_Admin::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
