@@ -12,7 +12,7 @@ void
 Callback_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG, "Performing clean shutdown\n"));
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 void
@@ -65,5 +65,5 @@ Simple_Server_i::callback_object (Callback_ptr callback
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
