@@ -14,7 +14,7 @@ public:
   Coordinator (CORBA::ULong peer_count);
 
   /// Check if all the peers have registered already
-  int has_all_peers (void) const;
+  int has_all_peers () const;
 
   /// Check a session on each peer
   void create_session_list (Test::Session_Control_ptr session_control,
