@@ -38,5 +38,5 @@ Peer::shutdown (void)
 
   ACE_DEBUG ((LM_DEBUG,
               "(%P|%t) Peer::shutdown, shutting down ORB\n"));
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
