@@ -17,5 +17,5 @@ Blocking_Sync_None::slow_operation (const Test::Payload &,
 void
 Blocking_Sync_None::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
