@@ -28,5 +28,5 @@ BlobServerImpl::test(
 void
 BlobServerImpl::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
