@@ -17,5 +17,5 @@ Test_i::test_method (void)
 void
 Test_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
