@@ -2,5 +2,5 @@
 
 void Callee_i::callback (const char * message)
 {
-  ACE_DEBUG ((LM_DEBUG, "Callee_i::callback: message is %s", message));
+  ACE_DEBUG ((LM_DEBUG, "Callee_i::callback: message is %C", message));
 }
