@@ -28,13 +28,13 @@ Sender_i::send_ready_message (void)
 }
 
 CORBA::ULong
-Sender_i::get_number_received (void) const
+Sender_i::get_number_received () const
 {
   return number_received_;
 }
 
 CORBA::ULong
-Sender_i::get_active_objects (void) const
+Sender_i::get_active_objects () const
 {
   return active_objects_;
 }
