@@ -61,8 +61,8 @@ Echo_Server_Request_Interceptor::receive_request_service_contexts (
   // locally on the server side as a side effect of another call,
   // meaning that the client hasn't added the service context yet.
   // Same goes for the shutdown call
-  if (ACE_OS_String::strcmp ("_is_a", operation.in ()) == 0 ||
-      ACE_OS_String::strcmp ("shutdown", operation.in ()) == 0)
+  if (ACE_OS::strcmp ("_is_a", operation.in ()) == 0 ||
+      ACE_OS::strcmp ("shutdown", operation.in ()) == 0)
     return;
 
   forward_location_done_ = true;
