@@ -71,5 +71,5 @@ Hello::mod_stringList (::Test::StringList & iosl)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
