@@ -25,5 +25,5 @@ Simple_Server_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
               "server (%P) Received shutdown request from client\n"));
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
