@@ -15,5 +15,5 @@ Hello::get_string (const char * A, const char * B, const char * C)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
