@@ -20,7 +20,7 @@ public:
   Worker(Publisher_impl * _owner);
   ~Worker();
   void addSubscriber(Subscriber_ptr subscriber);
-  virtual int svc (void);
+  virtual int svc ();
   void terminate();
 private:
   bool terminated;
@@ -145,6 +145,6 @@ void
 Publisher_impl::shutdown (
                           )
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
   worker->terminate();
 }
