@@ -12,11 +12,11 @@ public:
   DllORB (void);
   virtual ~DllORB (void);
 
-  CORBA::ORB_ptr orb (void) const;
+  CORBA::ORB_ptr orb () const;
 
   virtual int init (int argc, ACE_TCHAR *argv[]);
 
-  virtual int fini (void);
+  virtual int fini ();
 
 private:
   unsigned int                   failPrePostInit_;
