@@ -21,6 +21,6 @@ void Server::request (
 void Server::shutdown (
   void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
