@@ -15,5 +15,5 @@ Hello::method(Test::Hello_out r)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
