@@ -71,7 +71,7 @@ public:
   Worker (CORBA::ORB_ptr orb);
   // ctor
 
-  virtual int svc (void);
+  virtual int svc ();
   // The thread entry point.
 
 private:
@@ -96,7 +96,7 @@ public:
   ~Client () ;
 
   /// The thread entry point.
-  virtual int svc (void);
+  virtual int svc ();
 
   // private:
   /// Var for the AMI_Test object.
@@ -296,8 +296,8 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       server->shutdown ();
 
-      root_poa->destroy (1,  // ethernalize objects
-                         0); // wait for completion
+      root_poa->destroy (true,  // ethernalize objects
+                         false); // wait for completion
 
       orb->destroy ();
     }
