@@ -17,5 +17,5 @@ Hello::get_string (void)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
