@@ -21,7 +21,7 @@ public:
                server_ptr s);
   int svc (void);
 
-  bool exception (void) const;
+  bool exception () const;
 
 private:
   client_var client_;
@@ -154,7 +154,7 @@ ACE_TMAIN (int argc,
           server->shutdown ();
         }
 
-      root_poa->destroy (1, 1);
+      root_poa->destroy (true, true);
 
       orb->destroy ();
     }
