@@ -1,5 +1,3 @@
-// This may look like C, but it's really -*- C++ -*-
-
 //=============================================================================
 /**
  *  @file    OrbShutdownTask.h
@@ -15,24 +13,20 @@
 #include "ace/Task.h"
 #include "tao/ORB.h"
 
-
 class CSD_TP_Test_Export OrbShutdownTask : public ACE_Task_Base
 {
-  public:
+public:
+  OrbShutdownTask();
+  virtual ~OrbShutdownTask() = default;
 
-    OrbShutdownTask();
-    virtual ~OrbShutdownTask();
+  void orb(CORBA::ORB_ptr orb);
 
-    void orb(CORBA::ORB_ptr orb);
+  virtual int open(void*);
+  virtual int svc();
+  virtual int close(u_long);
 
-    virtual int open(void*);
-    virtual int svc();
-    virtual int close(u_long);
-
-
-  private:
-
-    CORBA::ORB_var orb_;
+private:
+  CORBA::ORB_var orb_;
 };
 
 #endif
