@@ -29,5 +29,5 @@ Callback::shutdown (void)
   ACE_DEBUG ((LM_DEBUG,
               "(%P|%t) Callback - shutdown!\n"));
 
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
