@@ -1,6 +1,3 @@
-//
-// $Id: Hello.cpp 94802 2011-10-20 09:46:10Z mcorino $
-//
 #include "Hello.h"
 #include "tao/ORB_Core.h"
 #include "tao/ORB_Table.h"
@@ -28,5 +25,5 @@ Hello::shutdown (void)
   // call to this method before shutting down the ORB.  We sleep
   // to avoid BAD_INV_ORDER exceptions on fast dual processor machines.
   ACE_OS::sleep (1);
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
