@@ -1,5 +1,3 @@
-// $Id: test_i.cpp 91652 2010-09-08 14:42:59Z johnnyw $
-
 #include "test_i.h"
 #include "tao/debug.h"
 
@@ -49,7 +47,7 @@ Simple_Server_i::raise_system_exception (void)
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 CORBA::Long
