@@ -21,7 +21,7 @@ public:
   Test_DynAny (CORBA::ORB_var orb, int debug);
   ~Test_DynAny (void);
 
-  const char* test_name (void) const;
+  const char* test_name () const;
 
   int run_test (void);
 
