@@ -1,6 +1,3 @@
-//
-// $Id: Hello.cpp 96505 2012-12-14 00:26:38Z mesnier_p $
-//
 #include "Hello.h"
 #include "ace/OS_NS_unistd.h"
 
@@ -39,5 +36,5 @@ Hello::get_string (CORBA::Long client_num)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
