@@ -167,7 +167,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
           server->shutdown ();
         }
 
-      root_poa->destroy (1, 1);
+      root_poa->destroy (true, true);
 
     }
   catch (const CORBA::COMM_FAILURE& x)
