@@ -25,7 +25,7 @@ Payload_Receiver::more_data (const Test::Payload &payload)
 void
 Payload_Receiver::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 
