@@ -27,5 +27,5 @@ Hello::get_helloworld (void)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
