@@ -9,7 +9,6 @@ Simple_Server_i::Simple_Server_i (CORBA::ORB_ptr orb)
 Simple_Server_i::Simple_Server_i (void)
   : orb_ (0)
 {
-  // no-op
 }
 
 CORBA::Long
@@ -25,5 +24,5 @@ Simple_Server_i::remote_call (void)
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
