@@ -15,7 +15,6 @@ Simple_Server_i::Simple_Server_i (CORBA::ORB_ptr orb)
 Simple_Server_i::Simple_Server_i (void)
   : orb_ (0)
 {
-  // no-op
 }
 
 CORBA::ULongLong
@@ -31,5 +30,5 @@ Simple_Server_i::remote_call (void)
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
