@@ -7,7 +7,6 @@
 Simple_Server_i::Simple_Server_i (void)
   :orb_ (0)
 {
-  // no-op
 }
 
 void
@@ -21,5 +20,5 @@ Simple_Server_i::remote_call (void)
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
