@@ -12,5 +12,5 @@ Simple_Server_i::test_method (void)
 void
 Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
