@@ -21,5 +21,5 @@ Hello::set_string (const char * s)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
