@@ -53,5 +53,5 @@ Test_impl::get_vb()
 void
 Test_impl::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
