@@ -42,5 +42,5 @@ Test_impl::get_value2 (void)
 void
 Test_impl::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
