@@ -31,8 +31,6 @@ template <class Servant>
 class Server
 {
 public:
-  // = Initialization and termination methods.
-
   /// Constructor.
   Server (void);
 
@@ -92,8 +90,6 @@ template <class InterfaceObj, class Var>
 class Client
 {
 public:
-
-  // = Initialization and termination methods.
   /// Constructor.
   Client (void);
 
@@ -107,7 +103,7 @@ public:
   InterfaceObj *operator-> () { return server_.in ();};
 
   /// Returns the shutdown flag.
-  int shutdown (void );
+  int shutdown ();
 
   /// Fills in the shutdwon flag.
   void shutdown (int);
