@@ -14,5 +14,5 @@ ORT_test_i::request_server (void)
 void
 ORT_test_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
