@@ -18,5 +18,5 @@ Hello::get_string (
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
