@@ -7,22 +7,24 @@
 
 class ORB_Task : public ACE_Task_Base
 {
- private:
+private:
   CORBA::ORB_var orb_;
 
- public:
+public:
   ORB_Task (CORBA::ORB_ptr orb)
     : orb_ (CORBA::ORB::_duplicate (orb))
+  {
+    if (CORBA::is_nil (orb_.in ()) == 1)
     {
-      if (CORBA::is_nil (orb_.in()) == 1) {
-  ACE_ERROR ((LM_ERROR, "ORB_Task> Ctr> Orb is NULL\n"));
-      }
-    };
+      ACE_ERROR ((LM_ERROR, "ORB_Task> Ctr> Orb is NULL\n"));
+    }
+  };
 
   virtual int svc ()
   {
-    if (CORBA::is_nil (orb_.in()) == 0) {
-      orb_->run();
+    if (CORBA::is_nil (orb_.in ()) == 0)
+    {
+      orb_->run ();
     }
 
     return -1;
