@@ -3,42 +3,48 @@
 
 #include "Server.h"
 
-#include "ace/Task.h"
 #include "ace/ARGV.h"
-#include "ace/Auto_Ptr.h"
+#include "ace/Task.h"
+
+#include <string>
 
 class Server_Task : public ACE_Task_Base
 {
- public:
-
+public:
   Server_Task (const std::string& args)
     : args_ (args)
-  { }
-  ~Server_Task ()
-    {
-      this->force_shutdown ();
-    }
+  {}
+  ~Server_Task () { this->force_shutdown (); }
 
   virtual int svc ()
   {
     bool initializer = false;
     {
       ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon, this->mutex_, -1);
-      if (server_.get() == 0) {
-  ACE_ARGV my_args (args_.c_str());
+      if (!server_)
+      {
+        ACE_ARGV my_args (args_.c_str ());
 
-  // Initialize Server ORB in new thread
-  ACE_auto_ptr_reset (server_, new Server (my_args.argc(), my_args.argv()));
-  ACE_ASSERT (server_.get() != 0);
-  initializer = true;
+        // Initialize Server ORB in new thread
+
+#ifdef ACE_HAS_CPP14
+        server_ = std::make_unique<Server> (my_args.argc (), my_args.argv ());
+#else
+        server_.reset (new Server(my_args.argc (), my_args.argv ()));
+#endif
+
+        ACE_ASSERT (server_);
+        initializer = true;
       }
     }
 
-    if (initializer) {
+    if (initializer)
+    {
       server_->run (false);
       this->force_shutdown (); // servant thread is responsible for shutdown
     }
-    else {
+    else
+    {
       server_->run (true);
     }
 
@@ -47,7 +53,8 @@ class Server_Task : public ACE_Task_Base
 
   bool ready ()
   {
-    if (server_.get() != 0) {
+    if (server_)
+    {
       return server_->init_;
     }
 
@@ -56,14 +63,15 @@ class Server_Task : public ACE_Task_Base
 
   void force_shutdown ()
   {
-    if (server_.get() != 0) {
+    if (server_)
+    {
       server_->shutdown ();
     }
   }
 
- private:
+private:
   std::string args_;
-  std::auto_ptr<Server> server_;
+  std::unique_ptr<Server> server_;
   TAO_SYNCH_MUTEX mutex_;
 };
 
