@@ -36,5 +36,5 @@ Receiver_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
               "(%P|%t) About to invoke shutdown...\n"));
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
