@@ -49,5 +49,5 @@ Sender_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
               "(%P|%t) About to invoke shutdown...\n"));
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
