@@ -30,5 +30,5 @@ test_i::op (void)
 void
 test_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
