@@ -310,7 +310,7 @@ DatabaseImpl::Employee::~Employee (void)
 }
 
 const char *
-DatabaseImpl::Employee::name (void) const
+DatabaseImpl::Employee::name () const
 {
   return this->name_;
 }
@@ -328,7 +328,7 @@ DatabaseImpl::Employee::name (const char* name)
 }
 
 CORBA::Long
-DatabaseImpl::Employee::id (void) const
+DatabaseImpl::Employee::id () const
 {
   return this->id_;
 }
@@ -351,22 +351,17 @@ DatabaseImpl::Employee::operator delete (void *pointer)
   DATABASE::instance ()->free (pointer);
 }
 
-#if defined (ACE_HAS_NEW_NOTHROW)
   /// Overloaded new operator, nothrow_t variant.
 void *
-DatabaseImpl::Employee::operator new (size_t size, const ACE_nothrow_t &)
+DatabaseImpl::Employee::operator new (size_t size, const std::nothrow_t &)
 {
   return DATABASE::instance ()->malloc (size);
 }
 
-#if !defined (ACE_LACKS_PLACEMENT_OPERATOR_DELETE)
 void
-DatabaseImpl::Employee::operator delete (void *ptr, const ACE_nothrow_t&) throw ()
+DatabaseImpl::Employee::operator delete (void *ptr, const std::nothrow_t&) throw ()
 {
   DATABASE::instance ()->free (ptr);
 }
-#endif /* ACE_LACKS_PLACEMENT_OPERATOR_DELETE */
-
-#endif /* ACE_HAS_NEW_NOTHROW */
 
 ACE_SINGLETON_TEMPLATE_INSTANTIATE(ACE_Singleton, DatabaseImpl::Simpler_Database_Malloc,  ACE_Null_Mutex);
