@@ -347,7 +347,7 @@ ACE_TMAIN (int argc, ACE_TCHAR *argv[])
     }
   try
     {
-      root_poa->destroy (1, 1);
+      root_poa->destroy (true, true);
 
       orb->destroy ();
     }
