@@ -34,7 +34,7 @@ test_i::forward (void)
 void
 test_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
 
 PortableServer::POA_ptr
