@@ -29,7 +29,7 @@ Test_ObjRef::~Test_ObjRef (void)
 }
 
 const char *
-Test_ObjRef::opname (void) const
+Test_ObjRef::opname () const
 {
   return this->opname_;
 }
@@ -262,10 +262,10 @@ Test_ObjRef::print_values (void)
 
   ACE_DEBUG ((LM_DEBUG,
               "\n=*=*=*=*=*=*"
-              "in = %s, "
-              "inout = %s, "
-              "out = %s, "
-              "ret = %s*=*=*=*=*=\n",
+              "in = %C, "
+              "inout = %C, "
+              "out = %C, "
+              "ret = %C*=*=*=*=*=\n",
               in?in:"ERROR(null string)",
               inout?inout:"ERROR(null string)",
               out?out:"ERROR(null string)",
