@@ -35,7 +35,7 @@ Test_Struct_Sequence::~Test_Struct_Sequence (void)
 }
 
 const char *
-Test_Struct_Sequence::opname (void) const
+Test_Struct_Sequence::opname () const
 {
   return this->opname_;
 }
@@ -232,7 +232,7 @@ Test_Unbounded_Struct_Sequence::~Test_Unbounded_Struct_Sequence (void)
 }
 
 const char *
-Test_Unbounded_Struct_Sequence::opname (void) const
+Test_Unbounded_Struct_Sequence::opname () const
 {
   return this->opname_;
 }
@@ -381,8 +381,8 @@ Test_Unbounded_Struct_Sequence::print_sequence (const Param_Test::PathSpec &s)
 
       ACE_DEBUG ((LM_DEBUG,
                   "Element #%d\n"
-                  "\tname.id = %s\n"
-                  "\tname.kind = %s\n"
+                  "\tname.id = %C\n"
+                  "\tname.kind = %C\n"
                   "\tprocess = %d\n",
                   i,
                   vs.name.id.in (), vs.name.kind.in (), vs.process));
