@@ -28,7 +28,7 @@ public:
   int run_sii_test (Param_Test_ptr objref);
 
   /// return operation name
-  const char *opname (void) const;
+  const char *opname () const;
 
   /// set values for parameters
   int init_parameters (Param_Test_ptr objref);
