@@ -5,6 +5,10 @@
 
 #include "server_interceptor.h"
 
+Echo_Server_ORBInitializer::Echo_Server_ORBInitializer (int& result) : result_ (result)
+{
+}
+
 void
 Echo_Server_ORBInitializer::pre_init (
     PortableInterceptor::ORBInitInfo_ptr)
@@ -21,7 +25,7 @@ Echo_Server_ORBInitializer::post_init (
 
   // Install the Echo server request interceptor
   ACE_NEW_THROW_EX (interceptor,
-                    Echo_Server_Request_Interceptor,
+                    Echo_Server_Request_Interceptor (this->result_),
                     CORBA::NO_MEMORY ());
 
   PortableInterceptor::ServerRequestInterceptor_var
