@@ -51,5 +51,5 @@ test_i::shutdown (void)
   ACE_DEBUG ((LM_INFO,
               "Server is shutting down.\n"));
 
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
