@@ -52,5 +52,5 @@ test_i::_default_POA (void)
 void
 test_i::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
