@@ -8,5 +8,5 @@ Shutdown_Helper::Shutdown_Helper (CORBA::ORB_ptr orb)
 void
 Shutdown_Helper::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
