@@ -16,5 +16,5 @@ test_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
               "(%P|%t) About to invoke shudown...\n"));
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
