@@ -13,5 +13,5 @@ Ping_Service::ping (void)
 void
 Ping_Service::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
