@@ -20,7 +20,7 @@ public:
   void dump_results (void);
 
   /// Get the status of the flag..
-  bool is_done (void) const;
+  bool is_done () const;
 
   // = The skeleton methods
   virtual CORBA::Boolean get_data (CORBA::ULong size,
