@@ -15,7 +15,7 @@ public:
   Worker (CORBA::ORB_ptr orb);
 
   // The thread entry point.
-  virtual int svc (void);
+  virtual int svc ();
 
 
 private:
