@@ -46,5 +46,5 @@ Hello::big_request (const ::Test::Octet_Seq & octet_in)
 void
 Hello::shutdown (void)
 {
-  this->orb_->shutdown (0);
+  this->orb_->shutdown (false);
 }
