@@ -48,7 +48,7 @@ public:
   ~Invocation (void);
 
   // return true if the invocation was a oneway
-  bool is_oneway(void) const;
+  bool is_oneway() const;
 
   // return true if the request is a oneway and has all its octets, or
   // if it also has all its reply octets. The side-effect of this call
@@ -56,16 +56,16 @@ public:
   // it with the peer process.
   bool message_complete (void);
 
-  size_t request_id (void) const;
+  size_t request_id () const;
 
   // returns true if this request was sent by the host process.
-  bool sent_request (void) const;
+  bool sent_request () const;
 
   // returns the size parsed from either the request or reply preamble
   // which can be used to match a HEXDUMP b
-  size_t expected_size (void) const;
+  size_t expected_size () const;
 
-  size_t request_bytes (void) const;
+  size_t request_bytes () const;
 
   void set_target (const char *oid, size_t oid_len);
 
@@ -78,8 +78,8 @@ public:
   size_t repl_line (void);
 
   void add_notify_incident (const ACE_CString &text, size_t offset);
-  Thread *waiter (void) const;
-  long handle (void) const;
+  Thread *waiter () const;
+  long handle () const;
 
   void new_line (ostream &strm, size_t indent, int offset,  bool add_nl, bool show_indent);
   void dump_detail (ostream &strm, size_t indent, Dump_Mode mode, bool show_handle);
