@@ -15,7 +15,7 @@ public:
     TEST_ACE_THREAD_MUTEX_GUARD // -t
   };
 
-  virtual int svc (void);
+  virtual int svc ();
   virtual int init (int, ACE_TCHAR *[]);
 
   void test_guard (int);
